Class: Stigg::Internal::Type::BaseModel Abstract
- Inherits:
-
Object
- Object
- Stigg::Internal::Type::BaseModel
- Extended by:
- Converter, Util::SorbetRuntimeSupport
- Defined in:
- lib/stigg/internal/type/base_model.rb,
sig/stigg/internal/type/base_model.rbs
Overview
Direct Known Subclasses
MyCursorIDPage::Pagination, Models::V1::Addon, Models::V1::Addon::Data, Models::V1::Addon::Data::Entitlement, Models::V1::AddonArchiveParams, Models::V1::AddonCreateDraftParams, Models::V1::AddonCreateParams, Models::V1::AddonListChargesParams, Models::V1::AddonListChargesResponse, Models::V1::AddonListChargesResponse::CreditRate, Models::V1::AddonListChargesResponse::Price, Models::V1::AddonListChargesResponse::Tier, Models::V1::AddonListChargesResponse::Tier::FlatPrice, Models::V1::AddonListChargesResponse::Tier::UnitPrice, Models::V1::AddonListParams, Models::V1::AddonListParams::CreatedAt, Models::V1::AddonListResponse, Models::V1::AddonListResponse::Entitlement, Models::V1::AddonPublishParams, Models::V1::AddonPublishResponse, Models::V1::AddonPublishResponse::Data, Models::V1::AddonRemoveDraftParams, Models::V1::AddonRemoveDraftResponse, Models::V1::AddonRemoveDraftResponse::Data, Models::V1::AddonRetrieveParams, Models::V1::AddonUpdateParams, Models::V1::AddonUpdateParams::Charges, Models::V1::AddonUpdateParams::Charges::MinimumSpend, Models::V1::AddonUpdateParams::Charges::MinimumSpend::Minimum, Models::V1::AddonUpdateParams::Charges::OveragePricingModel, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::MonthlyResetPeriodConfiguration, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::WeeklyResetPeriodConfiguration, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::YearlyResetPeriodConfiguration, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::CreditRate, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Price, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::FlatPrice, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::UnitPrice, Models::V1::AddonUpdateParams::Charges::PricingModel, Models::V1::AddonUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::CreditRate, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Price, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Tier, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Tier::FlatPrice, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Tier::UnitPrice, Models::V1::AddonUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration, Models::V1::AddonUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration, Models::V1::Addons::AddonPackageEntitlement, Models::V1::Addons::AddonPackageEntitlement::Data::Credit, Models::V1::Addons::AddonPackageEntitlement::Data::Feature, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Addons::EntitlementCreateParams, Models::V1::Addons::EntitlementCreateParams::Entitlement::Credit, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::YearlyResetPeriodConfiguration, Models::V1::Addons::EntitlementCreateResponse, Models::V1::Addons::EntitlementCreateResponse::Data::Credit, Models::V1::Addons::EntitlementCreateResponse::Data::Feature, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Addons::EntitlementDeleteParams, Models::V1::Addons::EntitlementListParams, Models::V1::Addons::EntitlementListResponse, Models::V1::Addons::EntitlementListResponse::Data::Credit, Models::V1::Addons::EntitlementListResponse::Data::Feature, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Addons::EntitlementListResponse::Pagination, Models::V1::Addons::EntitlementUpdateParams, Models::V1::Addons::EntitlementUpdateParams::Body::Credit, Models::V1::Addons::EntitlementUpdateParams::Body::Feature, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::MonthlyResetPeriodConfiguration, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::WeeklyResetPeriodConfiguration, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::YearlyResetPeriodConfiguration, Models::V1::ContractCreateParams, Models::V1::ContractCreateParams::Subscription, Models::V1::ContractCreateParams::Subscription::NewSubscription, Models::V1::ContractCreateParams::Subscription::NewSubscription::Addon, Models::V1::ContractCreateParams::Subscription::NewSubscription::AppliedCoupon, Models::V1::ContractCreateParams::Subscription::NewSubscription::AppliedCoupon::Configuration, Models::V1::ContractCreateParams::Subscription::NewSubscription::AppliedCoupon::Discount, Models::V1::ContractCreateParams::Subscription::NewSubscription::AppliedCoupon::Discount::AmountsOff, Models::V1::ContractCreateParams::Subscription::NewSubscription::BillingInformation, Models::V1::ContractCreateParams::Subscription::NewSubscription::BillingInformation::BillingAddress, Models::V1::ContractCreateParams::Subscription::NewSubscription::BillingInformation::TaxID, Models::V1::ContractCreateParams::Subscription::NewSubscription::Budget, Models::V1::ContractCreateParams::Subscription::NewSubscription::Charge, Models::V1::ContractCreateParams::Subscription::NewSubscription::CheckoutOptions, Models::V1::ContractCreateParams::Subscription::NewSubscription::Entitlement::Credit, Models::V1::ContractCreateParams::Subscription::NewSubscription::Entitlement::Feature, Models::V1::ContractCreateParams::Subscription::NewSubscription::Entitlement::Feature::MonthlyResetPeriodConfiguration, Models::V1::ContractCreateParams::Subscription::NewSubscription::Entitlement::Feature::WeeklyResetPeriodConfiguration, Models::V1::ContractCreateParams::Subscription::NewSubscription::Entitlement::Feature::YearlyResetPeriodConfiguration, Models::V1::ContractCreateParams::Subscription::NewSubscription::MinimumSpend, Models::V1::ContractCreateParams::Subscription::NewSubscription::PriceOverride, Models::V1::ContractCreateParams::Subscription::NewSubscription::PriceOverride::CreditRate, Models::V1::ContractCreateParams::Subscription::NewSubscription::PriceOverride::Tier, Models::V1::ContractCreateParams::Subscription::NewSubscription::PriceOverride::Tier::FlatPrice, Models::V1::ContractCreateParams::Subscription::NewSubscription::PriceOverride::Tier::UnitPrice, Models::V1::ContractCreateParams::Subscription::NewSubscription::TrialOverrideConfiguration, Models::V1::ContractCreateResponse, Models::V1::ContractCreateResponse::Data, Models::V1::ContractCreateResponse::Data::LatestInvoice, Models::V1::ContractCreateResponse::Data::NextInvoice, Models::V1::ContractCreateResponse::Data::NextInvoice::Amount, Models::V1::ContractCreateResponse::Data::Subscription, Models::V1::ContractDeleteParams, Models::V1::ContractDeleteResponse, Models::V1::ContractDeleteResponse::Data, Models::V1::ContractDeleteResponse::Data::LatestInvoice, Models::V1::ContractDeleteResponse::Data::NextInvoice, Models::V1::ContractDeleteResponse::Data::NextInvoice::Amount, Models::V1::ContractDeleteResponse::Data::Subscription, Models::V1::ContractListParams, Models::V1::ContractListResponse, Models::V1::ContractListResponse::LatestInvoice, Models::V1::ContractListResponse::NextInvoice, Models::V1::ContractListResponse::NextInvoice::Amount, Models::V1::ContractListResponse::Subscription, Models::V1::ContractRetrieveParams, Models::V1::ContractRetrieveResponse, Models::V1::ContractRetrieveResponse::Data, Models::V1::ContractRetrieveResponse::Data::LatestInvoice, Models::V1::ContractRetrieveResponse::Data::NextInvoice, Models::V1::ContractRetrieveResponse::Data::NextInvoice::Amount, Models::V1::ContractRetrieveResponse::Data::Subscription, Models::V1::ContractUpdateParams, Models::V1::ContractUpdateResponse, Models::V1::ContractUpdateResponse::Data, Models::V1::ContractUpdateResponse::Data::LatestInvoice, Models::V1::ContractUpdateResponse::Data::NextInvoice, Models::V1::ContractUpdateResponse::Data::NextInvoice::Amount, Models::V1::ContractUpdateResponse::Data::Subscription, Models::V1::Coupon, Models::V1::Coupon::Data, Models::V1::Coupon::Data::AmountsOff, Models::V1::CouponArchiveCouponParams, Models::V1::CouponCreateParams, Models::V1::CouponCreateParams::AmountsOff, Models::V1::CouponListParams, Models::V1::CouponListParams::CreatedAt, Models::V1::CouponListResponse, Models::V1::CouponListResponse::AmountsOff, Models::V1::CouponRetrieveParams, Models::V1::CouponUpdateCouponParams, Models::V1::CreditGetAutoRechargeParams, Models::V1::CreditGetAutoRechargeResponse, Models::V1::CreditGetAutoRechargeResponse::Data, Models::V1::CreditGetUsageParams, Models::V1::CreditGetUsageResponse, Models::V1::CreditGetUsageResponse::Data, Models::V1::CreditGetUsageResponse::Data::Currency, Models::V1::CreditGetUsageResponse::Data::Pagination, Models::V1::CreditGetUsageResponse::Data::Series, Models::V1::CreditGetUsageResponse::Data::Series::Point, Models::V1::CreditGetUsageResponse::Data::Series::Tag, Models::V1::CreditListLedgerParams, Models::V1::CreditListLedgerResponse, Models::V1::Credits::ConsumptionConsumeAsyncParams, Models::V1::Credits::ConsumptionConsumeAsyncParams::Consumption, Models::V1::Credits::ConsumptionConsumeAsyncResponse, Models::V1::Credits::ConsumptionConsumeParams, Models::V1::Credits::ConsumptionConsumeResponse, Models::V1::Credits::ConsumptionConsumeResponse::Data, Models::V1::Credits::ConsumptionConsumeResponse::Data::Credit, Models::V1::Credits::CreditGrantResponse, Models::V1::Credits::CreditGrantResponse::Data, Models::V1::Credits::CreditGrantResponse::Data::Cost, Models::V1::Credits::CreditGrantResponse::Data::LatestInvoice, Models::V1::Credits::CreditGrantResponse::Data::SyncState, Models::V1::Credits::CustomCurrencyArchiveParams, Models::V1::Credits::CustomCurrencyCreateParams, Models::V1::Credits::CustomCurrencyCreateParams::Units, Models::V1::Credits::CustomCurrencyListAssociatedEntitiesParams, Models::V1::Credits::CustomCurrencyListAssociatedEntitiesResponse, Models::V1::Credits::CustomCurrencyListAssociatedEntitiesResponse::Data, Models::V1::Credits::CustomCurrencyListParams, Models::V1::Credits::CustomCurrencyListResponse, Models::V1::Credits::CustomCurrencyListResponse::Units, Models::V1::Credits::CustomCurrencyResponse, Models::V1::Credits::CustomCurrencyResponse::Data, Models::V1::Credits::CustomCurrencyResponse::Data::Units, Models::V1::Credits::CustomCurrencyUnarchiveParams, Models::V1::Credits::CustomCurrencyUpdateParams, Models::V1::Credits::CustomCurrencyUpdateParams::Units, Models::V1::Credits::GrantCreateParams, Models::V1::Credits::GrantCreateParams::BillingInformation, Models::V1::Credits::GrantCreateParams::BillingInformation::BillingAddress, Models::V1::Credits::GrantCreateParams::Cost, Models::V1::Credits::GrantListParams, Models::V1::Credits::GrantListParams::CreatedAt, Models::V1::Credits::GrantListResponse, Models::V1::Credits::GrantListResponse::Cost, Models::V1::Credits::GrantListResponse::LatestInvoice, Models::V1::Credits::GrantListResponse::SyncState, Models::V1::Credits::GrantVoidParams, Models::V1::CustomerArchiveParams, Models::V1::CustomerCheckEntitlementParams, Models::V1::CustomerCheckEntitlementResponse, Models::V1::CustomerCheckEntitlementResponse::Data::Credit, Models::V1::CustomerCheckEntitlementResponse::Data::Credit::Currency, Models::V1::CustomerCheckEntitlementResponse::Data::Feature, Models::V1::CustomerCheckEntitlementResponse::Data::Feature::Feature, Models::V1::CustomerImportParams, Models::V1::CustomerImportParams::Customer, Models::V1::CustomerImportResponse, Models::V1::CustomerImportResponse::Data, Models::V1::CustomerIntegrationResponse, Models::V1::CustomerIntegrationResponse::Data, Models::V1::CustomerIntegrationResponse::Data::SyncData::SyncRevisionBillingData, Models::V1::CustomerIntegrationResponse::Data::SyncData::SyncRevisionMarketplaceData, Models::V1::CustomerIntegrationResponse::Data::SyncData::SyncRevisionPriceBillingData, Models::V1::CustomerListContractsParams, Models::V1::CustomerListContractsResponse, Models::V1::CustomerListContractsResponse::Data, Models::V1::CustomerListContractsResponse::Data::LatestInvoice, Models::V1::CustomerListContractsResponse::Data::NextInvoice, Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount, Models::V1::CustomerListContractsResponse::Data::Subscription, Models::V1::CustomerListInvoicesParams, Models::V1::CustomerListInvoicesResponse, Models::V1::CustomerListInvoicesResponse::LineItem, Models::V1::CustomerListParams, Models::V1::CustomerListParams::CreatedAt, Models::V1::CustomerListResourcesParams, Models::V1::CustomerListResourcesResponse, Models::V1::CustomerListResponse, Models::V1::CustomerListResponse::DefaultPaymentMethod, Models::V1::CustomerListResponse::Integration, Models::V1::CustomerListResponse::Passthrough, Models::V1::CustomerListResponse::Passthrough::Stripe, Models::V1::CustomerListResponse::Passthrough::Stripe::BillingAddress, Models::V1::CustomerListResponse::Passthrough::Stripe::ShippingAddress, Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID, Models::V1::CustomerListResponse::Passthrough::Zuora, Models::V1::CustomerListResponse::Passthrough::Zuora::BillingAddress, Models::V1::CustomerProvisionParams, Models::V1::CustomerProvisionParams::DefaultPaymentMethod, Models::V1::CustomerProvisionParams::Integration, Models::V1::CustomerProvisionParams::Passthrough, Models::V1::CustomerProvisionParams::Passthrough::Stripe, Models::V1::CustomerProvisionParams::Passthrough::Stripe::BillingAddress, Models::V1::CustomerProvisionParams::Passthrough::Stripe::ShippingAddress, Models::V1::CustomerProvisionParams::Passthrough::Stripe::TaxID, Models::V1::CustomerProvisionParams::Passthrough::Zuora, Models::V1::CustomerProvisionParams::Passthrough::Zuora::BillingAddress, Models::V1::CustomerResponse, Models::V1::CustomerResponse::Data, Models::V1::CustomerResponse::Data::DefaultPaymentMethod, Models::V1::CustomerResponse::Data::Integration, Models::V1::CustomerResponse::Data::Passthrough, Models::V1::CustomerResponse::Data::Passthrough::Stripe, Models::V1::CustomerResponse::Data::Passthrough::Stripe::BillingAddress, Models::V1::CustomerResponse::Data::Passthrough::Stripe::ShippingAddress, Models::V1::CustomerResponse::Data::Passthrough::Stripe::TaxID, Models::V1::CustomerResponse::Data::Passthrough::Zuora, Models::V1::CustomerResponse::Data::Passthrough::Zuora::BillingAddress, Models::V1::CustomerRetrieveEntitlementsParams, Models::V1::CustomerRetrieveEntitlementsResponse, Models::V1::CustomerRetrieveEntitlementsResponse::Data, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit::Currency, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::Feature, Models::V1::CustomerRetrieveParams, Models::V1::CustomerUnarchiveParams, Models::V1::CustomerUpdateParams, Models::V1::CustomerUpdateParams::Integration, Models::V1::CustomerUpdateParams::Passthrough, Models::V1::CustomerUpdateParams::Passthrough::Stripe, Models::V1::CustomerUpdateParams::Passthrough::Stripe::BillingAddress, Models::V1::CustomerUpdateParams::Passthrough::Stripe::ShippingAddress, Models::V1::CustomerUpdateParams::Passthrough::Stripe::TaxID, Models::V1::CustomerUpdateParams::Passthrough::Zuora, Models::V1::CustomerUpdateParams::Passthrough::Zuora::BillingAddress, Models::V1::Customers::IntegrationLinkParams, Models::V1::Customers::IntegrationListParams, Models::V1::Customers::IntegrationListResponse, Models::V1::Customers::IntegrationListResponse::SyncData::SyncRevisionBillingData, Models::V1::Customers::IntegrationListResponse::SyncData::SyncRevisionMarketplaceData, Models::V1::Customers::IntegrationListResponse::SyncData::SyncRevisionPriceBillingData, Models::V1::Customers::IntegrationRetrieveParams, Models::V1::Customers::IntegrationUnlinkParams, Models::V1::Customers::IntegrationUpdateParams, Models::V1::Customers::PaymentMethodAttachParams, Models::V1::Customers::PaymentMethodDetachParams, Models::V1::Customers::PromotionalEntitlementCreateParams, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration, Models::V1::Customers::PromotionalEntitlementCreateResponse, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementListParams, Models::V1::Customers::PromotionalEntitlementListParams::CreatedAt, Models::V1::Customers::PromotionalEntitlementListResponse, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementRevokeParams, Models::V1::Customers::PromotionalEntitlementRevokeResponse, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::EventEstimateParams, Models::V1::EventEstimateResponse, Models::V1::EventEstimateResponse::Data, Models::V1::EventEstimateResponse::Data::Estimate, Models::V1::EventEstimateResponse::Data::Estimate::Breakdown, Models::V1::EventReportParams, Models::V1::EventReportParams::Event, Models::V1::EventReportResponse, Models::V1::Events::Beta::CustomerRetrieveGovernanceParams, Models::V1::Events::Beta::CustomerRetrieveGovernanceResponse, Models::V1::Events::Beta::CustomerRetrieveGovernanceResponse::Data, Models::V1::Events::Beta::CustomerRetrieveGovernanceResponse::Pagination, Models::V1::Events::DataExport::DestinationCreateParams, Models::V1::Events::DataExport::DestinationCreateResponse, Models::V1::Events::DataExport::DestinationCreateResponse::Data, Models::V1::Events::DataExport::DestinationCreateResponse::Data::Destination, Models::V1::Events::DataExport::DestinationCreateResponse::Data::Destination::LastSyncStatus, Models::V1::Events::DataExport::DestinationDeleteParams, Models::V1::Events::DataExport::DestinationDeleteResponse, Models::V1::Events::DataExport::DestinationDeleteResponse::Data, Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination, Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus, Models::V1::Events::DataExport::DestinationUpdateSelectionParams, Models::V1::Events::DataExport::DestinationUpdateSelectionResponse, Models::V1::Events::DataExport::DestinationUpdateSelectionResponse::Data, Models::V1::Events::DataExport::DestinationUpdateSelectionResponse::Data::Destination, Models::V1::Events::DataExport::DestinationUpdateSelectionResponse::Data::Destination::LastSyncStatus, Models::V1::Events::DataExportListModelsParams, Models::V1::Events::DataExportListModelsResponse, Models::V1::Events::DataExportListModelsResponse::Data, Models::V1::Events::DataExportListModelsResponse::Data::Group, Models::V1::Events::DataExportListModelsResponse::Data::Group::Model, Models::V1::Events::DataExportMintScopedTokenParams, Models::V1::Events::DataExportMintScopedTokenResponse, Models::V1::Events::DataExportMintScopedTokenResponse::Data, Models::V1::Events::DataExportTriggerSyncParams, Models::V1::Events::DataExportTriggerSyncResponse, Models::V1::Events::DataExportTriggerSyncResponse::Data, Models::V1::Events::DataExportTriggerSyncResponse::Data::Result, Models::V1::Feature, Models::V1::Feature::Data, Models::V1::Feature::Data::EnumConfiguration, Models::V1::Feature::Data::UnitTransformation, Models::V1::FeatureArchiveFeatureParams, Models::V1::FeatureCreateFeatureParams, Models::V1::FeatureCreateFeatureParams::EnumConfiguration, Models::V1::FeatureCreateFeatureParams::UnitTransformation, Models::V1::FeatureListFeaturesParams, Models::V1::FeatureListFeaturesParams::CreatedAt, Models::V1::FeatureListFeaturesResponse, Models::V1::FeatureListFeaturesResponse::EnumConfiguration, Models::V1::FeatureListFeaturesResponse::UnitTransformation, Models::V1::FeatureRetrieveFeatureParams, Models::V1::FeatureUnarchiveFeatureParams, Models::V1::FeatureUpdateFeatureParams, Models::V1::FeatureUpdateFeatureParams::EnumConfiguration, Models::V1::FeatureUpdateFeatureParams::Meter, Models::V1::FeatureUpdateFeatureParams::Meter::Aggregation, Models::V1::FeatureUpdateFeatureParams::Meter::Filter, Models::V1::FeatureUpdateFeatureParams::Meter::Filter::Condition, Models::V1::FeatureUpdateFeatureParams::UnitTransformation, Models::V1::Plan, Models::V1::Plan::Data, Models::V1::Plan::Data::DefaultTrialConfig, Models::V1::Plan::Data::DefaultTrialConfig::Budget, Models::V1::Plan::Data::Entitlement, Models::V1::PlanArchiveParams, Models::V1::PlanCreateDraftParams, Models::V1::PlanCreateParams, Models::V1::PlanCreateParams::DefaultTrialConfig, Models::V1::PlanCreateParams::DefaultTrialConfig::Budget, Models::V1::PlanListChargesParams, Models::V1::PlanListChargesResponse, Models::V1::PlanListChargesResponse::CreditRate, Models::V1::PlanListChargesResponse::Price, Models::V1::PlanListChargesResponse::Tier, Models::V1::PlanListChargesResponse::Tier::FlatPrice, Models::V1::PlanListChargesResponse::Tier::UnitPrice, Models::V1::PlanListOverageChargesParams, Models::V1::PlanListOverageChargesResponse, Models::V1::PlanListOverageChargesResponse::CreditRate, Models::V1::PlanListOverageChargesResponse::Price, Models::V1::PlanListOverageChargesResponse::Tier, Models::V1::PlanListOverageChargesResponse::Tier::FlatPrice, Models::V1::PlanListOverageChargesResponse::Tier::UnitPrice, Models::V1::PlanListParams, Models::V1::PlanListParams::CreatedAt, Models::V1::PlanListResponse, Models::V1::PlanListResponse::DefaultTrialConfig, Models::V1::PlanListResponse::DefaultTrialConfig::Budget, Models::V1::PlanListResponse::Entitlement, Models::V1::PlanPublishParams, Models::V1::PlanPublishResponse, Models::V1::PlanPublishResponse::Data, Models::V1::PlanRemoveDraftParams, Models::V1::PlanRemoveDraftResponse, Models::V1::PlanRemoveDraftResponse::Data, Models::V1::PlanRetrieveParams, Models::V1::PlanUpdateParams, Models::V1::PlanUpdateParams::Charges, Models::V1::PlanUpdateParams::Charges::MinimumSpend, Models::V1::PlanUpdateParams::Charges::MinimumSpend::Minimum, Models::V1::PlanUpdateParams::Charges::OveragePricingModel, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::MonthlyResetPeriodConfiguration, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::WeeklyResetPeriodConfiguration, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::YearlyResetPeriodConfiguration, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::CreditRate, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Price, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::FlatPrice, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::UnitPrice, Models::V1::PlanUpdateParams::Charges::PricingModel, Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::CreditRate, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Price, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Tier, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Tier::FlatPrice, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Tier::UnitPrice, Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration, Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration, Models::V1::PlanUpdateParams::DefaultTrialConfig, Models::V1::PlanUpdateParams::DefaultTrialConfig::Budget, Models::V1::Plans::EntitlementCreateParams, Models::V1::Plans::EntitlementCreateParams::Entitlement::Credit, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::YearlyResetPeriodConfiguration, Models::V1::Plans::EntitlementCreateResponse, Models::V1::Plans::EntitlementCreateResponse::Data::Credit, Models::V1::Plans::EntitlementCreateResponse::Data::Feature, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Plans::EntitlementDeleteParams, Models::V1::Plans::EntitlementListParams, Models::V1::Plans::EntitlementListResponse, Models::V1::Plans::EntitlementListResponse::Data::Credit, Models::V1::Plans::EntitlementListResponse::Data::Feature, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Plans::EntitlementListResponse::Pagination, Models::V1::Plans::EntitlementUpdateParams, Models::V1::Plans::EntitlementUpdateParams::Body::Credit, Models::V1::Plans::EntitlementUpdateParams::Body::Feature, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::MonthlyResetPeriodConfiguration, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::WeeklyResetPeriodConfiguration, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::YearlyResetPeriodConfiguration, Models::V1::Plans::PlanEntitlement, Models::V1::Plans::PlanEntitlement::Data::Credit, Models::V1::Plans::PlanEntitlement::Data::Feature, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, Models::V1::Product, Models::V1::Product::Data, Models::V1::Product::Data::ProductSettings, Models::V1::ProductArchiveProductParams, Models::V1::ProductCreateProductParams, Models::V1::ProductDuplicateProductParams, Models::V1::ProductListProductsParams, Models::V1::ProductListProductsParams::CreatedAt, Models::V1::ProductListProductsResponse, Models::V1::ProductListProductsResponse::ProductSettings, Models::V1::ProductUnarchiveProductParams, Models::V1::ProductUpdateProductParams, Models::V1::ProductUpdateProductParams::ProductSettings, Models::V1::ProductUpdateProductParams::UsageResetCutoffRule, Models::V1::Subscription, Models::V1::Subscription::Data, Models::V1::Subscription::Data::Addon, Models::V1::Subscription::Data::Budget, Models::V1::Subscription::Data::Coupon, Models::V1::Subscription::Data::Coupon::AmountsOff, Models::V1::Subscription::Data::FutureUpdate, Models::V1::Subscription::Data::FutureUpdate::TargetPackage, Models::V1::Subscription::Data::LatestInvoice, Models::V1::Subscription::Data::MinimumSpend, Models::V1::Subscription::Data::Price, Models::V1::Subscription::Data::Price::Tier, Models::V1::Subscription::Data::Price::Tier::FlatPrice, Models::V1::Subscription::Data::Price::Tier::UnitPrice, Models::V1::Subscription::Data::SubscriptionEntitlement, Models::V1::Subscription::Data::Trial, Models::V1::SubscriptionCancelParams, Models::V1::SubscriptionDelegateParams, Models::V1::SubscriptionImportParams, Models::V1::SubscriptionImportParams::Subscription, Models::V1::SubscriptionImportParams::Subscription::Addon, Models::V1::SubscriptionImportParams::Subscription::Charge, Models::V1::SubscriptionImportResponse, Models::V1::SubscriptionImportResponse::Data, Models::V1::SubscriptionListParams, Models::V1::SubscriptionListParams::CreatedAt, Models::V1::SubscriptionListResponse, Models::V1::SubscriptionListResponse::Addon, Models::V1::SubscriptionListResponse::Budget, Models::V1::SubscriptionListResponse::Coupon, Models::V1::SubscriptionListResponse::Coupon::AmountsOff, Models::V1::SubscriptionListResponse::FutureUpdate, Models::V1::SubscriptionListResponse::FutureUpdate::TargetPackage, Models::V1::SubscriptionListResponse::LatestInvoice, Models::V1::SubscriptionListResponse::MinimumSpend, Models::V1::SubscriptionListResponse::Price, Models::V1::SubscriptionListResponse::Price::Tier, Models::V1::SubscriptionListResponse::Price::Tier::FlatPrice, Models::V1::SubscriptionListResponse::Price::Tier::UnitPrice, Models::V1::SubscriptionListResponse::SubscriptionEntitlement, Models::V1::SubscriptionListResponse::Trial, Models::V1::SubscriptionMigrateParams, Models::V1::SubscriptionPreviewParams, Models::V1::SubscriptionPreviewParams::Addon, Models::V1::SubscriptionPreviewParams::AppliedCoupon, Models::V1::SubscriptionPreviewParams::AppliedCoupon::Configuration, Models::V1::SubscriptionPreviewParams::AppliedCoupon::Discount, Models::V1::SubscriptionPreviewParams::AppliedCoupon::Discount::AmountsOff, Models::V1::SubscriptionPreviewParams::BillableFeature, Models::V1::SubscriptionPreviewParams::BillingInformation, Models::V1::SubscriptionPreviewParams::BillingInformation::BillingAddress, Models::V1::SubscriptionPreviewParams::BillingInformation::TaxID, Models::V1::SubscriptionPreviewParams::Charge, Models::V1::SubscriptionPreviewParams::TrialOverrideConfiguration, Models::V1::SubscriptionPreviewResponse, Models::V1::SubscriptionPreviewResponse::Data, Models::V1::SubscriptionPreviewResponse::Data::BillingPeriodRange, Models::V1::SubscriptionPreviewResponse::Data::FreeItem, Models::V1::SubscriptionPreviewResponse::Data::ImmediateInvoice, Models::V1::SubscriptionPreviewResponse::Data::ImmediateInvoice::BillingPeriodRange, Models::V1::SubscriptionPreviewResponse::Data::ImmediateInvoice::Discount, Models::V1::SubscriptionPreviewResponse::Data::ImmediateInvoice::DiscountDetails, Models::V1::SubscriptionPreviewResponse::Data::ImmediateInvoice::Line, Models::V1::SubscriptionPreviewResponse::Data::RecurringInvoice, Models::V1::SubscriptionPreviewResponse::Data::RecurringInvoice::BillingPeriodRange, Models::V1::SubscriptionPreviewResponse::Data::RecurringInvoice::Discount, Models::V1::SubscriptionPreviewResponse::Data::RecurringInvoice::DiscountDetails, Models::V1::SubscriptionPreviewResponse::Data::RecurringInvoice::Line, Models::V1::SubscriptionProvisionParams, Models::V1::SubscriptionProvisionParams::Addon, Models::V1::SubscriptionProvisionParams::AppliedCoupon, Models::V1::SubscriptionProvisionParams::AppliedCoupon::Configuration, Models::V1::SubscriptionProvisionParams::AppliedCoupon::Discount, Models::V1::SubscriptionProvisionParams::AppliedCoupon::Discount::AmountsOff, Models::V1::SubscriptionProvisionParams::BillingInformation, Models::V1::SubscriptionProvisionParams::BillingInformation::BillingAddress, Models::V1::SubscriptionProvisionParams::BillingInformation::TaxID, Models::V1::SubscriptionProvisionParams::Budget, Models::V1::SubscriptionProvisionParams::Charge, Models::V1::SubscriptionProvisionParams::CheckoutOptions, Models::V1::SubscriptionProvisionParams::Entitlement::Credit, Models::V1::SubscriptionProvisionParams::Entitlement::Feature, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::MonthlyResetPeriodConfiguration, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::WeeklyResetPeriodConfiguration, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::YearlyResetPeriodConfiguration, Models::V1::SubscriptionProvisionParams::MinimumSpend, Models::V1::SubscriptionProvisionParams::PriceOverride, Models::V1::SubscriptionProvisionParams::PriceOverride::CreditRate, Models::V1::SubscriptionProvisionParams::PriceOverride::Tier, Models::V1::SubscriptionProvisionParams::PriceOverride::Tier::FlatPrice, Models::V1::SubscriptionProvisionParams::PriceOverride::Tier::UnitPrice, Models::V1::SubscriptionProvisionParams::TrialOverrideConfiguration, Models::V1::SubscriptionProvisionResponse, Models::V1::SubscriptionProvisionResponse::Data, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant1, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant1::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Addon, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Budget, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Coupon, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Coupon::AmountsOff, Models::V1::SubscriptionProvisionResponse::Data::Subscription::FutureUpdate, Models::V1::SubscriptionProvisionResponse::Data::Subscription::FutureUpdate::TargetPackage, Models::V1::SubscriptionProvisionResponse::Data::Subscription::LatestInvoice, Models::V1::SubscriptionProvisionResponse::Data::Subscription::MinimumSpend, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Tier, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Tier::FlatPrice, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Tier::UnitPrice, Models::V1::SubscriptionProvisionResponse::Data::Subscription::SubscriptionEntitlement, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Trial, Models::V1::SubscriptionRetrieveParams, Models::V1::SubscriptionTransferParams, Models::V1::SubscriptionUpdateParams, Models::V1::SubscriptionUpdateParams::Addon, Models::V1::SubscriptionUpdateParams::AppliedCoupon, Models::V1::SubscriptionUpdateParams::AppliedCoupon::Configuration, Models::V1::SubscriptionUpdateParams::AppliedCoupon::Discount, Models::V1::SubscriptionUpdateParams::AppliedCoupon::Discount::AmountsOff, Models::V1::SubscriptionUpdateParams::BillingInformation, Models::V1::SubscriptionUpdateParams::BillingInformation::BillingAddress, Models::V1::SubscriptionUpdateParams::BillingInformation::TaxID, Models::V1::SubscriptionUpdateParams::Budget, Models::V1::SubscriptionUpdateParams::Charge, Models::V1::SubscriptionUpdateParams::Entitlement::Credit, Models::V1::SubscriptionUpdateParams::Entitlement::Feature, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::YearlyResetPeriodConfiguration, Models::V1::SubscriptionUpdateParams::MinimumSpend, Models::V1::SubscriptionUpdateParams::PriceOverride, Models::V1::Subscriptions::CancelSubscription, Models::V1::Subscriptions::CancelSubscription::Data, Models::V1::Subscriptions::FutureUpdateCancelPendingPaymentParams, Models::V1::Subscriptions::FutureUpdateCancelScheduleParams, Models::V1::Subscriptions::InvoiceMarkAsPaidParams, Models::V1::Subscriptions::InvoiceMarkAsPaidResponse, Models::V1::Subscriptions::InvoiceMarkAsPaidResponse::Data, Models::V1::Subscriptions::UsageChargeUsageParams, Models::V1::Subscriptions::UsageChargeUsageResponse, Models::V1::Subscriptions::UsageChargeUsageResponse::Data, Models::V1::Subscriptions::UsageChargeUsageResponse::Data::UsageCharged, Models::V1::Subscriptions::UsageSyncParams, Models::V1::Subscriptions::UsageSyncResponse, Models::V1::Subscriptions::UsageSyncResponse::Data, Models::V1::UsageEstimateParams, Models::V1::UsageEstimateResponse, Models::V1::UsageEstimateResponse::Data, Models::V1::UsageEstimateResponse::Data::Estimate, Models::V1::UsageEstimateResponse::Data::Estimate::Breakdown, Models::V1::UsageHistoryParams, Models::V1::UsageHistoryResponse, Models::V1::UsageHistoryResponse::Data, Models::V1::UsageHistoryResponse::Data::Marker, Models::V1::UsageHistoryResponse::Data::Series, Models::V1::UsageHistoryResponse::Data::Series::Point, Models::V1::UsageHistoryResponse::Data::Series::Tag, Models::V1::UsageReportParams, Models::V1::UsageReportParams::Usage, Models::V1::UsageReportResponse, Models::V1::UsageReportResponse::Data, Models::V1::UsageReportResponse::Data::Credit, Models::V1Beta::Customers::AssignmentListParams, Models::V1Beta::Customers::AssignmentListResponse, Models::V1Beta::Customers::AssignmentUpsertParams, Models::V1Beta::Customers::AssignmentUpsertParams::Assignment, Models::V1Beta::Customers::AssignmentUpsertResponse, Models::V1Beta::Customers::AssignmentUpsertResponse::Data, Models::V1Beta::Customers::EntitlementCheckParams, Models::V1Beta::Customers::EntitlementCheckResponse, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Credit, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Credit::Chain, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Credit::Currency, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Chain, Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Feature, Models::V1Beta::Customers::EntityArchiveParams, Models::V1Beta::Customers::EntityArchiveResponse, Models::V1Beta::Customers::EntityArchiveResponse::Data, Models::V1Beta::Customers::EntityListParams, Models::V1Beta::Customers::EntityListResponse, Models::V1Beta::Customers::EntityRetrieveParams, Models::V1Beta::Customers::EntityRetrieveResponse, Models::V1Beta::Customers::EntityRetrieveResponse::Data, Models::V1Beta::Customers::EntityUnarchiveParams, Models::V1Beta::Customers::EntityUnarchiveResponse, Models::V1Beta::Customers::EntityUnarchiveResponse::Data, Models::V1Beta::Customers::EntityUpsertParams, Models::V1Beta::Customers::EntityUpsertParams::Entity, Models::V1Beta::Customers::EntityUpsertResponse, Models::V1Beta::Customers::EntityUpsertResponse::Data, Models::V1Beta::EntityTypeListParams, Models::V1Beta::EntityTypeListResponse, Models::V1Beta::EntityTypeUpsertParams, Models::V1Beta::EntityTypeUpsertParams::Type, Models::V1Beta::EntityTypeUpsertResponse, Models::V1Beta::EntityTypeUpsertResponse::Data, RequestOptions
Class Method Summary collapse
- .==(other) ⇒ Boolean
- .coerce(value, state:) ⇒ self, Object private
- .dump(value, state:) ⇒ Hash{Object=>Object}, Object private
- .fields ⇒ Hash{Symbol=>Hash{Symbol=>Object}} private
- .hash ⇒ Integer
-
.inherited(child) ⇒ void
private
Assumes superclass fields are totally defined before fields are accessed / defined on subclasses.
- .inspect(depth: 0) ⇒ String private
- .known_fields ⇒ Hash{Symbol=>Hash{Symbol=>Object}} private
- .optional(name_sym, type_info, spec = {}) ⇒ Object private
- .recursively_to_h(model, convert:) ⇒ Hash{Symbol=>Object} private
- .required(name_sym, type_info, spec = {}) ⇒ Object private
- .to_sorbet_type ⇒ Object private
Instance Method Summary collapse
- #==(other) ⇒ Boolean
-
#[](key) ⇒ Object?
Returns the raw value associated with the given key, if found.
- #deconstruct_keys(keys) ⇒ Hash{Symbol=>Object}
-
#deep_to_h ⇒ Hash{Symbol=>Object}
In addition to the behaviour of
#to_h, this method will recursively call#to_hon nested models. - #hash ⇒ Integer
-
#initialize(data = {}) ⇒ BaseModel
constructor
Create a new instance of a model.
- #inspect ⇒ String private
-
#to_h ⇒ Hash{Symbol=>Object}
(also: #to_hash)
Returns a Hash of the data underlying this object.
- #to_json(*a) ⇒ String
- #to_s ⇒ String
- #to_yaml(*a) ⇒ String
Methods included from Converter
coerce, dump, meta_info, new_coerce_state, type_info
Methods included from Util::SorbetRuntimeSupport
const_missing, define_sorbet_constant!, sorbet_constant_defined?, to_sorbet_type
Constructor Details
#initialize(data = {}) ⇒ BaseModel
Create a new instance of a model.
474 475 476 477 478 479 480 481 482 483 484 485 |
# File 'lib/stigg/internal/type/base_model.rb', line 474 def initialize(data = {}) @data = {} @coerced = {} Stigg::Internal::Util.coerce_hash!(data).each do if self.class.known_fields.key?(_1) public_send(:"#{_1}=", _2) else @data.store(_1, _2) @coerced.store(_1, false) end end end |
Class Method Details
.==(other) ⇒ Boolean
207 208 209 |
# File 'lib/stigg/internal/type/base_model.rb', line 207 def ==(other) other.is_a?(Class) && other <= Stigg::Internal::Type::BaseModel && other.fields == fields end |
.coerce(value, state:) ⇒ self, Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/stigg/internal/type/base_model.rb', line 247 def coerce(value, state:) exactness = state.fetch(:exactness) if value.is_a?(self) exactness[:yes] += 1 return value end unless (val = Stigg::Internal::Util.coerce_hash(value)).is_a?(Hash) exactness[:no] += 1 state[:error] = TypeError.new("#{value.class} can't be coerced into #{Hash}") return value end exactness[:yes] += 1 keys = val.keys.to_set instance = new data = instance.to_h status = instance.instance_variable_get(:@coerced) # rubocop:disable Metrics/BlockLength fields.each do |name, field| mode, required, target = field.fetch_values(:mode, :required, :type) api_name, nilable, const = field.fetch_values(:api_name, :nilable, :const) src_name = state.fetch(:translate_names) ? api_name : name unless val.key?(src_name) if required && mode != :dump && const == Stigg::Internal::OMIT exactness[nilable ? :maybe : :no] += 1 else exactness[:yes] += 1 end next end item = val.fetch(src_name) keys.delete(src_name) state[:error] = nil converted = if item.nil? && (nilable || !required) exactness[nilable ? :yes : :maybe] += 1 nil else coerced = Stigg::Internal::Type::Converter.coerce(target, item, state: state) case target in Stigg::Internal::Type::Converter | Symbol coerced else item end end status.store(name, state.fetch(:error) || true) data.store(name, converted) end # rubocop:enable Metrics/BlockLength keys.each { data.store(_1, val.fetch(_1)) } instance end |
.dump(value, state:) ⇒ Hash{Object=>Object}, Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/stigg/internal/type/base_model.rb', line 318 def dump(value, state:) unless (coerced = Stigg::Internal::Util.coerce_hash(value)).is_a?(Hash) return super end acc = {} coerced.each do |key, val| name = key.is_a?(String) ? key.to_sym : key case (field = known_fields[name]) in nil acc.store(name, super(val, state: state)) else api_name, mode, type_fn = field.fetch_values(:api_name, :mode, :type_fn) case mode in :coerce next else target = type_fn.call acc.store(api_name, Stigg::Internal::Type::Converter.dump(target, val, state: state)) end end end known_fields.each_value do |field| api_name, mode, const = field.fetch_values(:api_name, :mode, :const) next if mode == :coerce || acc.key?(api_name) || const == Stigg::Internal::OMIT acc.store(api_name, const) end acc end |
.fields ⇒ Hash{Symbol=>Hash{Symbol=>Object}}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
31 32 33 34 35 |
# File 'lib/stigg/internal/type/base_model.rb', line 31 def fields known_fields.transform_values do |field| {**field.except(:type_fn), type: field.fetch(:type_fn).call} end end |
.hash ⇒ Integer
214 |
# File 'lib/stigg/internal/type/base_model.rb', line 214 def hash = fields.hash |
.inherited(child) ⇒ void
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
This method returns an undefined value.
Assumes superclass fields are totally defined before fields are accessed / defined on subclasses.
18 19 20 21 |
# File 'lib/stigg/internal/type/base_model.rb', line 18 def inherited(child) super child.known_fields.replace(known_fields.dup) end |
.inspect(depth: 0) ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/stigg/internal/type/base_model.rb', line 493 def inspect(depth: 0) return super() if depth.positive? depth = depth.succ deferred = fields.transform_values do |field| type, required, nilable = field.fetch_values(:type, :required, :nilable) inspected = [ Stigg::Internal::Type::Converter.inspect(type, depth: depth), !required || nilable ? "nil" : nil ].compact.join(" | ") -> { inspected }.tap { _1.define_singleton_method(:inspect) { call } } end "#{name}[#{deferred.inspect}]" end |
.known_fields ⇒ Hash{Symbol=>Hash{Symbol=>Object}}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
26 |
# File 'lib/stigg/internal/type/base_model.rb', line 26 def known_fields = @known_fields ||= {} |
.optional(name_sym, type_info, spec = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
173 174 175 |
# File 'lib/stigg/internal/type/base_model.rb', line 173 def optional(name_sym, type_info, spec = {}) add_field(name_sym, required: false, type_info: type_info, spec: spec) end |
.recursively_to_h(model, convert:) ⇒ Hash{Symbol=>Object}
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/stigg/internal/type/base_model.rb', line 366 def recursively_to_h(model, convert:) rec = ->(x) do case x in Stigg::Internal::Type::BaseModel if convert fields = x.class.known_fields x.to_h.to_h do |key, val| [key, rec.call(fields.key?(key) ? x.public_send(key) : val)] rescue Stigg::Errors::ConversionError [key, rec.call(val)] end else rec.call(x.to_h) end in Hash x.transform_values(&rec) in Array x.map(&rec) else x end end rec.call(model) end |
.required(name_sym, type_info, spec = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
154 155 156 |
# File 'lib/stigg/internal/type/base_model.rb', line 154 def required(name_sym, type_info, spec = {}) add_field(name_sym, required: true, type_info: type_info, spec: spec) end |
.to_sorbet_type ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
354 355 356 |
# File 'lib/stigg/internal/type/base_model.rb', line 354 def to_sorbet_type self end |
Instance Method Details
#==(other) ⇒ Boolean
222 |
# File 'lib/stigg/internal/type/base_model.rb', line 222 def ==(other) = self.class == other.class && @data == other.to_h |
#[](key) ⇒ Object?
Returns the raw value associated with the given key, if found. Otherwise, nil is returned.
It is valid to lookup keys that are not in the API spec, for example to access undocumented features. This method does not parse response data into higher-level types. Lookup by anything other than a Symbol is an ArgumentError.
404 405 406 407 408 409 410 |
# File 'lib/stigg/internal/type/base_model.rb', line 404 def [](key) unless key.instance_of?(Symbol) raise ArgumentError.new("Expected symbol key for lookup, got #{key.inspect}") end @data[key] end |
#deconstruct_keys(keys) ⇒ Hash{Symbol=>Object}
445 446 447 448 449 450 451 452 453 454 455 |
# File 'lib/stigg/internal/type/base_model.rb', line 445 def deconstruct_keys(keys) (keys || self.class.known_fields.keys) .filter_map do |k| unless self.class.known_fields.key?(k) next end [k, public_send(k)] end .to_h end |
#deep_to_h ⇒ Hash{Symbol=>Object}
In addition to the behaviour of #to_h, this method will recursively call
#to_h on nested models.
434 |
# File 'lib/stigg/internal/type/base_model.rb', line 434 def deep_to_h = self.class.recursively_to_h(@data, convert: false) |
#hash ⇒ Integer
227 |
# File 'lib/stigg/internal/type/base_model.rb', line 227 def hash = [self.class, @data].hash |
#inspect ⇒ String
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
518 519 520 521 |
# File 'lib/stigg/internal/type/base_model.rb', line 518 def inspect converted = self.class.recursively_to_h(self, convert: true) "#<#{self.class}:0x#{object_id.to_s(16)} #{converted}>" end |
#to_h ⇒ Hash{Symbol=>Object} Also known as: to_hash
Returns a Hash of the data underlying this object. O(1)
Keys are Symbols and values are the raw values from the response. The return value indicates which values were ever set on the object. i.e. there will be a key in this hash if they ever were, even if the set value was nil.
This method is not recursive. The returned value is shared by the object, so it should not be mutated.
424 |
# File 'lib/stigg/internal/type/base_model.rb', line 424 def to_h = @data |
#to_json(*a) ⇒ String
462 |
# File 'lib/stigg/internal/type/base_model.rb', line 462 def to_json(*a) = Stigg::Internal::Type::Converter.dump(self.class, self).to_json(*a) |
#to_s ⇒ String
513 |
# File 'lib/stigg/internal/type/base_model.rb', line 513 def to_s = deep_to_h.to_s |
#to_yaml(*a) ⇒ String
469 |
# File 'lib/stigg/internal/type/base_model.rb', line 469 def to_yaml(*a) = Stigg::Internal::Type::Converter.dump(self.class, self).to_yaml(*a) |