Module: Stigg::Internal::Type::Enum Private

Includes:
Converter, Util::SorbetRuntimeSupport
Included in:
Models::Internal::Beta::EventQueueListResponse::Data::Region, Models::Internal::Beta::EventQueueListResponse::Data::Status, Models::Internal::Beta::EventQueueProvisionParams::EventType, Models::Internal::Beta::EventQueueProvisionParams::Region, Models::Internal::Beta::EventQueueResponse::Data::Region, Models::Internal::Beta::EventQueueResponse::Data::Status, Models::Internal::Beta::EventQueueUpdateParams::EventType, Models::V1::Addon::Data::Entitlement::Type, Models::V1::Addon::Data::PricingType, Models::V1::Addon::Data::Status, Models::V1::AddonCreateParams::PricingType, Models::V1::AddonCreateParams::Status, Models::V1::AddonListResponse::Entitlement::Type, Models::V1::AddonListResponse::PricingType, Models::V1::AddonListResponse::Status, Models::V1::AddonPublishParams::MigrationType, Models::V1::AddonUpdateParams::Charges::MinimumSpend::BillingPeriod, Models::V1::AddonUpdateParams::Charges::MinimumSpend::Minimum::Currency, Models::V1::AddonUpdateParams::Charges::OverageBillingPeriod, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::BillingCadence, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::BillingModel, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::ResetPeriod, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::BillingPeriod, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::CreditGrantCadence, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Price::Currency, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::FlatPrice::Currency, Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::UnitPrice::Currency, Models::V1::AddonUpdateParams::Charges::PricingModel::BillingCadence, Models::V1::AddonUpdateParams::Charges::PricingModel::BillingModel, Models::V1::AddonUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::BillingPeriod, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::CreditGrantCadence, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Price::Currency, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Tier::FlatPrice::Currency, Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod::Tier::UnitPrice::Currency, Models::V1::AddonUpdateParams::Charges::PricingModel::ResetPeriod, Models::V1::AddonUpdateParams::Charges::PricingModel::TiersMode, Models::V1::AddonUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::AddonUpdateParams::Charges::PricingType, Models::V1::AddonUpdateParams::Status, Models::V1::Addons::AddonPackageEntitlement::Data::Credit::Behavior, Models::V1::Addons::AddonPackageEntitlement::Data::Credit::Cadence, Models::V1::Addons::AddonPackageEntitlement::Data::Credit::HiddenFromWidget, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::Behavior, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::HiddenFromWidget, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriod, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Addons::AddonPackageEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementCreateParams::Entitlement::Credit::Behavior, Models::V1::Addons::EntitlementCreateParams::Entitlement::Credit::Cadence, Models::V1::Addons::EntitlementCreateParams::Entitlement::Credit::HiddenFromWidget, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::Behavior, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::HiddenFromWidget, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::ResetPeriod, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::Addons::EntitlementCreateParams::Entitlement::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::Addons::EntitlementCreateResponse::Data::Credit::Behavior, Models::V1::Addons::EntitlementCreateResponse::Data::Credit::Cadence, Models::V1::Addons::EntitlementCreateResponse::Data::Credit::HiddenFromWidget, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::Behavior, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::HiddenFromWidget, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriod, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementListResponse::Data::Credit::Behavior, Models::V1::Addons::EntitlementListResponse::Data::Credit::Cadence, Models::V1::Addons::EntitlementListResponse::Data::Credit::HiddenFromWidget, Models::V1::Addons::EntitlementListResponse::Data::Feature::Behavior, Models::V1::Addons::EntitlementListResponse::Data::Feature::HiddenFromWidget, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriod, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Addons::EntitlementUpdateParams::Body::Credit::Behavior, Models::V1::Addons::EntitlementUpdateParams::Body::Credit::Cadence, Models::V1::Addons::EntitlementUpdateParams::Body::Credit::HiddenFromWidget, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::Behavior, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::HiddenFromWidget, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::ResetPeriod, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::Addons::EntitlementUpdateParams::Body::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::Coupon::Data::AmountsOff::Currency, Models::V1::Coupon::Data::Source, Models::V1::Coupon::Data::Status, Models::V1::Coupon::Data::Type, Models::V1::CouponCreateParams::AmountsOff::Currency, Models::V1::CouponListParams::Type, Models::V1::CouponListResponse::AmountsOff::Currency, Models::V1::CouponListResponse::Source, Models::V1::CouponListResponse::Status, Models::V1::CouponListResponse::Type, Models::V1::CustomerIntegrationResponse::Data::VendorIdentifier, Models::V1::CustomerListResponse::BillingCurrency, Models::V1::CustomerListResponse::DefaultPaymentMethod::Type, Models::V1::CustomerListResponse::Integration::VendorIdentifier, Models::V1::CustomerListResponse::Passthrough::Zuora::Currency, Models::V1::CustomerProvisionParams::BillingCurrency, Models::V1::CustomerProvisionParams::DefaultPaymentMethod::Type, Models::V1::CustomerProvisionParams::Integration::VendorIdentifier, Models::V1::CustomerProvisionParams::Passthrough::Zuora::Currency, Models::V1::CustomerResponse::Data::BillingCurrency, Models::V1::CustomerResponse::Data::DefaultPaymentMethod::Type, Models::V1::CustomerResponse::Data::Integration::VendorIdentifier, Models::V1::CustomerResponse::Data::Passthrough::Zuora::Currency, Models::V1::CustomerRetrieveEntitlementsResponse::Data::AccessDeniedReason, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit::AccessDeniedReason, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::AccessDeniedReason, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::Feature::FeatureStatus, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::Feature::FeatureType, Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::ResetPeriod, Models::V1::CustomerUpdateParams::BillingCurrency, Models::V1::CustomerUpdateParams::Integration::VendorIdentifier, Models::V1::CustomerUpdateParams::Passthrough::Zuora::Currency, Models::V1::Customers::IntegrationLinkParams::VendorIdentifier, Models::V1::Customers::IntegrationListResponse::VendorIdentifier, Models::V1::Customers::PaymentMethodAttachParams::BillingCurrency, Models::V1::Customers::PaymentMethodAttachParams::VendorIdentifier, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::ResetPeriod, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::Period, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriod, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementCreateResponse::Data::Status, Models::V1::Customers::PromotionalEntitlementListResponse::Period, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriod, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementListResponse::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementListResponse::Status, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::Period, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriod, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Customers::PromotionalEntitlementRevokeResponse::Data::Status, Models::V1::Events::CreditGetAutoRechargeResponse::Data::GrantExpirationPeriod, Models::V1::Events::CreditGetAutoRechargeResponse::Data::ThresholdType, Models::V1::Events::CreditGetUsageParams::TimeRange, Models::V1::Events::CreditListLedgerResponse::EventType, Models::V1::Events::Credits::CreditGrantResponse::Data::GrantType, Models::V1::Events::Credits::CreditGrantResponse::Data::LatestInvoice::BillingReason, Models::V1::Events::Credits::CreditGrantResponse::Data::LatestInvoice::Status, Models::V1::Events::Credits::CreditGrantResponse::Data::PaymentCollection, Models::V1::Events::Credits::CreditGrantResponse::Data::SourceType, Models::V1::Events::Credits::CreditGrantResponse::Data::Status, Models::V1::Events::Credits::GrantCreateParams::Cost::Currency, Models::V1::Events::Credits::GrantCreateParams::GrantType, Models::V1::Events::Credits::GrantCreateParams::PaymentCollectionMethod, Models::V1::Events::Credits::GrantListResponse::GrantType, Models::V1::Events::Credits::GrantListResponse::LatestInvoice::BillingReason, Models::V1::Events::Credits::GrantListResponse::LatestInvoice::Status, Models::V1::Events::Credits::GrantListResponse::PaymentCollection, Models::V1::Events::Credits::GrantListResponse::SourceType, Models::V1::Events::Credits::GrantListResponse::Status, Models::V1::Feature::Data::FeatureStatus, Models::V1::Feature::Data::FeatureType, Models::V1::Feature::Data::MeterType, Models::V1::Feature::Data::UnitTransformation::Round, Models::V1::FeatureCreateFeatureParams::FeatureStatus, Models::V1::FeatureCreateFeatureParams::FeatureType, Models::V1::FeatureCreateFeatureParams::MeterType, Models::V1::FeatureCreateFeatureParams::UnitTransformation::Round, Models::V1::FeatureListFeaturesResponse::FeatureStatus, Models::V1::FeatureListFeaturesResponse::FeatureType, Models::V1::FeatureListFeaturesResponse::MeterType, Models::V1::FeatureListFeaturesResponse::UnitTransformation::Round, Models::V1::FeatureUpdateFeatureParams::Meter::Aggregation::Function, Models::V1::FeatureUpdateFeatureParams::Meter::Filter::Condition::Operation, Models::V1::FeatureUpdateFeatureParams::UnitTransformation::Round, Models::V1::Plan::Data::DefaultTrialConfig::TrialEndBehavior, Models::V1::Plan::Data::DefaultTrialConfig::Units, Models::V1::Plan::Data::Entitlement::Type, Models::V1::Plan::Data::PricingType, Models::V1::Plan::Data::Status, Models::V1::PlanCreateParams::DefaultTrialConfig::TrialEndBehavior, Models::V1::PlanCreateParams::DefaultTrialConfig::Units, Models::V1::PlanCreateParams::PricingType, Models::V1::PlanCreateParams::Status, Models::V1::PlanListResponse::DefaultTrialConfig::TrialEndBehavior, Models::V1::PlanListResponse::DefaultTrialConfig::Units, Models::V1::PlanListResponse::Entitlement::Type, Models::V1::PlanListResponse::PricingType, Models::V1::PlanListResponse::Status, Models::V1::PlanPublishParams::MigrationType, Models::V1::PlanUpdateParams::Charges::MinimumSpend::BillingPeriod, Models::V1::PlanUpdateParams::Charges::MinimumSpend::Minimum::Currency, Models::V1::PlanUpdateParams::Charges::OverageBillingPeriod, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::BillingCadence, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::BillingModel, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::ResetPeriod, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::BillingPeriod, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::CreditGrantCadence, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Price::Currency, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::FlatPrice::Currency, Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod::Tier::UnitPrice::Currency, Models::V1::PlanUpdateParams::Charges::PricingModel::BillingCadence, Models::V1::PlanUpdateParams::Charges::PricingModel::BillingModel, Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::BillingPeriod, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::CreditGrantCadence, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Price::Currency, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Tier::FlatPrice::Currency, Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod::Tier::UnitPrice::Currency, Models::V1::PlanUpdateParams::Charges::PricingModel::ResetPeriod, Models::V1::PlanUpdateParams::Charges::PricingModel::TiersMode, Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::PlanUpdateParams::Charges::PricingType, Models::V1::PlanUpdateParams::DefaultTrialConfig::TrialEndBehavior, Models::V1::PlanUpdateParams::DefaultTrialConfig::Units, Models::V1::Plans::EntitlementCreateParams::Entitlement::Credit::Behavior, Models::V1::Plans::EntitlementCreateParams::Entitlement::Credit::Cadence, Models::V1::Plans::EntitlementCreateParams::Entitlement::Credit::HiddenFromWidget, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::Behavior, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::HiddenFromWidget, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::ResetPeriod, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::EntitlementCreateParams::Entitlement::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::EntitlementCreateResponse::Data::Credit::Behavior, Models::V1::Plans::EntitlementCreateResponse::Data::Credit::Cadence, Models::V1::Plans::EntitlementCreateResponse::Data::Credit::HiddenFromWidget, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::Behavior, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::HiddenFromWidget, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriod, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementCreateResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementListResponse::Data::Credit::Behavior, Models::V1::Plans::EntitlementListResponse::Data::Credit::Cadence, Models::V1::Plans::EntitlementListResponse::Data::Credit::HiddenFromWidget, Models::V1::Plans::EntitlementListResponse::Data::Feature::Behavior, Models::V1::Plans::EntitlementListResponse::Data::Feature::HiddenFromWidget, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriod, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementListResponse::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Plans::EntitlementUpdateParams::Body::Credit::Behavior, Models::V1::Plans::EntitlementUpdateParams::Body::Credit::Cadence, Models::V1::Plans::EntitlementUpdateParams::Body::Credit::HiddenFromWidget, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::Behavior, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::HiddenFromWidget, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::ResetPeriod, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::EntitlementUpdateParams::Body::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::Plans::PlanEntitlement::Data::Credit::Behavior, Models::V1::Plans::PlanEntitlement::Data::Credit::Cadence, Models::V1::Plans::PlanEntitlement::Data::Credit::HiddenFromWidget, Models::V1::Plans::PlanEntitlement::Data::Feature::Behavior, Models::V1::Plans::PlanEntitlement::Data::Feature::HiddenFromWidget, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriod, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::MonthlyResetPeriodConfig::AccordingTo, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::WeeklyResetPeriodConfig::AccordingTo, Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig::AccordingTo, Models::V1::Product::Data::ProductSettings::SubscriptionCancellationTime, Models::V1::Product::Data::ProductSettings::SubscriptionEndSetup, Models::V1::Product::Data::ProductSettings::SubscriptionStartSetup, Models::V1::Product::Data::Status, Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionCancellationTime, Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionEndSetup, Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionStartSetup, Models::V1::ProductListProductsResponse::Status, Models::V1::ProductUpdateProductParams::ProductSettings::SubscriptionCancellationTime, Models::V1::ProductUpdateProductParams::ProductSettings::SubscriptionEndSetup, Models::V1::ProductUpdateProductParams::ProductSettings::SubscriptionStartSetup, Models::V1::ProductUpdateProductParams::UsageResetCutoffRule::Behavior, Models::V1::Subscription::Data::CancelReason, Models::V1::Subscription::Data::Coupon::AmountsOff::Currency, Models::V1::Subscription::Data::Coupon::Status, Models::V1::Subscription::Data::FutureUpdate::ScheduleStatus, Models::V1::Subscription::Data::FutureUpdate::SubscriptionScheduleType, Models::V1::Subscription::Data::LatestInvoice::BillingReason, Models::V1::Subscription::Data::LatestInvoice::Status, Models::V1::Subscription::Data::MinimumSpend::Currency, Models::V1::Subscription::Data::PaymentCollection, Models::V1::Subscription::Data::PaymentCollectionMethod, Models::V1::Subscription::Data::Price::Currency, Models::V1::Subscription::Data::Price::Tier::FlatPrice::Currency, Models::V1::Subscription::Data::Price::Tier::UnitPrice::Currency, Models::V1::Subscription::Data::PricingType, Models::V1::Subscription::Data::Status, Models::V1::Subscription::Data::SubscriptionEntitlement::Type, Models::V1::Subscription::Data::Trial::TrialEndBehavior, Models::V1::SubscriptionCancelParams::CancellationAction, Models::V1::SubscriptionCancelParams::CancellationTime, Models::V1::SubscriptionImportParams::Subscription::BillingPeriod, Models::V1::SubscriptionImportParams::Subscription::Charge::Type, Models::V1::SubscriptionListResponse::CancelReason, Models::V1::SubscriptionListResponse::Coupon::AmountsOff::Currency, Models::V1::SubscriptionListResponse::Coupon::Status, Models::V1::SubscriptionListResponse::FutureUpdate::ScheduleStatus, Models::V1::SubscriptionListResponse::FutureUpdate::SubscriptionScheduleType, Models::V1::SubscriptionListResponse::LatestInvoice::BillingReason, Models::V1::SubscriptionListResponse::LatestInvoice::Status, Models::V1::SubscriptionListResponse::MinimumSpend::Currency, Models::V1::SubscriptionListResponse::PaymentCollection, Models::V1::SubscriptionListResponse::PaymentCollectionMethod, Models::V1::SubscriptionListResponse::Price::Currency, Models::V1::SubscriptionListResponse::Price::Tier::FlatPrice::Currency, Models::V1::SubscriptionListResponse::Price::Tier::UnitPrice::Currency, Models::V1::SubscriptionListResponse::PricingType, Models::V1::SubscriptionListResponse::Status, Models::V1::SubscriptionListResponse::SubscriptionEntitlement::Type, Models::V1::SubscriptionListResponse::Trial::TrialEndBehavior, Models::V1::SubscriptionMigrateParams::SubscriptionMigrationTime, Models::V1::SubscriptionPreviewParams::AppliedCoupon::Discount::AmountsOff::Currency, Models::V1::SubscriptionPreviewParams::BillingCycleAnchor, Models::V1::SubscriptionPreviewParams::BillingInformation::ProrationBehavior, Models::V1::SubscriptionPreviewParams::BillingPeriod, Models::V1::SubscriptionPreviewParams::Charge::Type, Models::V1::SubscriptionPreviewParams::ScheduleStrategy, Models::V1::SubscriptionPreviewParams::TrialOverrideConfiguration::TrialEndBehavior, Models::V1::SubscriptionProvisionParams::AppliedCoupon::Discount::AmountsOff::Currency, Models::V1::SubscriptionProvisionParams::BillingCycleAnchor, Models::V1::SubscriptionProvisionParams::BillingInformation::ProrationBehavior, Models::V1::SubscriptionProvisionParams::BillingPeriod, Models::V1::SubscriptionProvisionParams::Charge::Type, Models::V1::SubscriptionProvisionParams::Entitlement::Credit::Cadence, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::ResetPeriod, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionProvisionParams::Entitlement::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionProvisionParams::MinimumSpend::Currency, Models::V1::SubscriptionProvisionParams::PaymentCollectionMethod, Models::V1::SubscriptionProvisionParams::PriceOverride::CreditGrantCadence, Models::V1::SubscriptionProvisionParams::PriceOverride::Currency, Models::V1::SubscriptionProvisionParams::PriceOverride::Tier::FlatPrice::Currency, Models::V1::SubscriptionProvisionParams::PriceOverride::Tier::UnitPrice::Currency, Models::V1::SubscriptionProvisionParams::ScheduleStrategy, Models::V1::SubscriptionProvisionParams::TrialOverrideConfiguration::TrialEndBehavior, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::AccessDeniedReason, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature::FeatureStatus, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature::FeatureType, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::ResetPeriod, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Type, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant1::AccessDeniedReason, Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant1::Type, Models::V1::SubscriptionProvisionResponse::Data::Status, Models::V1::SubscriptionProvisionResponse::Data::Subscription::CancelReason, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Coupon::AmountsOff::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Coupon::Status, Models::V1::SubscriptionProvisionResponse::Data::Subscription::FutureUpdate::ScheduleStatus, Models::V1::SubscriptionProvisionResponse::Data::Subscription::FutureUpdate::SubscriptionScheduleType, Models::V1::SubscriptionProvisionResponse::Data::Subscription::LatestInvoice::BillingReason, Models::V1::SubscriptionProvisionResponse::Data::Subscription::LatestInvoice::Status, Models::V1::SubscriptionProvisionResponse::Data::Subscription::MinimumSpend::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription::PaymentCollection, Models::V1::SubscriptionProvisionResponse::Data::Subscription::PaymentCollectionMethod, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Tier::FlatPrice::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Price::Tier::UnitPrice::Currency, Models::V1::SubscriptionProvisionResponse::Data::Subscription::PricingType, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Status, Models::V1::SubscriptionProvisionResponse::Data::Subscription::SubscriptionEntitlement::Type, Models::V1::SubscriptionProvisionResponse::Data::Subscription::Trial::TrialEndBehavior, Models::V1::SubscriptionUpdateParams::AppliedCoupon::Discount::AmountsOff::Currency, Models::V1::SubscriptionUpdateParams::BillingCycleAnchor, Models::V1::SubscriptionUpdateParams::BillingInformation::ProrationBehavior, Models::V1::SubscriptionUpdateParams::BillingPeriod, Models::V1::SubscriptionUpdateParams::Charge::Type, Models::V1::SubscriptionUpdateParams::Entitlement::Credit::Cadence, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::MonthlyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::ResetPeriod, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::WeeklyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionUpdateParams::Entitlement::Feature::YearlyResetPeriodConfiguration::AccordingTo, Models::V1::SubscriptionUpdateParams::MinimumSpend::Currency, Models::V1::SubscriptionUpdateParams::PriceOverride::Currency, Models::V1::SubscriptionUpdateParams::ScheduleStrategy, Models::V1::UsageHistoryResponse::Data::Marker::Type, Models::V1::UsageReportParams::Usage::UpdateBehavior
Defined in:
lib/stigg/internal/type/enum.rb

Overview

This module is part of a private API. You should avoid using this module if possible, as it may be removed or be changed in the future.

A value from among a specified list of options. OpenAPI enum values map to Ruby values in the SDK as follows:

  1. boolean => true | false

  2. integer => Integer

  3. float => Float

  4. string => Symbol

We can therefore convert string values to Symbols, but can’t convert other values safely.

Instance Method Summary collapse

Methods included from Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, to_sorbet_type

Methods included from Converter

coerce, dump, inspect, meta_info, new_coerce_state, type_info

Instance Method Details

#==(other) ⇒ Boolean

Parameters:

  • other (Object)

Returns:



39
40
41
42
43
# File 'lib/stigg/internal/type/enum.rb', line 39

def ==(other)
  # rubocop:disable Style/CaseEquality
  Stigg::Internal::Type::Enum === other && other.values.to_set == values.to_set
  # rubocop:enable Style/CaseEquality
end

#===(other) ⇒ Boolean

Parameters:

  • other (Object)

Returns:



32
# File 'lib/stigg/internal/type/enum.rb', line 32

def ===(other) = values.include?(other)

#coerce(value, state:) ⇒ Symbol, Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Unlike with primitives, ‘Enum` additionally validates that the value is a member of the enum.

Parameters:

  • value (String, Symbol, Object)
  • state (Hash{Symbol=>Object})

    .

    @option state [Boolean] :translate_names

    @option state [Boolean] :strictness

    @option state [HashSymbol=>Object] :exactness

    @option state [Class<StandardError>] :error

    @option state [Integer] :branched

Returns:

  • (Symbol, Object)


70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/stigg/internal/type/enum.rb', line 70

def coerce(value, state:)
  exactness = state.fetch(:exactness)
  val = value.is_a?(String) ? value.to_sym : value

  if values.include?(val)
    exactness[:yes] += 1
    val
  elsif values.first&.class == val.class
    exactness[:maybe] += 1
    value
  else
    exactness[:no] += 1
    state[:error] = TypeError.new("#{value.class} can't be coerced into #{self}")
    value
  end
end

#dump(value, state:) ⇒ Symbol, Object

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • value (Symbol, Object)
  • state (Hash{Symbol=>Object})

    .

    @option state [Boolean] :can_retry

Returns:

  • (Symbol, Object)


# File 'lib/stigg/internal/type/enum.rb', line 87

#hashInteger

Returns:

  • (Integer)


48
# File 'lib/stigg/internal/type/enum.rb', line 48

def hash = values.to_set.hash

#inspect(depth: 0) ⇒ String

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Parameters:

  • depth (Integer) (defaults to: 0)

Returns:

  • (String)


118
119
120
121
122
123
124
125
126
127
# File 'lib/stigg/internal/type/enum.rb', line 118

def inspect(depth: 0)
  if depth.positive?
    return is_a?(Module) ? super() : self.class.name
  end

  members = values.map { Stigg::Internal::Type::Converter.inspect(_1, depth: depth.succ) }
  prefix = is_a?(Module) ? name : self.class.name

  "#{prefix}[#{members.join(' | ')}]"
end

#to_sorbet_typeObject

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns:

  • (Object)


101
102
103
104
105
106
107
108
109
110
111
# File 'lib/stigg/internal/type/enum.rb', line 101

def to_sorbet_type
  types = values.map { Stigg::Internal::Util::SorbetRuntimeSupport.to_sorbet_type(_1) }.uniq
  case types
  in []
    T.noreturn
  in [type]
    type
  else
    T.any(*types)
  end
end

#valuesArray<NilClass, Boolean, Integer, Float, Symbol>

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

All of the valid Symbol values for this enum.

Returns:

  • (Array<NilClass, Boolean, Integer, Float, Symbol>)


25
# File 'lib/stigg/internal/type/enum.rb', line 25

def values = constants.map { const_get(_1) }