Class: Stigg::Models::Internal::Beta::EventQueueListResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::Internal::Beta::EventQueueListResponse::Data
- Defined in:
- lib/stigg/models/internal/beta/event_queue_list_response.rb
Defined Under Namespace
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#queue_name ⇒ String
Unique queue identifier.
-
#queue_url ⇒ String?
SQS queue URL.
-
#region ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region
AWS region where the queue is deployed.
-
#role_arn ⇒ String?
IAM role ARN for queue access.
-
#status ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status
Current provisioning status.
-
#suffix ⇒ String?
Queue suffix for disambiguation.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(created_at:, queue_name:, region:, status:, updated_at:, queue_url: nil, role_arn: nil, suffix: nil) ⇒ Object
constructor
Event queue provisioning status and details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(created_at:, queue_name:, region:, status:, updated_at:, queue_url: nil, role_arn: nil, suffix: nil) ⇒ Object
Event queue provisioning status and details
28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 28 class Data < Stigg::Internal::Type::BaseModel # @!attribute created_at # Timestamp of when the record was created # # @return [Time] required :created_at, Time, api_name: :createdAt # @!attribute queue_name # Unique queue identifier # # @return [String] required :queue_name, String, api_name: :queueName # @!attribute region # AWS region where the queue is deployed # # @return [Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region] required :region, enum: -> { Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region } # @!attribute status # Current provisioning status # # @return [Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status] required :status, enum: -> { Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status } # @!attribute updated_at # Timestamp of when the record was last updated # # @return [Time] required :updated_at, Time, api_name: :updatedAt # @!attribute queue_url # SQS queue URL # # @return [String, nil] optional :queue_url, String, api_name: :queueUrl, nil?: true # @!attribute role_arn # IAM role ARN for queue access # # @return [String, nil] optional :role_arn, String, api_name: :roleArn, nil?: true # @!attribute suffix # Queue suffix for disambiguation # # @return [String, nil] optional :suffix, String, nil?: true # @!method initialize(created_at:, queue_name:, region:, status:, updated_at:, queue_url: nil, role_arn: nil, suffix: nil) # Event queue provisioning status and details # # @param created_at [Time] Timestamp of when the record was created # # @param queue_name [String] Unique queue identifier # # @param region [Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region] AWS region where the queue is deployed # # @param status [Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status] Current provisioning status # # @param updated_at [Time] Timestamp of when the record was last updated # # @param queue_url [String, nil] SQS queue URL # # @param role_arn [String, nil] IAM role ARN for queue access # # @param suffix [String, nil] Queue suffix for disambiguation # AWS region where the queue is deployed # # @see Stigg::Models::Internal::Beta::EventQueueListResponse::Data#region module Region extend Stigg::Internal::Type::Enum US_EAST_1 = :"us-east-1" US_EAST_2 = :"us-east-2" US_WEST_1 = :"us-west-1" US_WEST_2 = :"us-west-2" CA_CENTRAL_1 = :"ca-central-1" EU_WEST_1 = :"eu-west-1" EU_WEST_2 = :"eu-west-2" EU_WEST_3 = :"eu-west-3" EU_CENTRAL_1 = :"eu-central-1" EU_CENTRAL_2 = :"eu-central-2" EU_NORTH_1 = :"eu-north-1" EU_SOUTH_1 = :"eu-south-1" EU_SOUTH_2 = :"eu-south-2" AP_SOUTHEAST_1 = :"ap-southeast-1" AP_SOUTHEAST_2 = :"ap-southeast-2" AP_SOUTHEAST_3 = :"ap-southeast-3" AP_NORTHEAST_1 = :"ap-northeast-1" AP_NORTHEAST_2 = :"ap-northeast-2" AP_NORTHEAST_3 = :"ap-northeast-3" AP_SOUTH_1 = :"ap-south-1" AP_SOUTH_2 = :"ap-south-2" AP_EAST_1 = :"ap-east-1" SA_EAST_1 = :"sa-east-1" AF_SOUTH_1 = :"af-south-1" ME_SOUTH_1 = :"me-south-1" ME_CENTRAL_1 = :"me-central-1" IL_CENTRAL_1 = :"il-central-1" # @!method self.values # @return [Array<Symbol>] end # Current provisioning status # # @see Stigg::Models::Internal::Beta::EventQueueListResponse::Data#status module Status extend Stigg::Internal::Type::Enum PROVISIONING = :PROVISIONING ACTIVE = :ACTIVE FAILED = :FAILED DEPROVISIONING = :DEPROVISIONING # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the record was created
33 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 33 required :created_at, Time, api_name: :createdAt |
#queue_name ⇒ String
Unique queue identifier
39 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 39 required :queue_name, String, api_name: :queueName |
#queue_url ⇒ String?
SQS queue URL
63 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 63 optional :queue_url, String, api_name: :queueUrl, nil?: true |
#region ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region
AWS region where the queue is deployed
45 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 45 required :region, enum: -> { Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Region } |
#role_arn ⇒ String?
IAM role ARN for queue access
69 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 69 optional :role_arn, String, api_name: :roleArn, nil?: true |
#status ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status
Current provisioning status
51 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 51 required :status, enum: -> { Stigg::Models::Internal::Beta::EventQueueListResponse::Data::Status } |
#suffix ⇒ String?
Queue suffix for disambiguation
75 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 75 optional :suffix, String, nil?: true |
#updated_at ⇒ Time
Timestamp of when the record was last updated
57 |
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 57 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/internal/beta/event_queue_list_response.rb', line 130
|