Class: Stigg::Models::V1::AddonCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/addon_create_params.rb

Overview

Defined Under Namespace

Modules: PricingType, Status

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, display_name:, product_id:, billing_id: nil, description: nil, max_quantity: nil, metadata: nil, pricing_type: nil, status: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)

    The unique identifier for the entity

  • display_name (String)

    The display name of the package

  • product_id (String)

    The product id of the package

  • billing_id (String, nil) (defaults to: nil)

    The unique identifier for the entity in the billing provider

  • description (String, nil) (defaults to: nil)

    The description of the package

  • max_quantity (Integer, nil) (defaults to: nil)

    The maximum quantity of this addon that can be added to a subscription

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Metadata associated with the entity

  • pricing_type (Symbol, Stigg::Models::V1::AddonCreateParams::PricingType, nil) (defaults to: nil)

    The pricing type of the package

  • status (Symbol, Stigg::Models::V1::AddonCreateParams::Status) (defaults to: nil)

    The status of the package

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/addon_create_params.rb', line 68

Instance Attribute Details

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


33
# File 'lib/stigg/models/v1/addon_create_params.rb', line 33

optional :billing_id, String, api_name: :billingId, nil?: true

#descriptionString?

The description of the package

Returns:

  • (String, nil)


39
# File 'lib/stigg/models/v1/addon_create_params.rb', line 39

optional :description, String, nil?: true

#display_nameString

The display name of the package

Returns:

  • (String)


21
# File 'lib/stigg/models/v1/addon_create_params.rb', line 21

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the entity

Returns:

  • (String)


15
# File 'lib/stigg/models/v1/addon_create_params.rb', line 15

required :id, String

#max_quantityInteger?

The maximum quantity of this addon that can be added to a subscription

Returns:

  • (Integer, nil)


45
# File 'lib/stigg/models/v1/addon_create_params.rb', line 45

optional :max_quantity, Integer, api_name: :maxQuantity, nil?: true

#metadataHash{Symbol=>String}?

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String}, nil)


51
# File 'lib/stigg/models/v1/addon_create_params.rb', line 51

optional :metadata, Stigg::Internal::Type::HashOf[String]

#pricing_typeSymbol, ...

The pricing type of the package



57
58
59
60
# File 'lib/stigg/models/v1/addon_create_params.rb', line 57

optional :pricing_type,
enum: -> { Stigg::V1::AddonCreateParams::PricingType },
api_name: :pricingType,
nil?: true

#product_idString

The product id of the package

Returns:

  • (String)


27
# File 'lib/stigg/models/v1/addon_create_params.rb', line 27

required :product_id, String, api_name: :productId

#statusSymbol, ...

The status of the package



66
# File 'lib/stigg/models/v1/addon_create_params.rb', line 66

optional :status, enum: -> { Stigg::V1::AddonCreateParams::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/addon_create_params.rb', line 97