Class: Stigg::Models::V1::AddonListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/addon_list_response.rb

Overview

Defined Under Namespace

Modules: PricingType, Status Classes: Entitlement

Instance Attribute Summary collapse

Class Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Stigg::Internal::Type::BaseModel

Instance Attribute Details

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


18
# File 'lib/stigg/models/v1/addon_list_response.rb', line 18

required :billing_id, String, api_name: :billingId, nil?: true

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


24
# File 'lib/stigg/models/v1/addon_list_response.rb', line 24

required :created_at, Time, api_name: :createdAt

#dependenciesArray<String>?

List of addons the addon is dependant on

Returns:

  • (Array<String>, nil)


30
# File 'lib/stigg/models/v1/addon_list_response.rb', line 30

required :dependencies, Stigg::Internal::Type::ArrayOf[String], nil?: true

#descriptionString?

The description of the package

Returns:

  • (String, nil)


36
# File 'lib/stigg/models/v1/addon_list_response.rb', line 36

required :description, String, nil?: true

#display_nameString

The display name of the package

Returns:

  • (String)


42
# File 'lib/stigg/models/v1/addon_list_response.rb', line 42

required :display_name, String, api_name: :displayName

#entitlementsArray<Stigg::Models::V1::AddonListResponse::Entitlement>

List of entitlements of the package



48
49
# File 'lib/stigg/models/v1/addon_list_response.rb', line 48

required :entitlements,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::AddonListResponse::Entitlement] }

#idString

The unique identifier for the entity

Returns:

  • (String)


12
# File 'lib/stigg/models/v1/addon_list_response.rb', line 12

required :id, String

#is_latestBoolean?

Indicates if the package is the latest version

Returns:

  • (Boolean, nil)


55
# File 'lib/stigg/models/v1/addon_list_response.rb', line 55

required :is_latest, Stigg::Internal::Type::Boolean, api_name: :isLatest, nil?: true

#max_quantityInteger?

The maximum quantity of this addon that can be added to a subscription

Returns:

  • (Integer, nil)


61
# File 'lib/stigg/models/v1/addon_list_response.rb', line 61

required :max_quantity, Integer, api_name: :maxQuantity, nil?: true

#metadataHash{Symbol=>String}

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String})


67
# File 'lib/stigg/models/v1/addon_list_response.rb', line 67

required :metadata, Stigg::Internal::Type::HashOf[String]

#pricing_typeSymbol, ...

The pricing type of the package



73
74
75
76
# File 'lib/stigg/models/v1/addon_list_response.rb', line 73

required :pricing_type,
enum: -> { Stigg::Models::V1::AddonListResponse::PricingType },
api_name: :pricingType,
nil?: true

#product_idString

The product id of the package

Returns:

  • (String)


82
# File 'lib/stigg/models/v1/addon_list_response.rb', line 82

required :product_id, String, api_name: :productId

#statusSymbol, Stigg::Models::V1::AddonListResponse::Status

The status of the package



88
# File 'lib/stigg/models/v1/addon_list_response.rb', line 88

required :status, enum: -> { Stigg::Models::V1::AddonListResponse::Status }

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


94
# File 'lib/stigg/models/v1/addon_list_response.rb', line 94

required :updated_at, Time, api_name: :updatedAt

#version_numberInteger

The version number of the package

Returns:

  • (Integer)


100
# File 'lib/stigg/models/v1/addon_list_response.rb', line 100

required :version_number, Integer, api_name: :versionNumber

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/addon_list_response.rb', line 161