Class: Stigg::Models::V1::AddonUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/addon_update_params.rb

Overview

Defined Under Namespace

Modules: Status Classes: Charges

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

This class inherits a constructor from Stigg::Internal::Type::BaseModel

Instance Attribute Details

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


20
# File 'lib/stigg/models/v1/addon_update_params.rb', line 20

optional :billing_id, String, api_name: :billingId, nil?: true

#chargesStigg::Models::V1::AddonUpdateParams::Charges?

Pricing configuration to set on the addon draft



26
# File 'lib/stigg/models/v1/addon_update_params.rb', line 26

optional :charges, -> { Stigg::V1::AddonUpdateParams::Charges }

#dependenciesArray<String>?

List of addons the addon is dependant on

Returns:

  • (Array<String>, nil)


32
# File 'lib/stigg/models/v1/addon_update_params.rb', line 32

optional :dependencies, Stigg::Internal::Type::ArrayOf[String], nil?: true

#descriptionString?

The description of the package

Returns:

  • (String, nil)


38
# File 'lib/stigg/models/v1/addon_update_params.rb', line 38

optional :description, String, nil?: true

#display_nameString?

The display name of the package

Returns:

  • (String, nil)


44
# File 'lib/stigg/models/v1/addon_update_params.rb', line 44

optional :display_name, String, api_name: :displayName

#idString

Returns:

  • (String)


14
# File 'lib/stigg/models/v1/addon_update_params.rb', line 14

required :id, String

#max_quantityInteger?

The maximum quantity of this addon that can be added to a subscription

Returns:

  • (Integer, nil)


50
# File 'lib/stigg/models/v1/addon_update_params.rb', line 50

optional :max_quantity, Integer, api_name: :maxQuantity, nil?: true

#metadataHash{Symbol=>String}?

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String}, nil)


56
# File 'lib/stigg/models/v1/addon_update_params.rb', line 56

optional :metadata, Stigg::Internal::Type::HashOf[String]

#statusSymbol, ...

The status of the package



62
# File 'lib/stigg/models/v1/addon_update_params.rb', line 62

optional :status, enum: -> { Stigg::V1::AddonUpdateParams::Status }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/addon_update_params.rb', line 2159