Class: Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel
- Defined in:
- lib/stigg/models/v1/addon_update_params.rb,
sig/stigg/models/v1/addon_update_params.rbs
Defined Under Namespace
Classes: CreditEntitlement, Entitlement, PricePeriod
Instance Attribute Summary collapse
-
#credit_entitlement ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement?
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan.
-
#currency_id ⇒ String?
The refId of the custom currency this credit overage applies to.
-
#entitlement ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement?
Entitlement configuration for the overage feature.
-
#feature_id ⇒ String?
The feature ID for overage pricing.
-
#price_periods ⇒ Array<Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod>
Price periods for overage pricing.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
502 |
# File 'sig/stigg/models/v1/addon_update_params.rbs', line 502
def initialize: (
|
Instance Attribute Details
#credit_entitlement ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement?
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan
392 393 394 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 392 optional :credit_entitlement, -> { Stigg::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement }, api_name: :creditEntitlement |
#currency_id ⇒ String?
The refId of the custom currency this credit overage applies to
400 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 400 optional :currency_id, String, api_name: :currencyId |
#entitlement ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement?
Entitlement configuration for the overage feature
406 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 406 optional :entitlement, -> { Stigg::V1::AddonUpdateParams::Charges::OveragePricingModel::Entitlement } |
#feature_id ⇒ String?
The feature ID for overage pricing
412 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 412 optional :feature_id, String, api_name: :featureId |
#price_periods ⇒ Array<Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod>
Price periods for overage pricing
381 382 383 384 385 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 381 required :price_periods, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::AddonUpdateParams::Charges::OveragePricingModel::PricePeriod] }, api_name: :pricePeriods |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1041
|
Instance Method Details
#to_hash ⇒ {
510 |
# File 'sig/stigg/models/v1/addon_update_params.rbs', line 510
def to_hash: -> {
|