Class: Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement
- Defined in:
- lib/stigg/models/v1/addon_update_params.rb,
sig/stigg/models/v1/addon_update_params.rbs
Overview
Defined Under Namespace
Modules: Cadence
Instance Attribute Summary collapse
-
#amount ⇒ Float
The base credit balance granted per cadence.
-
#cadence ⇒ Symbol, Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement::Cadence
The credit grant cadence (MONTH or YEAR).
-
#custom_currency_id ⇒ String
The refId of the custom currency to grant.
Instance Method Summary collapse
-
#initialize(amount:, cadence:, custom_currency_id:) ⇒ Object
constructor
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, cadence:, custom_currency_id:) ⇒ Object
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan
|
|
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1118
|
Instance Attribute Details
#amount ⇒ Float
The base credit balance granted per cadence
1103 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1103 required :amount, Float |
#cadence ⇒ Symbol, Stigg::Models::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement::Cadence
The credit grant cadence (MONTH or YEAR)
1109 1110 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1109 required :cadence, enum: -> { Stigg::V1::AddonUpdateParams::Charges::OveragePricingModel::CreditEntitlement::Cadence } |
#custom_currency_id ⇒ String
The refId of the custom currency to grant
1116 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1116 required :custom_currency_id, String, api_name: :customCurrencyId |
Instance Method Details
#to_hash ⇒ {
1535 |
# File 'sig/stigg/models/v1/addon_update_params.rbs', line 1535
def to_hash: -> {
|