Class: Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel
- Defined in:
- lib/stigg/models/v1/addon_update_params.rb
Defined Under Namespace
Modules: BillingCadence, BillingModel, ResetPeriod, TiersMode Classes: MonthlyResetPeriodConfiguration, PricePeriod, WeeklyResetPeriodConfiguration, YearlyResetPeriodConfiguration
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF).
-
#billing_model ⇒ Symbol, Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED).
-
#feature_id ⇒ String?
The feature ID this pricing model is associated with.
-
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999).
-
#min_unit_quantity ⇒ Integer?
Minimum number of units.
-
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration.
-
#price_periods ⇒ Array<Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required).
-
#reset_period ⇒ Symbol, ...
The usage reset period.
-
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED).
-
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing.
-
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration.
-
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
constructor
A pricing model configuration with billing details and price periods.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
A pricing model configuration with billing details and price periods.
|
|
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1366
|
Instance Attribute Details
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF)
1292 1293 1294 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1292 optional :billing_cadence, enum: -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::BillingCadence }, api_name: :billingCadence |
#billing_model ⇒ Symbol, Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED)
1274 1275 1276 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1274 required :billing_model, enum: -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::BillingModel }, api_name: :billingModel |
#feature_id ⇒ String?
The feature ID this pricing model is associated with
1300 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1300 optional :feature_id, String, api_name: :featureId |
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999)
1306 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1306 optional :max_unit_quantity, Integer, api_name: :maxUnitQuantity |
#min_unit_quantity ⇒ Integer?
Minimum number of units
1312 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1312 optional :min_unit_quantity, Integer, api_name: :minUnitQuantity |
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration
1318 1319 1320 1321 1322 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1318 optional :monthly_reset_period_configuration, -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration }, api_name: :monthlyResetPeriodConfiguration |
#price_periods ⇒ Array<Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required)
1282 1283 1284 1285 1286 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1282 required :price_periods, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::AddonUpdateParams::Charges::PricingModel::PricePeriod] }, api_name: :pricePeriods |
#reset_period ⇒ Symbol, ...
The usage reset period
1328 1329 1330 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1328 optional :reset_period, enum: -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::ResetPeriod }, api_name: :resetPeriod |
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED)
1336 1337 1338 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1336 optional :tiers_mode, enum: -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::TiersMode }, api_name: :tiersMode |
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing
1344 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1344 optional :top_up_custom_currency_id, String, api_name: :topUpCustomCurrencyId |
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration
1350 1351 1352 1353 1354 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1350 optional :weekly_reset_period_configuration, -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration }, api_name: :weeklyResetPeriodConfiguration |
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::AddonUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration
1360 1361 1362 1363 1364 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1360 optional :yearly_reset_period_configuration, -> { Stigg::V1::AddonUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration }, api_name: :yearlyResetPeriodConfiguration |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/addon_update_params.rb', line 1405
|