Class: Stigg::Models::V1::ContractCreateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/contract_create_params.rb,
sig/stigg/models/v1/contract_create_params.rbs

Overview

See Also:

  • Stigg::Resources::V1::Contracts#create

Defined Under Namespace

Classes: Subscription

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initializeObject



50
# File 'sig/stigg/models/v1/contract_create_params.rbs', line 50

def initialize: (

Instance Attribute Details

#activation_end_dateTime?

Optional contract activation end date

Parameters:

  • (Time)

Returns:

  • (Time, nil)


30
# File 'lib/stigg/models/v1/contract_create_params.rb', line 30

optional :activation_end_date, Time, api_name: :activationEndDate

#activation_start_dateTime?

Optional contract activation start date

Parameters:

  • (Time)

Returns:

  • (Time, nil)


36
# File 'lib/stigg/models/v1/contract_create_params.rb', line 36

optional :activation_start_date, Time, api_name: :activationStartDate

#customer_idString

The customer ref ID the contract belongs to

Parameters:

  • value (String)

Returns:

  • (String)


15
# File 'lib/stigg/models/v1/contract_create_params.rb', line 15

required :customer_id, String, api_name: :customerId

#nameString?

Optional contract name

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


42
# File 'lib/stigg/models/v1/contract_create_params.rb', line 42

optional :name, String, nil?: true

#po_numberString?

Optional purchase-order number

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


48
# File 'lib/stigg/models/v1/contract_create_params.rb', line 48

optional :po_number, String, api_name: :poNumber, nil?: true

#setup_billingBoolean?

Whether to set up billing for the contract by creating a billing contract in the connected billing provider. When false, the contract only provisions access (grants entitlements) and no billing contract is created. Defaults to true.

Parameters:

  • (Boolean)

Returns:

  • (Boolean, nil)


56
# File 'lib/stigg/models/v1/contract_create_params.rb', line 56

optional :setup_billing, Stigg::Internal::Type::Boolean, api_name: :setupBilling

#subscriptionsArray<Stigg::Models::V1::ContractCreateParams::Subscription>

The subscriptions to attach to the contract (must be non-empty). Each entry is either a new subscription to create or a reference to an existing custom subscription.

Parameters:

  • value (::Array[Stigg::V1::ContractCreateParams::Subscription])

Returns:



23
24
# File 'lib/stigg/models/v1/contract_create_params.rb', line 23

required :subscriptions,
-> { Stigg::Internal::Type::ArrayOf[Stigg::V1::ContractCreateParams::Subscription] }

#x_account_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


61
# File 'lib/stigg/models/v1/contract_create_params.rb', line 61

optional :x_account_id, String

#x_environment_idString?

Parameters:

  • (String)

Returns:

  • (String, nil)


66
# File 'lib/stigg/models/v1/contract_create_params.rb', line 66

optional :x_environment_id, String

Instance Method Details

#to_hash{

Returns:

  • ({)


63
# File 'sig/stigg/models/v1/contract_create_params.rbs', line 63

def to_hash: -> {