Class: Stigg::Models::V1::ContractCreateResponse::Data::NextInvoice
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::ContractCreateResponse::Data::NextInvoice
- Defined in:
- lib/stigg/models/v1/contract_create_response.rb,
sig/stigg/models/v1/contract_create_response.rbs
Overview
Defined Under Namespace
Classes: Amount
Instance Attribute Summary collapse
-
#amount ⇒ Stigg::Models::V1::ContractCreateResponse::Data::NextInvoice::Amount
The total amount of the upcoming invoice.
-
#due_date ⇒ Time?
The date the upcoming invoice is due.
-
#period_end ⇒ Time?
The end of the billing period the upcoming invoice covers.
-
#period_start ⇒ Time?
The start of the billing period the upcoming invoice covers.
Instance Method Summary collapse
-
#initialize(amount:, due_date:, period_end:, period_start:) ⇒ Object
constructor
A preview of the contract's upcoming invoice, or null when none is available.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, due_date:, period_end:, period_start:) ⇒ Object
A preview of the contract's upcoming invoice, or null when none is available
|
|
# File 'lib/stigg/models/v1/contract_create_response.rb', line 298
|
Instance Attribute Details
#amount ⇒ Stigg::Models::V1::ContractCreateResponse::Data::NextInvoice::Amount
The total amount of the upcoming invoice
278 |
# File 'lib/stigg/models/v1/contract_create_response.rb', line 278 required :amount, -> { Stigg::Models::V1::ContractCreateResponse::Data::NextInvoice::Amount } |
#due_date ⇒ Time?
The date the upcoming invoice is due
284 |
# File 'lib/stigg/models/v1/contract_create_response.rb', line 284 required :due_date, Time, api_name: :dueDate, nil?: true |
#period_end ⇒ Time?
The end of the billing period the upcoming invoice covers
290 |
# File 'lib/stigg/models/v1/contract_create_response.rb', line 290 required :period_end, Time, api_name: :periodEnd, nil?: true |
#period_start ⇒ Time?
The start of the billing period the upcoming invoice covers
296 |
# File 'lib/stigg/models/v1/contract_create_response.rb', line 296 required :period_start, Time, api_name: :periodStart, nil?: true |
Instance Method Details
#to_hash ⇒ {
218 |
# File 'sig/stigg/models/v1/contract_create_response.rbs', line 218
def to_hash: -> {
|