Class: Stigg::Models::V1::ContractListResponse::NextInvoice

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/contract_list_response.rb,
sig/stigg/models/v1/contract_list_response.rbs

Overview

See Also:

  • Stigg::Models::V1::ContractListResponse#next_invoice

Defined Under Namespace

Classes: Amount

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, due_date:, period_end:, period_start:) ⇒ Object

A preview of the contract's upcoming invoice, or null when none is available

Parameters:

  • amount (Stigg::Models::V1::ContractListResponse::NextInvoice::Amount)

    The total amount of the upcoming invoice

  • due_date (Time, nil)

    The date the upcoming invoice is due

  • period_end (Time, nil)

    The end of the billing period the upcoming invoice covers

  • period_start (Time, nil)

    The start of the billing period the upcoming invoice covers



# File 'lib/stigg/models/v1/contract_list_response.rb', line 285

Instance Attribute Details

#amountStigg::Models::V1::ContractListResponse::NextInvoice::Amount

The total amount of the upcoming invoice



265
# File 'lib/stigg/models/v1/contract_list_response.rb', line 265

required :amount, -> { Stigg::Models::V1::ContractListResponse::NextInvoice::Amount }

#due_dateTime?

The date the upcoming invoice is due

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


271
# File 'lib/stigg/models/v1/contract_list_response.rb', line 271

required :due_date, Time, api_name: :dueDate, nil?: true

#period_endTime?

The end of the billing period the upcoming invoice covers

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


277
# File 'lib/stigg/models/v1/contract_list_response.rb', line 277

required :period_end, Time, api_name: :periodEnd, nil?: true

#period_startTime?

The start of the billing period the upcoming invoice covers

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


283
# File 'lib/stigg/models/v1/contract_list_response.rb', line 283

required :period_start, Time, api_name: :periodStart, nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


204
# File 'sig/stigg/models/v1/contract_list_response.rbs', line 204

def to_hash: -> {