Class: Stigg::Models::V1::ContractRetrieveResponse::Data::Subscription

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/contract_retrieve_response.rb,
sig/stigg/models/v1/contract_retrieve_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(plan_display_name:, product_display_name:, subscription_id:) ⇒ Object

A custom subscription attached to a contract.

Parameters:

  • plan_display_name (String, nil)

    Display name of the subscription plan

  • product_display_name (String, nil)

    Display name of the product the subscription plan belongs to

  • subscription_id (String)

    The subscription ref ID (use it to deep-link to the subscription)



# File 'lib/stigg/models/v1/contract_retrieve_response.rb', line 494

Instance Attribute Details

#plan_display_nameString?

Display name of the subscription plan

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


480
# File 'lib/stigg/models/v1/contract_retrieve_response.rb', line 480

required :plan_display_name, String, api_name: :planDisplayName, nil?: true

#product_display_nameString?

Display name of the product the subscription plan belongs to

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


486
# File 'lib/stigg/models/v1/contract_retrieve_response.rb', line 486

required :product_display_name, String, api_name: :productDisplayName, nil?: true

#subscription_idString

The subscription ref ID (use it to deep-link to the subscription)

Parameters:

  • value (String)

Returns:

  • (String)


492
# File 'lib/stigg/models/v1/contract_retrieve_response.rb', line 492

required :subscription_id, String, api_name: :subscriptionId

Instance Method Details

#to_hash{

Returns:

  • ({)


522
# File 'sig/stigg/models/v1/contract_retrieve_response.rbs', line 522

def to_hash: -> {