Class: Stigg::Models::V1::ContractUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::ContractUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/contract_update_params.rb,
sig/stigg/models/v1/contract_update_params.rbs
Overview
Instance Attribute Summary collapse
-
#activation_end_date ⇒ Time?
New activation end date.
-
#activation_start_date ⇒ Time?
New activation start date.
- #id ⇒ String
-
#name ⇒ String?
New contract name.
-
#po_number ⇒ String?
New purchase-order number.
-
#setup_billing ⇒ Boolean?
Enable billing on a provision-access-only contract by creating a billing contract in the connected billing provider.
-
#subscription_ids ⇒ Array<String>?
When provided, replaces the set of subscriptions linked to the contract (subscription ref IDs).
- #x_account_id ⇒ String?
- #x_environment_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, activation_end_date: nil, activation_start_date: nil, name: nil, po_number: nil, setup_billing: nil, subscription_ids: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see ContractUpdateParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, activation_end_date: nil, activation_start_date: nil, name: nil, po_number: nil, setup_billing: nil, subscription_ids: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::ContractUpdateParams for more details.
|
|
# File 'lib/stigg/models/v1/contract_update_params.rb', line 66
|
Instance Attribute Details
#activation_end_date ⇒ Time?
New activation end date
20 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 20 optional :activation_end_date, Time, api_name: :activationEndDate |
#activation_start_date ⇒ Time?
New activation start date
26 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 26 optional :activation_start_date, Time, api_name: :activationStartDate |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 14 required :id, String |
#name ⇒ String?
New contract name
32 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 32 optional :name, String, nil?: true |
#po_number ⇒ String?
New purchase-order number
38 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 38 optional :po_number, String, api_name: :poNumber, nil?: true |
#setup_billing ⇒ Boolean?
Enable billing on a provision-access-only contract by creating a billing contract in the connected billing provider. Only takes effect when true and the contract has no billing yet; omitting it leaves billing unchanged. Billing is never removed by an update.
47 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 47 optional :setup_billing, Stigg::Internal::Type::Boolean, api_name: :setupBilling |
#subscription_ids ⇒ Array<String>?
When provided, replaces the set of subscriptions linked to the contract (subscription ref IDs)
54 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 54 optional :subscription_ids, Stigg::Internal::Type::ArrayOf[String], api_name: :subscriptionIds |
#x_account_id ⇒ String?
59 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 59 optional :x_account_id, String |
#x_environment_id ⇒ String?
64 |
# File 'lib/stigg/models/v1/contract_update_params.rb', line 64 optional :x_environment_id, String |
Instance Method Details
#to_hash ⇒ {
65 |
# File 'sig/stigg/models/v1/contract_update_params.rbs', line 65
def to_hash: -> {
|