Class: Stigg::Models::V1::CouponListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CouponListResponse
- Defined in:
- lib/stigg/models/v1/coupon_list_response.rb
Overview
Defined Under Namespace
Modules: Source, Status, Type Classes: AmountsOff
Instance Attribute Summary collapse
-
#amounts_off ⇒ Array<Stigg::Models::V1::CouponListResponse::AmountsOff>?
Fixed amount discounts in different currencies.
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#billing_link_url ⇒ String?
The URL to the entity in the billing provider.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#description ⇒ String?
Description of the coupon.
-
#duration_in_months ⇒ Integer?
Duration of the coupon validity in months.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity.
-
#name ⇒ String
Name of the coupon.
-
#percent_off ⇒ Integer?
Percentage discount off the original price.
-
#source ⇒ Symbol, ...
The source of the coupon.
-
#status ⇒ Symbol, Stigg::Models::V1::CouponListResponse::Status
Current status of the coupon.
-
#type ⇒ Symbol, Stigg::Models::V1::CouponListResponse::Type
Type of the coupon (percentage or fixed amount).
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#amounts_off ⇒ Array<Stigg::Models::V1::CouponListResponse::AmountsOff>?
Fixed amount discounts in different currencies
18 19 20 21 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 18 required :amounts_off, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CouponListResponse::AmountsOff] }, api_name: :amountsOff, nil?: true |
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
27 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 27 required :billing_id, String, api_name: :billingId, nil?: true |
#billing_link_url ⇒ String?
The URL to the entity in the billing provider
33 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 33 required :billing_link_url, String, api_name: :billingLinkUrl, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
39 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 39 required :created_at, Time, api_name: :createdAt |
#description ⇒ String?
Description of the coupon
45 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 45 required :description, String, nil?: true |
#duration_in_months ⇒ Integer?
Duration of the coupon validity in months
51 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 51 required :duration_in_months, Integer, api_name: :durationInMonths, nil?: true |
#id ⇒ String
The unique identifier for the entity
12 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity
57 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 57 required :metadata, Stigg::Internal::Type::HashOf[String], nil?: true |
#name ⇒ String
Name of the coupon
63 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 63 required :name, String |
#percent_off ⇒ Integer?
Percentage discount off the original price
69 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 69 required :percent_off, Integer, api_name: :percentOff, nil?: true |
#source ⇒ Symbol, ...
The source of the coupon
75 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 75 required :source, enum: -> { Stigg::Models::V1::CouponListResponse::Source }, nil?: true |
#status ⇒ Symbol, Stigg::Models::V1::CouponListResponse::Status
Current status of the coupon
81 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 81 required :status, enum: -> { Stigg::Models::V1::CouponListResponse::Status } |
#type ⇒ Symbol, Stigg::Models::V1::CouponListResponse::Type
Type of the coupon (percentage or fixed amount)
87 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 87 required :type, enum: -> { Stigg::Models::V1::CouponListResponse::Type } |
#updated_at ⇒ Time
Timestamp of when the record was last updated
93 |
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 93 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/coupon_list_response.rb', line 269
|