Class: Stigg::Models::V1::CreditGetUsageResponse::Data::Pagination
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CreditGetUsageResponse::Data::Pagination
- Defined in:
- lib/stigg/models/v1/credit_get_usage_response.rb,
sig/stigg/models/v1/credit_get_usage_response.rbs
Overview
Instance Attribute Summary collapse
-
#next_ ⇒ String?
Cursor for fetching the next page of results, or null if no additional pages exist.
-
#prev ⇒ String?
Cursor for fetching the previous page of results, or null if at the beginning.
Instance Method Summary collapse
-
#initialize ⇒ Pagination
constructor
A new instance of Pagination.
- #to_hash ⇒ { next_: String?, prev: String? }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Pagination
Returns a new instance of Pagination.
88 |
# File 'sig/stigg/models/v1/credit_get_usage_response.rbs', line 88
def initialize: (next_: String?, prev: String?) -> void
|
Instance Attribute Details
#next_ ⇒ String?
Cursor for fetching the next page of results, or null if no additional pages exist
107 |
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 107 required :next_, String, api_name: :next, nil?: true |
#prev ⇒ String?
Cursor for fetching the previous page of results, or null if at the beginning
113 |
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 113 required :prev, String, nil?: true |
Instance Method Details
#to_hash ⇒ { next_: String?, prev: String? }
90 |
# File 'sig/stigg/models/v1/credit_get_usage_response.rbs', line 90
def to_hash: -> { next_: String?, prev: String? }
|