Module: Stigg::Models::V1::Credits::ConsumptionConsumeAsyncParams::Consumption::Dimension
- Extended by:
- Internal::Type::Union
- Defined in:
- lib/stigg/models/v1/credits/consumption_consume_async_params.rb,
sig/stigg/models/v1/credits/consumption_consume_async_params.rbs
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, currency_id:, customer_id:, idempotency_key:, created_at: nil, dimensions: nil, resource_id: nil) ⇒ Object
Request body for consuming credits directly from a wallet.
- #self?.variants ⇒ ::Array[Stigg::Models::V1::Credits::ConsumptionConsumeAsyncParams::Consumption::dimension]
Methods included from Internal::Type::Union
==, ===, coerce, derefed_variants, dump, hash, inspect, to_sorbet_type, variants
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Class Method Details
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/stigg/models/v1/credits/consumption_consume_async_params.rb', line 108
|
Instance Method Details
#initialize(amount:, currency_id:, customer_id:, idempotency_key:, created_at: nil, dimensions: nil, resource_id: nil) ⇒ Object
Request body for consuming credits directly from a wallet
99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/stigg/models/v1/credits/consumption_consume_async_params.rb', line 99 module Dimension extend Stigg::Internal::Type::Union variant String variant Float variant Stigg::Internal::Type::Boolean # @!method self.variants # @return [Array(String, Float, Boolean)] end |
#self?.variants ⇒ ::Array[Stigg::Models::V1::Credits::ConsumptionConsumeAsyncParams::Consumption::dimension]
100 |
# File 'sig/stigg/models/v1/credits/consumption_consume_async_params.rbs', line 100
def self?.variants: -> ::Array[Stigg::Models::V1::Credits::ConsumptionConsumeAsyncParams::Consumption::dimension]
|