Class: Stigg::Models::V1::Credits::ConsumptionConsumeAsyncResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/credits/consumption_consume_async_response.rb,
sig/stigg/models/v1/credits/consumption_consume_async_response.rbs

Overview

See Also:

  • Stigg::Resources::V1::Credits::Consumption#consume_async

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(data:) ⇒ ConsumptionConsumeAsyncResponse

Response object

Parameters:

  • data (Object)

    Confirmation that the credit consumptions were accepted for processing

  • data: (top)


# File 'lib/stigg/models/v1/credits/consumption_consume_async_response.rb', line 15

Instance Attribute Details

#dataObject

Confirmation that the credit consumptions were accepted for processing

Parameters:

  • value (top)

Returns:

  • (Object)


13
# File 'lib/stigg/models/v1/credits/consumption_consume_async_response.rb', line 13

required :data, Stigg::Internal::Type::Unknown

Instance Method Details

#to_hash{ data: top }

Returns:

  • ({ data: top })


12
# File 'sig/stigg/models/v1/credits/consumption_consume_async_response.rbs', line 12

def to_hash: -> { data: top }