Class: Stigg::Models::V1::Credits::CustomCurrencyListResponse

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/credits/custom_currency_list_response.rb

Overview

Defined Under Namespace

Classes: Units

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, created_at:, description:, display_name:, metadata:, symbol:, units:, updated_at:) ⇒ Object

A custom currency used to denominate credit-based entitlements and pricing

Parameters:

  • id (String)

    The unique identifier for the custom currency

  • archived_at (Time, nil)

    Timestamp of when the record was deleted

  • created_at (Time)

    Timestamp of when the record was created

  • description (String, nil)

    Description of the currency

  • display_name (String)

    The display name of the custom currency

  • metadata (Hash{Symbol=>String})

    Metadata associated with the entity

  • symbol (String, nil)

    The symbol used to represent the custom currency

  • units (Stigg::Models::V1::Credits::CustomCurrencyListResponse::Units, nil)

    Singular and plural unit labels for a custom currency

  • updated_at (Time)

    Timestamp of when the record was last updated



# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 63

Instance Attribute Details

#archived_atTime?

Timestamp of when the record was deleted

Returns:

  • (Time, nil)


19
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 19

required :archived_at, Time, api_name: :archivedAt, nil?: true

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


25
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 25

required :created_at, Time, api_name: :createdAt

#descriptionString?

Description of the currency

Returns:

  • (String, nil)


31
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 31

required :description, String, nil?: true

#display_nameString

The display name of the custom currency

Returns:

  • (String)


37
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 37

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the custom currency

Returns:

  • (String)


13
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 13

required :id, String

#metadataHash{Symbol=>String}

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String})


43
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 43

required :metadata, Stigg::Internal::Type::HashOf[String]

#symbolString?

The symbol used to represent the custom currency

Returns:

  • (String, nil)


49
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 49

required :symbol, String, nil?: true

#unitsStigg::Models::V1::Credits::CustomCurrencyListResponse::Units?

Singular and plural unit labels for a custom currency



55
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 55

required :units, -> { Stigg::Models::V1::Credits::CustomCurrencyListResponse::Units }, nil?: true

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


61
# File 'lib/stigg/models/v1/credits/custom_currency_list_response.rb', line 61

required :updated_at, Time, api_name: :updatedAt