Class: Stigg::Models::V1::CustomerImportParams::Customer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_import_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, email:, name:, billing_id: nil, metadata: nil, payment_method_id: nil, salesforce_id: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String)

    Customer slug

  • email (String, nil)

    The email of the customer

  • name (String, nil)

    The name of the customer

  • billing_id (String) (defaults to: nil)

    Id in the billing provider

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional metadata

  • payment_method_id (String) (defaults to: nil)

    Billing provider payment method id

  • salesforce_id (String) (defaults to: nil)

    The unique identifier for the customer in Salesforce integration

  • updated_at (Time) (defaults to: nil)

    Timestamp of when the record was last updated



44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/stigg/models/v1/customer_import_params.rb', line 44

class Customer < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   Customer slug
  #
  #   @return [String]
  required :id, String

  # @!attribute email
  #   The email of the customer
  #
  #   @return [String, nil]
  required :email, String, nil?: true

  # @!attribute name
  #   The name of the customer
  #
  #   @return [String, nil]
  required :name, String, nil?: true

  # @!attribute billing_id
  #   Id in the billing provider
  #
  #   @return [String, nil]
  optional :billing_id, String, api_name: :billingId

  # @!attribute metadata
  #   Additional metadata
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :metadata, Stigg::Internal::Type::HashOf[String]

  # @!attribute payment_method_id
  #   Billing provider payment method id
  #
  #   @return [String, nil]
  optional :payment_method_id, String, api_name: :paymentMethodId

  # @!attribute salesforce_id
  #   The unique identifier for the customer in Salesforce integration
  #
  #   @return [String, nil]
  optional :salesforce_id, String, api_name: :salesforceId

  # @!attribute updated_at
  #   Timestamp of when the record was last updated
  #
  #   @return [Time, nil]
  optional :updated_at, Time, api_name: :updatedAt

  # @!method initialize(id:, email:, name:, billing_id: nil, metadata: nil, payment_method_id: nil, salesforce_id: nil, updated_at: nil)
  #   @param id [String] Customer slug
  #
  #   @param email [String, nil] The email of the customer
  #
  #   @param name [String, nil] The name of the customer
  #
  #   @param billing_id [String] Id in the billing provider
  #
  #   @param metadata [Hash{Symbol=>String}] Additional metadata
  #
  #   @param payment_method_id [String] Billing provider payment method id
  #
  #   @param salesforce_id [String] The unique identifier for the customer in Salesforce integration
  #
  #   @param updated_at [Time] Timestamp of when the record was last updated
end

Instance Attribute Details

#billing_idString?

Id in the billing provider

Returns:

  • (String, nil)


67
# File 'lib/stigg/models/v1/customer_import_params.rb', line 67

optional :billing_id, String, api_name: :billingId

#emailString?

The email of the customer

Returns:

  • (String, nil)


55
# File 'lib/stigg/models/v1/customer_import_params.rb', line 55

required :email, String, nil?: true

#idString

Customer slug

Returns:

  • (String)


49
# File 'lib/stigg/models/v1/customer_import_params.rb', line 49

required :id, String

#metadataHash{Symbol=>String}?

Additional metadata

Returns:

  • (Hash{Symbol=>String}, nil)


73
# File 'lib/stigg/models/v1/customer_import_params.rb', line 73

optional :metadata, Stigg::Internal::Type::HashOf[String]

#nameString?

The name of the customer

Returns:

  • (String, nil)


61
# File 'lib/stigg/models/v1/customer_import_params.rb', line 61

required :name, String, nil?: true

#payment_method_idString?

Billing provider payment method id

Returns:

  • (String, nil)


79
# File 'lib/stigg/models/v1/customer_import_params.rb', line 79

optional :payment_method_id, String, api_name: :paymentMethodId

#salesforce_idString?

The unique identifier for the customer in Salesforce integration

Returns:

  • (String, nil)


85
# File 'lib/stigg/models/v1/customer_import_params.rb', line 85

optional :salesforce_id, String, api_name: :salesforceId

#updated_atTime?

Timestamp of when the record was last updated

Returns:

  • (Time, nil)


91
# File 'lib/stigg/models/v1/customer_import_params.rb', line 91

optional :updated_at, Time, api_name: :updatedAt