Class: Stigg::Models::V1::CustomerListContractsResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_list_contracts_response.rb,
sig/stigg/models/v1/customer_list_contracts_response.rbs

Defined Under Namespace

Modules: State Classes: LatestInvoice, NextInvoice, Subscription

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, activation_end_date:, activation_start_date:, billing_id:, contract_id:, created_at:, customer_external_id:, external_id:, latest_invoice:, name:, next_invoice:, po_number:, ref_id:, state:, subscriptions:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::CustomerListContractsResponse::Data for more details.

A billing contract as reported by the connected billing provider.

Parameters:

  • id (String, nil)

    The persisted Stigg contract id (matches a subscription’s contractId; present fo

  • activation_end_date (Time, nil)

    The date the contract activation ends

  • activation_start_date (Time, nil)

    The date the contract becomes active

  • billing_id (String, nil)

    The billing provider (Received) contract ID; null until the contract has synced

  • contract_id (String)

    The Stigg contract ref ID (the key used to fetch/update/delete this contract)

  • created_at (Time, nil)

    The date the contract was created

  • customer_external_id (String, nil)

    The external identifier of the customer the contract belongs to

  • external_id (String)

    The external identifier of the contract

  • latest_invoice (Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice, nil)

    The most recent non-draft invoice for this contract (open, paid, or canceled), o

  • name (String, nil)

    The contract name (the purchase-order number when set, otherwise the contract/cu

  • next_invoice (Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice, nil)

    A preview of the contract's upcoming invoice, or null when none is available

  • po_number (String, nil)

    Purchase-order number, when set on the contract

  • ref_id (String, nil)

    The Stigg contract ref ID (present for Stigg-managed contracts; the key used to

  • state (Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::State)

    The current state of the contract

  • subscriptions (Array<Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription>)

    The custom subscriptions attached to this contract (empty when none)



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 19

class Data < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   The persisted Stigg contract id (matches a subscription’s contractId; present
  #   for Stigg-managed contracts)
  #
  #   @return [String, nil]
  required :id, String, nil?: true

  # @!attribute activation_end_date
  #   The date the contract activation ends
  #
  #   @return [Time, nil]
  required :activation_end_date, Time, api_name: :activationEndDate, nil?: true

  # @!attribute activation_start_date
  #   The date the contract becomes active
  #
  #   @return [Time, nil]
  required :activation_start_date, Time, api_name: :activationStartDate, nil?: true

  # @!attribute billing_id
  #   The billing provider (Received) contract ID; null until the contract has synced
  #   to the billing provider
  #
  #   @return [String, nil]
  required :billing_id, String, api_name: :billingId, nil?: true

  # @!attribute contract_id
  #   The Stigg contract ref ID (the key used to fetch/update/delete this contract)
  #
  #   @return [String]
  required :contract_id, String, api_name: :contractId

  # @!attribute created_at
  #   The date the contract was created
  #
  #   @return [Time, nil]
  required :created_at, Time, api_name: :createdAt, nil?: true

  # @!attribute customer_external_id
  #   The external identifier of the customer the contract belongs to
  #
  #   @return [String, nil]
  required :customer_external_id, String, api_name: :customerExternalId, nil?: true

  # @!attribute external_id
  #   The external identifier of the contract
  #
  #   @return [String]
  required :external_id, String, api_name: :externalId

  # @!attribute latest_invoice
  #   The most recent non-draft invoice for this contract (open, paid, or canceled),
  #   or null when none exists
  #
  #   @return [Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice, nil]
  required :latest_invoice,
           -> { Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice },
           api_name: :latestInvoice,
           nil?: true

  # @!attribute name
  #   The contract name (the purchase-order number when set, otherwise the
  #   contract/customer name)
  #
  #   @return [String, nil]
  required :name, String, nil?: true

  # @!attribute next_invoice
  #   A preview of the contract's upcoming invoice, or null when none is available
  #
  #   @return [Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice, nil]
  required :next_invoice,
           -> { Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice },
           api_name: :nextInvoice,
           nil?: true

  # @!attribute po_number
  #   Purchase-order number, when set on the contract
  #
  #   @return [String, nil]
  required :po_number, String, api_name: :poNumber, nil?: true

  # @!attribute ref_id
  #   The Stigg contract ref ID (present for Stigg-managed contracts; the key used to
  #   update/delete)
  #
  #   @return [String, nil]
  required :ref_id, String, api_name: :refId, nil?: true

  # @!attribute state
  #   The current state of the contract
  #
  #   @return [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::State]
  required :state, enum: -> { Stigg::Models::V1::CustomerListContractsResponse::Data::State }

  # @!attribute subscriptions
  #   The custom subscriptions attached to this contract (empty when none)
  #
  #   @return [Array<Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription>]
  required :subscriptions,
           -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription] }

  # @!method initialize(id:, activation_end_date:, activation_start_date:, billing_id:, contract_id:, created_at:, customer_external_id:, external_id:, latest_invoice:, name:, next_invoice:, po_number:, ref_id:, state:, subscriptions:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1::CustomerListContractsResponse::Data} for more details.
  #
  #   A billing contract as reported by the connected billing provider.
  #
  #   @param id [String, nil] The persisted Stigg contract id (matches a subscription’s contractId; present fo
  #
  #   @param activation_end_date [Time, nil] The date the contract activation ends
  #
  #   @param activation_start_date [Time, nil] The date the contract becomes active
  #
  #   @param billing_id [String, nil] The billing provider (Received) contract ID; null until the contract has synced
  #
  #   @param contract_id [String] The Stigg contract ref ID (the key used to fetch/update/delete this contract)
  #
  #   @param created_at [Time, nil] The date the contract was created
  #
  #   @param customer_external_id [String, nil] The external identifier of the customer the contract belongs to
  #
  #   @param external_id [String] The external identifier of the contract
  #
  #   @param latest_invoice [Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice, nil] The most recent non-draft invoice for this contract (open, paid, or canceled), o
  #
  #   @param name [String, nil] The contract name (the purchase-order number when set, otherwise the contract/cu
  #
  #   @param next_invoice [Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice, nil] A preview of the contract's upcoming invoice, or null when none is available
  #
  #   @param po_number [String, nil] Purchase-order number, when set on the contract
  #
  #   @param ref_id [String, nil] The Stigg contract ref ID (present for Stigg-managed contracts; the key used to
  #
  #   @param state [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::State] The current state of the contract
  #
  #   @param subscriptions [Array<Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription>] The custom subscriptions attached to this contract (empty when none)

  # @see Stigg::Models::V1::CustomerListContractsResponse::Data#latest_invoice
  class LatestInvoice < Stigg::Internal::Type::BaseModel
    # @!attribute billing_id
    #   Invoice billing ID
    #
    #   @return [String]
    required :billing_id, String, api_name: :billingId

    # @!attribute created_at
    #   Invoice creation date
    #
    #   @return [Time]
    required :created_at, Time, api_name: :createdAt

    # @!attribute requires_action
    #   Whether payment requires action
    #
    #   @return [Boolean]
    required :requires_action, Stigg::Internal::Type::Boolean, api_name: :requiresAction

    # @!attribute status
    #   Invoice status
    #
    #   @return [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::Status]
    required :status,
             enum: -> { Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::Status }

    # @!attribute amount_due
    #   Amount due
    #
    #   @return [Float, nil]
    optional :amount_due, Float, api_name: :amountDue, nil?: true

    # @!attribute billing_reason
    #   Billing reason
    #
    #   @return [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::BillingReason, nil]
    optional :billing_reason,
             enum: -> { Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::BillingReason },
             api_name: :billingReason,
             nil?: true

    # @!attribute currency
    #   Invoice currency
    #
    #   @return [String, nil]
    optional :currency, String, nil?: true

    # @!attribute pdf_url
    #   Invoice PDF URL
    #
    #   @return [String, nil]
    optional :pdf_url, String, api_name: :pdfUrl, nil?: true

    # @!attribute total
    #   Total amount
    #
    #   @return [Float, nil]
    optional :total, Float, nil?: true

    # @!method initialize(billing_id:, created_at:, requires_action:, status:, amount_due: nil, billing_reason: nil, currency: nil, pdf_url: nil, total: nil)
    #   The most recent non-draft invoice for this contract (open, paid, or canceled),
    #   or null when none exists
    #
    #   @param billing_id [String] Invoice billing ID
    #
    #   @param created_at [Time] Invoice creation date
    #
    #   @param requires_action [Boolean] Whether payment requires action
    #
    #   @param status [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::Status] Invoice status
    #
    #   @param amount_due [Float, nil] Amount due
    #
    #   @param billing_reason [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice::BillingReason, nil] Billing reason
    #
    #   @param currency [String, nil] Invoice currency
    #
    #   @param pdf_url [String, nil] Invoice PDF URL
    #
    #   @param total [Float, nil] Total amount

    # Invoice status
    #
    # @see Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice#status
    module Status
      extend Stigg::Internal::Type::Enum

      OPEN = :OPEN
      CANCELED = :CANCELED
      PAID = :PAID

      # @!method self.values
      #   @return [Array<Symbol>]
    end

    # Billing reason
    #
    # @see Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice#billing_reason
    module BillingReason
      extend Stigg::Internal::Type::Enum

      BILLING_CYCLE = :BILLING_CYCLE
      SUBSCRIPTION_CREATION = :SUBSCRIPTION_CREATION
      SUBSCRIPTION_UPDATE = :SUBSCRIPTION_UPDATE
      MANUAL = :MANUAL
      MINIMUM_INVOICE_AMOUNT_EXCEEDED = :MINIMUM_INVOICE_AMOUNT_EXCEEDED
      OTHER = :OTHER

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see Stigg::Models::V1::CustomerListContractsResponse::Data#next_invoice
  class NextInvoice < Stigg::Internal::Type::BaseModel
    # @!attribute amount
    #   The total amount of the upcoming invoice
    #
    #   @return [Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount]
    required :amount, -> { Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount }

    # @!attribute due_date
    #   The date the upcoming invoice is due
    #
    #   @return [Time, nil]
    required :due_date, Time, api_name: :dueDate, nil?: true

    # @!attribute period_end
    #   The end of the billing period the upcoming invoice covers
    #
    #   @return [Time, nil]
    required :period_end, Time, api_name: :periodEnd, nil?: true

    # @!attribute period_start
    #   The start of the billing period the upcoming invoice covers
    #
    #   @return [Time, nil]
    required :period_start, Time, api_name: :periodStart, nil?: true

    # @!method initialize(amount:, due_date:, period_end:, period_start:)
    #   A preview of the contract's upcoming invoice, or null when none is available
    #
    #   @param amount [Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount] The total amount of the upcoming invoice
    #
    #   @param due_date [Time, nil] The date the upcoming invoice is due
    #
    #   @param period_end [Time, nil] The end of the billing period the upcoming invoice covers
    #
    #   @param period_start [Time, nil] The start of the billing period the upcoming invoice covers

    # @see Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice#amount
    class Amount < Stigg::Internal::Type::BaseModel
      # @!attribute amount
      #   The price amount
      #
      #   @return [Float]
      required :amount, Float

      # @!attribute currency
      #   ISO 4217 currency code
      #
      #   @return [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount::Currency]
      required :currency,
               enum: -> { Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount::Currency }

      # @!method initialize(amount:, currency:)
      #   The total amount of the upcoming invoice
      #
      #   @param amount [Float] The price amount
      #
      #   @param currency [Symbol, Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount::Currency] ISO 4217 currency code

      # ISO 4217 currency code
      #
      # @see Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice::Amount#currency
      module Currency
        extend Stigg::Internal::Type::Enum

        USD = :usd
        AED = :aed
        ALL = :all
        AMD = :amd
        ANG = :ang
        AUD = :aud
        AWG = :awg
        AZN = :azn
        BAM = :bam
        BBD = :bbd
        BDT = :bdt
        BGN = :bgn
        BIF = :bif
        BMD = :bmd
        BND = :bnd
        BSD = :bsd
        BWP = :bwp
        BYN = :byn
        BZD = :bzd
        BRL = :brl
        CAD = :cad
        CDF = :cdf
        CHF = :chf
        CNY = :cny
        CZK = :czk
        DKK = :dkk
        DOP = :dop
        DZD = :dzd
        EGP = :egp
        ETB = :etb
        EUR = :eur
        FJD = :fjd
        GBP = :gbp
        GEL = :gel
        GIP = :gip
        GMD = :gmd
        GYD = :gyd
        HKD = :hkd
        HRK = :hrk
        HTG = :htg
        IDR = :idr
        ILS = :ils
        INR = :inr
        ISK = :isk
        JMD = :jmd
        JPY = :jpy
        KES = :kes
        KGS = :kgs
        KHR = :khr
        KMF = :kmf
        KRW = :krw
        KYD = :kyd
        KZT = :kzt
        LBP = :lbp
        LKR = :lkr
        LRD = :lrd
        LSL = :lsl
        MAD = :mad
        MDL = :mdl
        MGA = :mga
        MKD = :mkd
        MMK = :mmk
        MNT = :mnt
        MOP = :mop
        MRO = :mro
        MVR = :mvr
        MWK = :mwk
        MXN = :mxn
        MYR = :myr
        MZN = :mzn
        NAD = :nad
        NGN = :ngn
        NOK = :nok
        NPR = :npr
        NZD = :nzd
        PGK = :pgk
        PHP = :php
        PKR = :pkr
        PLN = :pln
        QAR = :qar
        RON = :ron
        RSD = :rsd
        RUB = :rub
        RWF = :rwf
        SAR = :sar
        SBD = :sbd
        SCR = :scr
        SEK = :sek
        SGD = :sgd
        SLE = :sle
        SLL = :sll
        SOS = :sos
        SZL = :szl
        THB = :thb
        TJS = :tjs
        TOP = :top
        TRY = :try
        TTD = :ttd
        TZS = :tzs
        UAH = :uah
        UZS = :uzs
        VND = :vnd
        VUV = :vuv
        WST = :wst
        XAF = :xaf
        XCD = :xcd
        YER = :yer
        ZAR = :zar
        ZMW = :zmw
        CLP = :clp
        DJF = :djf
        GNF = :gnf
        UGX = :ugx
        PYG = :pyg
        XOF = :xof
        XPF = :xpf

        # @!method self.values
        #   @return [Array<Symbol>]
      end
    end
  end

  # The current state of the contract
  #
  # @see Stigg::Models::V1::CustomerListContractsResponse::Data#state
  module State
    extend Stigg::Internal::Type::Enum

    DRAFT = :DRAFT
    ACTIVE = :ACTIVE
    CANCELED = :CANCELED
    END_BILLING = :END_BILLING

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  class Subscription < Stigg::Internal::Type::BaseModel
    # @!attribute plan_display_name
    #   Display name of the subscription plan
    #
    #   @return [String, nil]
    required :plan_display_name, String, api_name: :planDisplayName, nil?: true

    # @!attribute product_display_name
    #   Display name of the product the subscription plan belongs to
    #
    #   @return [String, nil]
    required :product_display_name, String, api_name: :productDisplayName, nil?: true

    # @!attribute subscription_id
    #   The subscription ref ID (use it to deep-link to the subscription)
    #
    #   @return [String]
    required :subscription_id, String, api_name: :subscriptionId

    # @!method initialize(plan_display_name:, product_display_name:, subscription_id:)
    #   A custom subscription attached to a contract.
    #
    #   @param plan_display_name [String, nil] Display name of the subscription plan
    #
    #   @param product_display_name [String, nil] Display name of the product the subscription plan belongs to
    #
    #   @param subscription_id [String] The subscription ref ID (use it to deep-link to the subscription)
  end
end

Instance Attribute Details

#activation_end_dateTime?

The date the contract activation ends

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


31
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 31

required :activation_end_date, Time, api_name: :activationEndDate, nil?: true

#activation_start_dateTime?

The date the contract becomes active

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


37
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 37

required :activation_start_date, Time, api_name: :activationStartDate, nil?: true

#billing_idString?

The billing provider (Received) contract ID; null until the contract has synced to the billing provider

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


44
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 44

required :billing_id, String, api_name: :billingId, nil?: true

#contract_idString

The Stigg contract ref ID (the key used to fetch/update/delete this contract)

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 50

required :contract_id, String, api_name: :contractId

#created_atTime?

The date the contract was created

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


56
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 56

required :created_at, Time, api_name: :createdAt, nil?: true

#customer_external_idString?

The external identifier of the customer the contract belongs to

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


62
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 62

required :customer_external_id, String, api_name: :customerExternalId, nil?: true

#external_idString

The external identifier of the contract

Parameters:

  • value (String)

Returns:

  • (String)


68
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 68

required :external_id, String, api_name: :externalId

#idString?

The persisted Stigg contract id (matches a subscription’s contractId; present for Stigg-managed contracts)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


25
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 25

required :id, String, nil?: true

#latest_invoiceStigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice?

The most recent non-draft invoice for this contract (open, paid, or canceled), or null when none exists



75
76
77
78
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 75

required :latest_invoice,
-> { Stigg::Models::V1::CustomerListContractsResponse::Data::LatestInvoice },
api_name: :latestInvoice,
nil?: true

#nameString?

The contract name (the purchase-order number when set, otherwise the contract/customer name)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


85
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 85

required :name, String, nil?: true

#next_invoiceStigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice?

A preview of the contract's upcoming invoice, or null when none is available



91
92
93
94
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 91

required :next_invoice,
-> { Stigg::Models::V1::CustomerListContractsResponse::Data::NextInvoice },
api_name: :nextInvoice,
nil?: true

#po_numberString?

Purchase-order number, when set on the contract

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


100
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 100

required :po_number, String, api_name: :poNumber, nil?: true

#ref_idString?

The Stigg contract ref ID (present for Stigg-managed contracts; the key used to update/delete)

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


107
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 107

required :ref_id, String, api_name: :refId, nil?: true

#stateSymbol, Stigg::Models::V1::CustomerListContractsResponse::Data::State

The current state of the contract

Parameters:

  • value (Stigg::Models::V1::CustomerListContractsResponse::Data::state)

Returns:



113
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 113

required :state, enum: -> { Stigg::Models::V1::CustomerListContractsResponse::Data::State }

#subscriptionsArray<Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription>

The custom subscriptions attached to this contract (empty when none)



119
120
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 119

required :subscriptions,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription] }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 267

Instance Method Details

#to_hash{

Returns:

  • ({)


88
# File 'sig/stigg/models/v1/customer_list_contracts_response.rbs', line 88

def to_hash: -> {