Class: Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListContractsResponse::Data::Subscription
- Defined in:
- lib/stigg/models/v1/customer_list_contracts_response.rb,
sig/stigg/models/v1/customer_list_contracts_response.rbs
Instance Attribute Summary collapse
-
#plan_display_name ⇒ String?
Display name of the subscription plan.
-
#product_display_name ⇒ String?
Display name of the product the subscription plan belongs to.
-
#subscription_id ⇒ String
The subscription ref ID (use it to deep-link to the subscription).
Instance Method Summary collapse
-
#initialize(plan_display_name:, product_display_name:, subscription_id:) ⇒ Object
constructor
A custom subscription attached to a contract.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(plan_display_name:, product_display_name:, subscription_id:) ⇒ Object
A custom subscription attached to a contract.
|
|
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 494
|
Instance Attribute Details
#plan_display_name ⇒ String?
Display name of the subscription plan
480 |
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 480 required :plan_display_name, String, api_name: :planDisplayName, nil?: true |
#product_display_name ⇒ String?
Display name of the product the subscription plan belongs to
486 |
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 486 required :product_display_name, String, api_name: :productDisplayName, nil?: true |
#subscription_id ⇒ String
The subscription ref ID (use it to deep-link to the subscription)
492 |
# File 'lib/stigg/models/v1/customer_list_contracts_response.rb', line 492 required :subscription_id, String, api_name: :subscriptionId |
Instance Method Details
#to_hash ⇒ {
524 |
# File 'sig/stigg/models/v1/customer_list_contracts_response.rbs', line 524
def to_hash: -> {
|