Class: Stigg::Models::V1::CustomerListInvoicesParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListInvoicesParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/customer_list_invoices_params.rb,
sig/stigg/models/v1/customer_list_invoices_params.rbs
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#after ⇒ String?
Return items that come after this cursor.
-
#before ⇒ String?
Return items that come before this cursor.
-
#contract_external_id ⇒ String?
Filter to invoices for this contract only (contract external ID or Received contract ID).
- #id ⇒ String
-
#issued_after ⇒ Time?
Filter to invoices issued on or after this date, inclusive (ISO 8601).
-
#issued_before ⇒ Time?
Filter to invoices issued on or before this date, inclusive (ISO 8601).
-
#limit ⇒ Integer?
Maximum number of items to return.
-
#order_by ⇒ Symbol, ...
Field to sort by: issueDate (default), dueDate, or total.
-
#order_dir ⇒ Symbol, ...
Sort direction: ASC (default) or DESC.
-
#state_in ⇒ String?
Filter by invoice state.
- #x_account_id ⇒ String?
- #x_environment_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, after: nil, before: nil, contract_external_id: nil, issued_after: nil, issued_before: nil, limit: nil, order_by: nil, order_dir: nil, state_in: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see CustomerListInvoicesParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, after: nil, before: nil, contract_external_id: nil, issued_after: nil, issued_before: nil, limit: nil, order_by: nil, order_dir: nil, state_in: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::CustomerListInvoicesParams for more details.
|
|
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 81
|
Instance Attribute Details
#after ⇒ String?
Return items that come after this cursor
20 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 20 optional :after, String |
#before ⇒ String?
Return items that come before this cursor
26 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 26 optional :before, String |
#contract_external_id ⇒ String?
Filter to invoices for this contract only (contract external ID or Received contract ID). Omit for all contracts.
33 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 33 optional :contract_external_id, String |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 14 required :id, String |
#issued_after ⇒ Time?
Filter to invoices issued on or after this date, inclusive (ISO 8601)
39 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 39 optional :issued_after, Time |
#issued_before ⇒ Time?
Filter to invoices issued on or before this date, inclusive (ISO 8601)
45 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 45 optional :issued_before, Time |
#limit ⇒ Integer?
Maximum number of items to return
51 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 51 optional :limit, Integer |
#order_by ⇒ Symbol, ...
Field to sort by: issueDate (default), dueDate, or total
57 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 57 optional :order_by, enum: -> { Stigg::V1::CustomerListInvoicesParams::OrderBy } |
#order_dir ⇒ Symbol, ...
Sort direction: ASC (default) or DESC
63 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 63 optional :order_dir, enum: -> { Stigg::V1::CustomerListInvoicesParams::OrderDir } |
#state_in ⇒ String?
Filter by invoice state. Supports comma-separated values for multiple states
69 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 69 optional :state_in, String |
#x_account_id ⇒ String?
74 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 74 optional :x_account_id, String |
#x_environment_id ⇒ String?
79 |
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 79 optional :x_environment_id, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_list_invoices_params.rb', line 119
|
Instance Method Details
#to_hash ⇒ {
91 |
# File 'sig/stigg/models/v1/customer_list_invoices_params.rbs', line 91
def to_hash: -> {
|