Class: Stigg::Models::V1::CustomerListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListResponse
- Defined in:
- lib/stigg/models/v1/customer_list_response.rb
Overview
Defined Under Namespace
Modules: BillingCurrency, CouponID Classes: DefaultPaymentMethod, Integration, Passthrough
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#billing_currency ⇒ Symbol, ...
The billing currency of the customer.
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#coupon_id ⇒ String, ...
Customer level coupon.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#default_payment_method ⇒ Stigg::Models::V1::CustomerListResponse::DefaultPaymentMethod?
The default payment method details.
-
#email ⇒ String?
The email of the customer.
-
#id ⇒ String
Customer slug.
-
#integrations ⇒ Array<Stigg::Models::V1::CustomerListResponse::Integration>?
List of integrations.
-
#language ⇒ String?
Language to use for this customer.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#name ⇒ String?
The name of the customer.
-
#passthrough ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough?
Vendor-specific billing passthrough fields.
-
#timezone ⇒ String?
Timezone to use for this customer.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, updated_at:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil) ⇒ Object
constructor
A customer can be either an organization or an individual.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, updated_at:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil) ⇒ Object
A customer can be either an organization or an individual
|
|
# File 'lib/stigg/models/v1/customer_list_response.rb', line 108
|
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
18 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 18 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#billing_currency ⇒ Symbol, ...
The billing currency of the customer
36 37 38 39 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 36 optional :billing_currency, enum: -> { Stigg::Models::V1::CustomerListResponse::BillingCurrency }, api_name: :billingCurrency, nil?: true |
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
45 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 45 optional :billing_id, String, api_name: :billingId, nil?: true |
#coupon_id ⇒ String, ...
Customer level coupon
51 52 53 54 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 51 optional :coupon_id, union: -> { Stigg::Models::V1::CustomerListResponse::CouponID }, api_name: :couponId, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
24 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 24 required :created_at, Time, api_name: :createdAt |
#default_payment_method ⇒ Stigg::Models::V1::CustomerListResponse::DefaultPaymentMethod?
The default payment method details
60 61 62 63 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 60 optional :default_payment_method, -> { Stigg::Models::V1::CustomerListResponse::DefaultPaymentMethod }, api_name: :defaultPaymentMethod, nil?: true |
#email ⇒ String?
The email of the customer
69 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 69 optional :email, String, nil?: true |
#id ⇒ String
Customer slug
12 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 12 required :id, String |
#integrations ⇒ Array<Stigg::Models::V1::CustomerListResponse::Integration>?
List of integrations
75 76 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 75 optional :integrations, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CustomerListResponse::Integration] } |
#language ⇒ String?
Language to use for this customer
82 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 82 optional :language, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
88 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 88 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the customer
94 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 94 optional :name, String, nil?: true |
#passthrough ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough?
Vendor-specific billing passthrough fields.
100 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 100 optional :passthrough, -> { Stigg::Models::V1::CustomerListResponse::Passthrough } |
#timezone ⇒ String?
Timezone to use for this customer
106 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 106 optional :timezone, String, nil?: true |
#updated_at ⇒ Time
Timestamp of when the record was last updated
30 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 30 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_list_response.rb', line 264
|