Class: Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe
- Defined in:
- lib/stigg/models/v1/customer_list_response.rb
Overview
Defined Under Namespace
Classes: BillingAddress, ShippingAddress, TaxID
Instance Attribute Summary collapse
-
#billing_address ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::BillingAddress?
Physical address.
-
#customer_name ⇒ String?
Customer name.
-
#invoice_custom_fields ⇒ Hash{Symbol=>String}?
Invoice custom fields.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer.
-
#shipping_address ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::ShippingAddress?
Physical address.
-
#tax_ids ⇒ Array<Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID>?
Tax IDs.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Physical address.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Physical address
|
|
# File 'lib/stigg/models/v1/customer_list_response.rb', line 478
|
Instance Attribute Details
#billing_address ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::BillingAddress?
Physical address
432 433 434 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 432 optional :billing_address, -> { Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::BillingAddress }, api_name: :billingAddress |
#customer_name ⇒ String?
Customer name
440 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 440 optional :customer_name, String, api_name: :customerName |
#invoice_custom_fields ⇒ Hash{Symbol=>String}?
Invoice custom fields
446 447 448 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 446 optional :invoice_custom_fields, Stigg::Internal::Type::HashOf[String], api_name: :invoiceCustomFields |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
454 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 454 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer
460 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 460 optional :payment_method_id, String, api_name: :paymentMethodId |
#shipping_address ⇒ Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::ShippingAddress?
Physical address
466 467 468 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 466 optional :shipping_address, -> { Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::ShippingAddress }, api_name: :shippingAddress |
#tax_ids ⇒ Array<Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID>?
Tax IDs
474 475 476 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 474 optional :tax_ids, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID] }, api_name: :taxIds |