Class: Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID
- Defined in:
- lib/stigg/models/v1/customer_list_response.rb,
sig/stigg/models/v1/customer_list_response.rbs
Instance Attribute Summary collapse
-
#type ⇒ String
The type of tax exemption identifier, such as VAT.
-
#value ⇒ String
The actual tax identifier value.
Instance Method Summary collapse
-
#initialize ⇒ TaxID
constructor
A new instance of TaxID.
- #to_hash ⇒ { type: String, value: String }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ TaxID
Returns a new instance of TaxID.
672 |
# File 'sig/stigg/models/v1/customer_list_response.rbs', line 672
def initialize: (type: String, value: String) -> void
|
Instance Attribute Details
#type ⇒ String
The type of tax exemption identifier, such as VAT.
610 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 610 required :type, String |
#value ⇒ String
The actual tax identifier value
616 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 616 required :value, String |
Instance Method Details
#to_hash ⇒ { type: String, value: String }
674 |
# File 'sig/stigg/models/v1/customer_list_response.rbs', line 674
def to_hash: -> { type: String, value: String }
|