Class: Stigg::Models::V1::CustomerProvisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerProvisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/customer_provision_params.rb
Overview
Defined Under Namespace
Modules: BillingCurrency, CouponID Classes: DefaultPaymentMethod, Integration, Passthrough
Instance Attribute Summary collapse
-
#billing_currency ⇒ Symbol, ...
The billing currency of the customer.
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#coupon_id ⇒ String, ...
Customer level coupon.
-
#default_payment_method ⇒ Stigg::Models::V1::CustomerProvisionParams::DefaultPaymentMethod?
The default payment method details.
-
#email ⇒ String?
The email of the customer.
-
#id ⇒ String
Customer slug.
-
#integrations ⇒ Array<Stigg::Models::V1::CustomerProvisionParams::Integration>?
List of integrations.
-
#language ⇒ String?
Language to use for this customer.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#name ⇒ String?
The name of the customer.
-
#passthrough ⇒ Stigg::Models::V1::CustomerProvisionParams::Passthrough?
Vendor-specific billing passthrough fields.
-
#timezone ⇒ String?
Timezone to use for this customer.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 93
|
Instance Attribute Details
#billing_currency ⇒ Symbol, ...
The billing currency of the customer
21 22 23 24 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 21 optional :billing_currency, enum: -> { Stigg::V1::CustomerProvisionParams::BillingCurrency }, api_name: :billingCurrency, nil?: true |
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
30 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 30 optional :billing_id, String, api_name: :billingId, nil?: true |
#coupon_id ⇒ String, ...
Customer level coupon
36 37 38 39 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 36 optional :coupon_id, union: -> { Stigg::V1::CustomerProvisionParams::CouponID }, api_name: :couponId, nil?: true |
#default_payment_method ⇒ Stigg::Models::V1::CustomerProvisionParams::DefaultPaymentMethod?
The default payment method details
45 46 47 48 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 45 optional :default_payment_method, -> { Stigg::V1::CustomerProvisionParams::DefaultPaymentMethod }, api_name: :defaultPaymentMethod, nil?: true |
#email ⇒ String?
The email of the customer
54 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 54 optional :email, String, nil?: true |
#id ⇒ String
Customer slug
15 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 15 required :id, String |
#integrations ⇒ Array<Stigg::Models::V1::CustomerProvisionParams::Integration>?
List of integrations
60 61 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 60 optional :integrations, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::CustomerProvisionParams::Integration] } |
#language ⇒ String?
Language to use for this customer
67 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 67 optional :language, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
73 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 73 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the customer
79 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 79 optional :name, String, nil?: true |
#passthrough ⇒ Stigg::Models::V1::CustomerProvisionParams::Passthrough?
Vendor-specific billing passthrough fields.
85 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 85 optional :passthrough, -> { Stigg::V1::CustomerProvisionParams::Passthrough } |
#timezone ⇒ String?
Timezone to use for this customer
91 |
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 91 optional :timezone, String, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_provision_params.rb', line 241
|