Class: Stigg::Models::V1::CustomerResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerResponse
- Defined in:
- lib/stigg/models/v1/customer_response.rb,
sig/stigg/models/v1/customer_response.rbs
Overview
Defined Under Namespace
Classes: Data
Instance Attribute Summary collapse
-
#data ⇒ Stigg::Models::V1::CustomerResponse::Data
A customer can be either an organization or an individual.
Instance Method Summary collapse
-
#initialize(data:) ⇒ CustomerResponse
constructor
Response object.
- #to_hash ⇒ { data: Stigg::V1::CustomerResponse::Data }
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(data:) ⇒ CustomerResponse
Response object
|
|
# File 'lib/stigg/models/v1/customer_response.rb', line 14
|
Instance Attribute Details
#data ⇒ Stigg::Models::V1::CustomerResponse::Data
A customer can be either an organization or an individual
12 |
# File 'lib/stigg/models/v1/customer_response.rb', line 12 required :data, -> { Stigg::V1::CustomerResponse::Data } |
Instance Method Details
#to_hash ⇒ { data: Stigg::V1::CustomerResponse::Data }
11 |
# File 'sig/stigg/models/v1/customer_response.rbs', line 11
def to_hash: -> { data: Stigg::V1::CustomerResponse::Data }
|