Class: Stigg::Models::V1::CustomerResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_response.rb

Overview

See Also:

Defined Under Namespace

Modules: BillingCurrency, CouponID Classes: DefaultPaymentMethod, Integration, Passthrough

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, created_at:, updated_at:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil) ⇒ Object

A customer can be either an organization or an individual

Parameters:

  • id (String)

    Customer slug

  • archived_at (Time, nil)

    Timestamp of when the record was deleted

  • created_at (Time)

    Timestamp of when the record was created

  • updated_at (Time)

    Timestamp of when the record was last updated

  • billing_currency (Symbol, Stigg::Models::V1::CustomerResponse::Data::BillingCurrency, nil) (defaults to: nil)

    The billing currency of the customer

  • billing_id (String, nil) (defaults to: nil)

    The unique identifier for the entity in the billing provider

  • coupon_id (String, Symbol, Stigg::Models::V1::CustomerResponse::Data::CouponID, nil) (defaults to: nil)

    Customer level coupon

  • default_payment_method (Stigg::Models::V1::CustomerResponse::Data::DefaultPaymentMethod, nil) (defaults to: nil)

    The default payment method details

  • email (String, nil) (defaults to: nil)

    The email of the customer

  • integrations (Array<Stigg::Models::V1::CustomerResponse::Data::Integration>) (defaults to: nil)

    List of integrations

  • language (String, nil) (defaults to: nil)

    Language to use for this customer

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional metadata

  • name (String, nil) (defaults to: nil)

    The name of the customer

  • passthrough (Stigg::Models::V1::CustomerResponse::Data::Passthrough) (defaults to: nil)

    Vendor-specific billing passthrough fields.

  • timezone (String, nil) (defaults to: nil)

    Timezone to use for this customer



# File 'lib/stigg/models/v1/customer_response.rb', line 121

Instance Attribute Details

#archived_atTime?

Timestamp of when the record was deleted

Returns:

  • (Time, nil)


31
# File 'lib/stigg/models/v1/customer_response.rb', line 31

required :archived_at, Time, api_name: :archivedAt, nil?: true

#billing_currencySymbol, ...

The billing currency of the customer



49
50
51
52
# File 'lib/stigg/models/v1/customer_response.rb', line 49

optional :billing_currency,
enum: -> { Stigg::V1::CustomerResponse::Data::BillingCurrency },
api_name: :billingCurrency,
nil?: true

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


58
# File 'lib/stigg/models/v1/customer_response.rb', line 58

optional :billing_id, String, api_name: :billingId, nil?: true

#coupon_idString, ...

Customer level coupon

Returns:



64
65
66
67
# File 'lib/stigg/models/v1/customer_response.rb', line 64

optional :coupon_id,
union: -> { Stigg::V1::CustomerResponse::Data::CouponID },
api_name: :couponId,
nil?: true

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


37
# File 'lib/stigg/models/v1/customer_response.rb', line 37

required :created_at, Time, api_name: :createdAt

#default_payment_methodStigg::Models::V1::CustomerResponse::Data::DefaultPaymentMethod?

The default payment method details



73
74
75
76
# File 'lib/stigg/models/v1/customer_response.rb', line 73

optional :default_payment_method,
-> { Stigg::V1::CustomerResponse::Data::DefaultPaymentMethod },
api_name: :defaultPaymentMethod,
nil?: true

#emailString?

The email of the customer

Returns:

  • (String, nil)


82
# File 'lib/stigg/models/v1/customer_response.rb', line 82

optional :email, String, nil?: true

#idString

Customer slug

Returns:

  • (String)


25
# File 'lib/stigg/models/v1/customer_response.rb', line 25

required :id, String

#integrationsArray<Stigg::Models::V1::CustomerResponse::Data::Integration>?

List of integrations



88
89
# File 'lib/stigg/models/v1/customer_response.rb', line 88

optional :integrations,
-> { Stigg::Internal::Type::ArrayOf[Stigg::V1::CustomerResponse::Data::Integration] }

#languageString?

Language to use for this customer

Returns:

  • (String, nil)


95
# File 'lib/stigg/models/v1/customer_response.rb', line 95

optional :language, String, nil?: true

#metadataHash{Symbol=>String}?

Additional metadata

Returns:

  • (Hash{Symbol=>String}, nil)


101
# File 'lib/stigg/models/v1/customer_response.rb', line 101

optional :metadata, Stigg::Internal::Type::HashOf[String]

#nameString?

The name of the customer

Returns:

  • (String, nil)


107
# File 'lib/stigg/models/v1/customer_response.rb', line 107

optional :name, String, nil?: true

#passthroughStigg::Models::V1::CustomerResponse::Data::Passthrough?

Vendor-specific billing passthrough fields.



113
# File 'lib/stigg/models/v1/customer_response.rb', line 113

optional :passthrough, -> { Stigg::V1::CustomerResponse::Data::Passthrough }

#timezoneString?

Timezone to use for this customer

Returns:

  • (String, nil)


119
# File 'lib/stigg/models/v1/customer_response.rb', line 119

optional :timezone, String, nil?: true

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


43
# File 'lib/stigg/models/v1/customer_response.rb', line 43

required :updated_at, Time, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customer_response.rb', line 277