Class: Stigg::Models::V1::CustomerResponse::Data::Passthrough

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Stripe, Zuora

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(type:, value:) ⇒ Object

Tax identifier with type and value for customer tax exemptions.

Parameters:

  • type (String)

    The type of tax exemption identifier, such as VAT.

  • value (String)

    The actual tax identifier value



# File 'lib/stigg/models/v1/customer_response.rb', line 432

Instance Attribute Details

#stripeStigg::Models::V1::CustomerResponse::Data::Passthrough::Stripe?

Stripe-specific billing fields for the customer.



424
# File 'lib/stigg/models/v1/customer_response.rb', line 424

optional :stripe, -> { Stigg::V1::CustomerResponse::Data::Passthrough::Stripe }

#zuoraStigg::Models::V1::CustomerResponse::Data::Passthrough::Zuora?

Zuora-specific billing fields for the customer.



430
# File 'lib/stigg/models/v1/customer_response.rb', line 430

optional :zuora, -> { Stigg::V1::CustomerResponse::Data::Passthrough::Zuora }