Class: Stigg::Models::V1::CustomerResponse::Data::Passthrough::Zuora
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerResponse::Data::Passthrough::Zuora
- Defined in:
- lib/stigg/models/v1/customer_response.rb
Overview
Defined Under Namespace
Modules: Currency Classes: BillingAddress
Instance Attribute Summary collapse
-
#billing_address ⇒ Stigg::Models::V1::CustomerResponse::Data::Passthrough::Zuora::BillingAddress?
Physical address.
-
#currency ⇒ Symbol, ...
Customers selected currency.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Physical address.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Physical address
|
|
# File 'lib/stigg/models/v1/customer_response.rb', line 668
|
Instance Attribute Details
#billing_address ⇒ Stigg::Models::V1::CustomerResponse::Data::Passthrough::Zuora::BillingAddress?
Physical address
646 647 648 |
# File 'lib/stigg/models/v1/customer_response.rb', line 646 optional :billing_address, -> { Stigg::V1::CustomerResponse::Data::Passthrough::Zuora::BillingAddress }, api_name: :billingAddress |
#currency ⇒ Symbol, ...
Customers selected currency
654 |
# File 'lib/stigg/models/v1/customer_response.rb', line 654 optional :currency, enum: -> { Stigg::V1::CustomerResponse::Data::Passthrough::Zuora::Currency } |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
660 |
# File 'lib/stigg/models/v1/customer_response.rb', line 660 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer
666 |
# File 'lib/stigg/models/v1/customer_response.rb', line 666 optional :payment_method_id, String, api_name: :paymentMethodId |