Class: Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data
- Defined in:
- lib/stigg/models/v1/customer_retrieve_entitlements_response.rb
Overview
Defined Under Namespace
Modules: AccessDeniedReason, Entitlement
Instance Attribute Summary collapse
-
#access_denied_reason ⇒ Symbol, ...
Reason why entitlements access was denied, if applicable.
-
#entitlements ⇒ Array<Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature, Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit>
List of effective feature and credit entitlements.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access_denied_reason:, entitlements:) ⇒ Object
constructor
The effective entitlements state for a customer or resource.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_denied_reason:, entitlements:) ⇒ Object
The effective entitlements state for a customer or resource.
|
|
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 37
|
Instance Attribute Details
#access_denied_reason ⇒ Symbol, ...
Reason why entitlements access was denied, if applicable
25 26 27 28 |
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 25 required :access_denied_reason, enum: -> { Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::AccessDeniedReason }, api_name: :accessDeniedReason, nil?: true |
#entitlements ⇒ Array<Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature, Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit>
List of effective feature and credit entitlements
34 35 |
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 34 required :entitlements, -> { Stigg::Internal::Type::ArrayOf[union: Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement] } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 54
|