Class: Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_retrieve_entitlements_response.rb

Defined Under Namespace

Modules: AccessDeniedReason Classes: Currency

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_denied_reason:, currency:, current_usage:, is_granted:, usage_limit:, usage_updated_at:, entitlement_updated_at: nil, usage_period_end: nil, valid_until: nil, type: :CREDIT) ⇒ Object

Parameters:



# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 346

Instance Attribute Details

#access_denied_reasonSymbol, ...



290
291
292
293
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 290

required :access_denied_reason,
enum: -> { Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit::AccessDeniedReason },
api_name: :accessDeniedReason,
nil?: true

#currencyStigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit::Currency

The currency associated with a credit entitlement.



299
300
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 299

required :currency,
-> { Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Credit::Currency }

#current_usageFloat

Returns:

  • (Float)


305
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 305

required :current_usage, Float, api_name: :currentUsage

#entitlement_updated_atTime?

Timestamp of the last update to the entitlement grant or configuration.

Returns:

  • (Time, nil)


332
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 332

optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt

#is_grantedBoolean

Returns:

  • (Boolean)


310
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 310

required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted

#typeSymbol, :CREDIT

Returns:

  • (Symbol, :CREDIT)


315
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 315

required :type, const: :CREDIT

#usage_limitFloat

Returns:

  • (Float)


320
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 320

required :usage_limit, Float, api_name: :usageLimit

#usage_period_endTime?

The end date of the current billing period for recurring credit grants.

Returns:

  • (Time, nil)


338
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 338

optional :usage_period_end, Time, api_name: :usagePeriodEnd

#usage_updated_atTime

Timestamp of the last update to the credit usage.

Returns:

  • (Time)


326
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 326

required :usage_updated_at, Time, api_name: :usageUpdatedAt

#valid_untilTime?

The next time the entitlement should be recalculated

Returns:

  • (Time, nil)


344
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 344

optional :valid_until, Time, api_name: :validUntil

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 386