Class: Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_retrieve_entitlements_response.rb

Defined Under Namespace

Modules: AccessDeniedReason, ResetPeriod Classes: Feature

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(access_denied_reason:, is_granted:, current_usage: nil, entitlement_updated_at: nil, feature: nil, has_unlimited_usage: nil, reset_period: nil, usage_limit: nil, usage_period_anchor: nil, usage_period_end: nil, usage_period_start: nil, valid_until: nil, type: :FEATURE) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature for more details.

Parameters:



# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 149

Instance Attribute Details

#access_denied_reasonSymbol, ...



72
73
74
75
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 72

required :access_denied_reason,
enum: -> { Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::AccessDeniedReason },
api_name: :accessDeniedReason,
nil?: true

#current_usageFloat?

Returns:

  • (Float, nil)


90
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 90

optional :current_usage, Float, api_name: :currentUsage

#entitlement_updated_atTime?

Timestamp of the last update to the entitlement grant or configuration.

Returns:

  • (Time, nil)


96
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 96

optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt

#has_unlimited_usageBoolean?

Returns:

  • (Boolean, nil)


107
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 107

optional :has_unlimited_usage, Stigg::Internal::Type::Boolean, api_name: :hasUnlimitedUsage

#is_grantedBoolean

Returns:

  • (Boolean)


80
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 80

required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted

#reset_periodSymbol, ...



112
113
114
115
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 112

optional :reset_period,
enum: -> { Stigg::Models::V1::CustomerRetrieveEntitlementsResponse::Data::Entitlement::Feature::ResetPeriod },
api_name: :resetPeriod,
nil?: true

#typeSymbol, :FEATURE

Returns:

  • (Symbol, :FEATURE)


85
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 85

required :type, const: :FEATURE

#usage_limitFloat?

Returns:

  • (Float, nil)


120
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 120

optional :usage_limit, Float, api_name: :usageLimit, nil?: true

#usage_period_anchorTime?

The anchor for calculating the usage period for metered entitlements with a reset period configured

Returns:

  • (Time, nil)


127
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 127

optional :usage_period_anchor, Time, api_name: :usagePeriodAnchor

#usage_period_endTime?

The end date of the usage period for metered entitlements with a reset period configured

Returns:

  • (Time, nil)


134
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 134

optional :usage_period_end, Time, api_name: :usagePeriodEnd

#usage_period_startTime?

The start date of the usage period for metered entitlements with a reset period configured

Returns:

  • (Time, nil)


141
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 141

optional :usage_period_start, Time, api_name: :usagePeriodStart

#valid_untilTime?

The next time the entitlement should be recalculated

Returns:

  • (Time, nil)


147
# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 147

optional :valid_until, Time, api_name: :validUntil

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customer_retrieve_entitlements_response.rb', line 199