Class: Stigg::Models::V1::CustomerUpdateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/customer_update_params.rb

Overview

Defined Under Namespace

Modules: BillingCurrency, CouponID Classes: Integration, Passthrough

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, billing_currency: nil, billing_id: nil, coupon_id: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)
  • billing_currency (Symbol, Stigg::Models::V1::CustomerUpdateParams::BillingCurrency, nil) (defaults to: nil)

    The billing currency of the customer

  • billing_id (String, nil) (defaults to: nil)

    The unique identifier for the entity in the billing provider

  • coupon_id (String, Symbol, Stigg::Models::V1::CustomerUpdateParams::CouponID, nil) (defaults to: nil)

    Customer level coupon

  • email (String, nil) (defaults to: nil)

    The email of the customer

  • integrations (Array<Stigg::Models::V1::CustomerUpdateParams::Integration>) (defaults to: nil)

    List of integrations

  • language (String, nil) (defaults to: nil)

    Language to use for this customer

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional metadata

  • name (String, nil) (defaults to: nil)

    The name of the customer

  • passthrough (Stigg::Models::V1::CustomerUpdateParams::Passthrough) (defaults to: nil)

    Vendor-specific billing passthrough fields.

  • timezone (String, nil) (defaults to: nil)

    Timezone to use for this customer

  • x_account_id (String) (defaults to: nil)
  • x_environment_id (String) (defaults to: nil)
  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/customer_update_params.rb', line 93

Instance Attribute Details

#billing_currencySymbol, ...

The billing currency of the customer



20
21
22
23
# File 'lib/stigg/models/v1/customer_update_params.rb', line 20

optional :billing_currency,
enum: -> { Stigg::V1::CustomerUpdateParams::BillingCurrency },
api_name: :billingCurrency,
nil?: true

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


29
# File 'lib/stigg/models/v1/customer_update_params.rb', line 29

optional :billing_id, String, api_name: :billingId, nil?: true

#coupon_idString, ...

Customer level coupon

Returns:



35
36
37
38
# File 'lib/stigg/models/v1/customer_update_params.rb', line 35

optional :coupon_id,
union: -> { Stigg::V1::CustomerUpdateParams::CouponID },
api_name: :couponId,
nil?: true

#emailString?

The email of the customer

Returns:

  • (String, nil)


44
# File 'lib/stigg/models/v1/customer_update_params.rb', line 44

optional :email, String, nil?: true

#idString

Returns:

  • (String)


14
# File 'lib/stigg/models/v1/customer_update_params.rb', line 14

required :id, String

#integrationsArray<Stigg::Models::V1::CustomerUpdateParams::Integration>?

List of integrations



50
51
# File 'lib/stigg/models/v1/customer_update_params.rb', line 50

optional :integrations,
-> { Stigg::Internal::Type::ArrayOf[Stigg::V1::CustomerUpdateParams::Integration] }

#languageString?

Language to use for this customer

Returns:

  • (String, nil)


57
# File 'lib/stigg/models/v1/customer_update_params.rb', line 57

optional :language, String, nil?: true

#metadataHash{Symbol=>String}?

Additional metadata

Returns:

  • (Hash{Symbol=>String}, nil)


63
# File 'lib/stigg/models/v1/customer_update_params.rb', line 63

optional :metadata, Stigg::Internal::Type::HashOf[String]

#nameString?

The name of the customer

Returns:

  • (String, nil)


69
# File 'lib/stigg/models/v1/customer_update_params.rb', line 69

optional :name, String, nil?: true

#passthroughStigg::Models::V1::CustomerUpdateParams::Passthrough?

Vendor-specific billing passthrough fields.



75
# File 'lib/stigg/models/v1/customer_update_params.rb', line 75

optional :passthrough, -> { Stigg::V1::CustomerUpdateParams::Passthrough }

#timezoneString?

Timezone to use for this customer

Returns:

  • (String, nil)


81
# File 'lib/stigg/models/v1/customer_update_params.rb', line 81

optional :timezone, String, nil?: true

#x_account_idString?

Returns:

  • (String, nil)


86
# File 'lib/stigg/models/v1/customer_update_params.rb', line 86

optional :x_account_id, String

#x_environment_idString?

Returns:

  • (String, nil)


91
# File 'lib/stigg/models/v1/customer_update_params.rb', line 91

optional :x_environment_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customer_update_params.rb', line 243