Class: Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe
- Defined in:
- lib/stigg/models/v1/customer_update_params.rb
Overview
Defined Under Namespace
Classes: BillingAddress, ShippingAddress, TaxID
Instance Attribute Summary collapse
-
#billing_address ⇒ Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::BillingAddress?
Physical address.
-
#customer_name ⇒ String?
Customer name.
-
#invoice_custom_fields ⇒ Hash{Symbol=>String}?
Invoice custom fields.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer.
-
#shipping_address ⇒ Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::ShippingAddress?
Physical address.
-
#tax_ids ⇒ Array<Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::TaxID>?
Tax IDs.
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
Physical address.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
Physical address
|
|
# File 'lib/stigg/models/v1/customer_update_params.rb', line 382
|
Instance Attribute Details
#billing_address ⇒ Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::BillingAddress?
Physical address
334 335 336 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 334 optional :billing_address, -> { Stigg::V1::CustomerUpdateParams::Passthrough::Stripe::BillingAddress }, api_name: :billingAddress |
#customer_name ⇒ String?
Customer name
342 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 342 optional :customer_name, String, api_name: :customerName |
#invoice_custom_fields ⇒ Hash{Symbol=>String}?
Invoice custom fields
348 349 350 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 348 optional :invoice_custom_fields, Stigg::Internal::Type::HashOf[String], api_name: :invoiceCustomFields |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
356 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 356 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#payment_method_id ⇒ String?
Billing provider payment method id, attached to this customer
362 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 362 optional :payment_method_id, String, api_name: :paymentMethodId |
#shipping_address ⇒ Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::ShippingAddress?
Physical address
368 369 370 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 368 optional :shipping_address, -> { Stigg::V1::CustomerUpdateParams::Passthrough::Stripe::ShippingAddress }, api_name: :shippingAddress |
#tax_ids ⇒ Array<Stigg::Models::V1::CustomerUpdateParams::Passthrough::Stripe::TaxID>?
Tax IDs
376 377 378 379 380 |
# File 'lib/stigg/models/v1/customer_update_params.rb', line 376 optional :tax_ids, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::CustomerUpdateParams::Passthrough::Stripe::TaxID] }, api_name: :taxIds |