Class: Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb

Defined Under Namespace

Modules: Period, ResetPeriod Classes: MonthlyResetPeriodConfiguration, WeeklyResetPeriodConfiguration, YearlyResetPeriodConfiguration

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(custom_end_date:, enum_values:, feature_id:, has_soft_limit:, has_unlimited_usage:, is_visible:, monthly_reset_period_configuration:, period:, reset_period:, usage_limit:, weekly_reset_period_configuration:, yearly_reset_period_configuration:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement for more details.

Single entitlement grant config

Parameters:



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 34

class PromotionalEntitlement < Stigg::Internal::Type::BaseModel
  # @!attribute custom_end_date
  #   The custom end date of the promotional entitlement
  #
  #   @return [Time, nil]
  required :custom_end_date, Time, api_name: :customEndDate, nil?: true

  # @!attribute enum_values
  #   The enum values of the entitlement
  #
  #   @return [Array<String>, nil]
  required :enum_values, Stigg::Internal::Type::ArrayOf[String], api_name: :enumValues, nil?: true

  # @!attribute feature_id
  #   The unique identifier of the entitlement feature
  #
  #   @return [String]
  required :feature_id, String, api_name: :featureId

  # @!attribute has_soft_limit
  #   Whether the entitlement has a soft limit
  #
  #   @return [Boolean, nil]
  required :has_soft_limit, Stigg::Internal::Type::Boolean, api_name: :hasSoftLimit, nil?: true

  # @!attribute has_unlimited_usage
  #   Whether the entitlement has an unlimited usage
  #
  #   @return [Boolean, nil]
  required :has_unlimited_usage,
           Stigg::Internal::Type::Boolean,
           api_name: :hasUnlimitedUsage,
           nil?: true

  # @!attribute is_visible
  #   Whether the entitlement is visible
  #
  #   @return [Boolean, nil]
  required :is_visible, Stigg::Internal::Type::Boolean, api_name: :isVisible, nil?: true

  # @!attribute monthly_reset_period_configuration
  #   The monthly reset period configuration of the entitlement, defined when reset
  #   period is monthly
  #
  #   @return [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration, nil]
  required :monthly_reset_period_configuration,
           -> {
             Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration
           },
           api_name: :monthlyResetPeriodConfiguration,
           nil?: true

  # @!attribute period
  #   The grant period of the promotional entitlement
  #
  #   @return [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period]
  required :period,
           enum: -> { Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period }

  # @!attribute reset_period
  #   The reset period of the entitlement
  #
  #   @return [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::ResetPeriod, nil]
  required :reset_period,
           enum: -> {
             Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::ResetPeriod
           },
           api_name: :resetPeriod,
           nil?: true

  # @!attribute usage_limit
  #   The usage limit of the entitlement
  #
  #   @return [Integer, nil]
  required :usage_limit, Integer, api_name: :usageLimit, nil?: true

  # @!attribute weekly_reset_period_configuration
  #   The weekly reset period configuration of the entitlement, defined when reset
  #   period is weekly
  #
  #   @return [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration, nil]
  required :weekly_reset_period_configuration,
           -> {
             Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration
           },
           api_name: :weeklyResetPeriodConfiguration,
           nil?: true

  # @!attribute yearly_reset_period_configuration
  #   The yearly reset period configuration of the entitlement, defined when reset
  #   period is yearly
  #
  #   @return [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration, nil]
  required :yearly_reset_period_configuration,
           -> {
             Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration
           },
           api_name: :yearlyResetPeriodConfiguration,
           nil?: true

  # @!method initialize(custom_end_date:, enum_values:, feature_id:, has_soft_limit:, has_unlimited_usage:, is_visible:, monthly_reset_period_configuration:, period:, reset_period:, usage_limit:, weekly_reset_period_configuration:, yearly_reset_period_configuration:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement}
  #   for more details.
  #
  #   Single entitlement grant config
  #
  #   @param custom_end_date [Time, nil] The custom end date of the promotional entitlement
  #
  #   @param enum_values [Array<String>, nil] The enum values of the entitlement
  #
  #   @param feature_id [String] The unique identifier of the entitlement feature
  #
  #   @param has_soft_limit [Boolean, nil] Whether the entitlement has a soft limit
  #
  #   @param has_unlimited_usage [Boolean, nil] Whether the entitlement has an unlimited usage
  #
  #   @param is_visible [Boolean, nil] Whether the entitlement is visible
  #
  #   @param monthly_reset_period_configuration [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration, nil] The monthly reset period configuration of the entitlement, defined when reset pe
  #
  #   @param period [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period] The grant period of the promotional entitlement
  #
  #   @param reset_period [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::ResetPeriod, nil] The reset period of the entitlement
  #
  #   @param usage_limit [Integer, nil] The usage limit of the entitlement
  #
  #   @param weekly_reset_period_configuration [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration, nil] The weekly reset period configuration of the entitlement, defined when reset per
  #
  #   @param yearly_reset_period_configuration [Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration, nil] The yearly reset period configuration of the entitlement, defined when reset per

  # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement#monthly_reset_period_configuration
  class MonthlyResetPeriodConfiguration < Stigg::Internal::Type::BaseModel
    # @!attribute according_to
    #   Reset anchor (SubscriptionStart or StartOfTheMonth)
    #
    #   @return [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration::AccordingTo]
    required :according_to,
             enum: -> {
               Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration::AccordingTo
             },
             api_name: :accordingTo

    # @!method initialize(according_to:)
    #   The monthly reset period configuration of the entitlement, defined when reset
    #   period is monthly
    #
    #   @param according_to [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration::AccordingTo] Reset anchor (SubscriptionStart or StartOfTheMonth)

    # Reset anchor (SubscriptionStart or StartOfTheMonth)
    #
    # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration#according_to
    module AccordingTo
      extend Stigg::Internal::Type::Enum

      SUBSCRIPTION_START = :SubscriptionStart
      START_OF_THE_MONTH = :StartOfTheMonth

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # The grant period of the promotional entitlement
  #
  # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement#period
  module Period
    extend Stigg::Internal::Type::Enum

    PERIOD_1_WEEK = :"1 week"
    PERIOD_1_MONTH = :"1 month"
    PERIOD_6_MONTH = :"6 month"
    PERIOD_1_YEAR = :"1 year"
    LIFETIME = :lifetime
    CUSTOM = :custom

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # The reset period of the entitlement
  #
  # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement#reset_period
  module ResetPeriod
    extend Stigg::Internal::Type::Enum

    YEAR = :YEAR
    MONTH = :MONTH
    WEEK = :WEEK
    DAY = :DAY
    HOUR = :HOUR

    # @!method self.values
    #   @return [Array<Symbol>]
  end

  # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement#weekly_reset_period_configuration
  class WeeklyResetPeriodConfiguration < Stigg::Internal::Type::BaseModel
    # @!attribute according_to
    #   Reset anchor (SubscriptionStart or specific day)
    #
    #   @return [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration::AccordingTo]
    required :according_to,
             enum: -> {
               Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration::AccordingTo
             },
             api_name: :accordingTo

    # @!method initialize(according_to:)
    #   The weekly reset period configuration of the entitlement, defined when reset
    #   period is weekly
    #
    #   @param according_to [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration::AccordingTo] Reset anchor (SubscriptionStart or specific day)

    # Reset anchor (SubscriptionStart or specific day)
    #
    # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration#according_to
    module AccordingTo
      extend Stigg::Internal::Type::Enum

      SUBSCRIPTION_START = :SubscriptionStart
      EVERY_SUNDAY = :EverySunday
      EVERY_MONDAY = :EveryMonday
      EVERY_TUESDAY = :EveryTuesday
      EVERY_WEDNESDAY = :EveryWednesday
      EVERY_THURSDAY = :EveryThursday
      EVERY_FRIDAY = :EveryFriday
      EVERY_SATURDAY = :EverySaturday

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end

  # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement#yearly_reset_period_configuration
  class YearlyResetPeriodConfiguration < Stigg::Internal::Type::BaseModel
    # @!attribute according_to
    #   Reset anchor (SubscriptionStart)
    #
    #   @return [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration::AccordingTo]
    required :according_to,
             enum: -> {
               Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration::AccordingTo
             },
             api_name: :accordingTo

    # @!method initialize(according_to:)
    #   The yearly reset period configuration of the entitlement, defined when reset
    #   period is yearly
    #
    #   @param according_to [Symbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration::AccordingTo] Reset anchor (SubscriptionStart)

    # Reset anchor (SubscriptionStart)
    #
    # @see Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration#according_to
    module AccordingTo
      extend Stigg::Internal::Type::Enum

      SUBSCRIPTION_START = :SubscriptionStart

      # @!method self.values
      #   @return [Array<Symbol>]
    end
  end
end

Instance Attribute Details

#custom_end_dateTime?

The custom end date of the promotional entitlement

Returns:

  • (Time, nil)


39
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 39

required :custom_end_date, Time, api_name: :customEndDate, nil?: true

#enum_valuesArray<String>?

The enum values of the entitlement

Returns:

  • (Array<String>, nil)


45
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 45

required :enum_values, Stigg::Internal::Type::ArrayOf[String], api_name: :enumValues, nil?: true

#feature_idString

The unique identifier of the entitlement feature

Returns:

  • (String)


51
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 51

required :feature_id, String, api_name: :featureId

#has_soft_limitBoolean?

Whether the entitlement has a soft limit

Returns:

  • (Boolean, nil)


57
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 57

required :has_soft_limit, Stigg::Internal::Type::Boolean, api_name: :hasSoftLimit, nil?: true

#has_unlimited_usageBoolean?

Whether the entitlement has an unlimited usage

Returns:

  • (Boolean, nil)


63
64
65
66
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 63

required :has_unlimited_usage,
Stigg::Internal::Type::Boolean,
api_name: :hasUnlimitedUsage,
nil?: true

#is_visibleBoolean?

Whether the entitlement is visible

Returns:

  • (Boolean, nil)


72
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 72

required :is_visible, Stigg::Internal::Type::Boolean, api_name: :isVisible, nil?: true

#monthly_reset_period_configurationStigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration?

The monthly reset period configuration of the entitlement, defined when reset period is monthly



79
80
81
82
83
84
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 79

required :monthly_reset_period_configuration,
-> {
  Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::MonthlyResetPeriodConfiguration
},
api_name: :monthlyResetPeriodConfiguration,
nil?: true

#periodSymbol, Stigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period

The grant period of the promotional entitlement



90
91
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 90

required :period,
enum: -> { Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::Period }

#reset_periodSymbol, ...

The reset period of the entitlement



97
98
99
100
101
102
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 97

required :reset_period,
enum: -> {
  Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::ResetPeriod
},
api_name: :resetPeriod,
nil?: true

#usage_limitInteger?

The usage limit of the entitlement

Returns:

  • (Integer, nil)


108
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 108

required :usage_limit, Integer, api_name: :usageLimit, nil?: true

#weekly_reset_period_configurationStigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration?

The weekly reset period configuration of the entitlement, defined when reset period is weekly



115
116
117
118
119
120
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 115

required :weekly_reset_period_configuration,
-> {
  Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::WeeklyResetPeriodConfiguration
},
api_name: :weeklyResetPeriodConfiguration,
nil?: true

#yearly_reset_period_configurationStigg::Models::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration?

The yearly reset period configuration of the entitlement, defined when reset period is yearly



127
128
129
130
131
132
# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 127

required :yearly_reset_period_configuration,
-> {
  Stigg::V1::Customers::PromotionalEntitlementCreateParams::PromotionalEntitlement::YearlyResetPeriodConfiguration
},
api_name: :yearlyResetPeriodConfiguration,
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/customers/promotional_entitlement_create_params.rb', line 192