Class: Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/event_estimate_cost_response.rb,
sig/stigg/models/v1/event_estimate_cost_response.rbs

Defined Under Namespace

Modules: WarningCode

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(cost:, feature_id:, warning_code:) ⇒ Object

Parameters:



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/stigg/models/v1/event_estimate_cost_response.rb', line 93

class Breakdown < Stigg::Internal::Type::BaseModel
  # @!attribute cost
  #   The estimated credit cost contributed by this feature
  #
  #   @return [Float]
  required :cost, Float

  # @!attribute feature_id
  #   The feature whose meter contributed this cost
  #
  #   @return [String]
  required :feature_id, String, api_name: :featureId

  # @!attribute warning_code
  #   Warning explaining why this cost may be inaccurate, if any
  #
  #   @return [Symbol, Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown::WarningCode, nil]
  required :warning_code,
           enum: -> { Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown::WarningCode },
           api_name: :warningCode,
           nil?: true

  # @!method initialize(cost:, feature_id:, warning_code:)
  #   @param cost [Float] The estimated credit cost contributed by this feature
  #
  #   @param feature_id [String] The feature whose meter contributed this cost
  #
  #   @param warning_code [Symbol, Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown::WarningCode, nil] Warning explaining why this cost may be inaccurate, if any

  # Warning explaining why this cost may be inaccurate, if any
  #
  # @see Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown#warning_code
  module WarningCode
    extend Stigg::Internal::Type::Enum

    UNSUPPORTED_AGGREGATION = :UNSUPPORTED_AGGREGATION

    # @!method self.values
    #   @return [Array<Symbol>]
  end
end

Instance Attribute Details

#costFloat

The estimated credit cost contributed by this feature

Parameters:

  • value (Float)

Returns:

  • (Float)


98
# File 'lib/stigg/models/v1/event_estimate_cost_response.rb', line 98

required :cost, Float

#feature_idString

The feature whose meter contributed this cost

Parameters:

  • value (String)

Returns:

  • (String)


104
# File 'lib/stigg/models/v1/event_estimate_cost_response.rb', line 104

required :feature_id, String, api_name: :featureId

#warning_codeSymbol, ...

Warning explaining why this cost may be inaccurate, if any

Parameters:

  • value (Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown::warning_code, nil)

Returns:



110
111
112
113
# File 'lib/stigg/models/v1/event_estimate_cost_response.rb', line 110

required :warning_code,
enum: -> { Stigg::Models::V1::EventEstimateCostResponse::Data::Estimate::Breakdown::WarningCode },
api_name: :warningCode,
nil?: true

Instance Method Details

#to_hash{

Returns:

  • ({)


100
# File 'sig/stigg/models/v1/event_estimate_cost_response.rbs', line 100

def to_hash: -> {