Class: Stigg::Models::V1::Events::Beta::CustomerRetrieveGovernanceParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb

Overview

Defined Under Namespace

Modules: Order, Scope, SortBy

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, after: nil, currency_ids: nil, entity_id_search: nil, entity_type_ids: nil, feature_ids: nil, limit: nil, min_utilization: nil, order: nil, scope: nil, sort_by: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::Events::Beta::CustomerRetrieveGovernanceParams for more details.

Parameters:

  • id (String)
  • after (String) (defaults to: nil)

    Return items that come after this cursor

  • currency_ids (Array<String>) (defaults to: nil)

    Currency ids to include, repeated per value (e.g. ‘?currencyIds=credits`). Omit

  • entity_id_search (String) (defaults to: nil)

    Case-insensitive substring match on the entity id (‘%`/`_` matched literally).

  • entity_type_ids (Array<String>) (defaults to: nil)

    Filter to one or more entity types, repeated per value (e.g. ‘?entityTypeIds=tea

  • feature_ids (Array<String>) (defaults to: nil)

    Feature ids to include, repeated per value (e.g. ‘?featureIds=ai-tokens&featureI

  • limit (Integer) (defaults to: nil)

    Maximum number of items to return

  • min_utilization (Float) (defaults to: nil)

    Only nodes with utilization ≥ this value (e.g. 0.8 for ≥80%, 1 for at/over limit

  • order (Symbol, Stigg::Models::V1::Events::Beta::CustomerRetrieveGovernanceParams::Order) (defaults to: nil)

    Sort direction: ‘asc` or `desc` (default `desc`).

  • scope (Symbol, Stigg::Models::V1::Events::Beta::CustomerRetrieveGovernanceParams::Scope) (defaults to: nil)

    Filter by configuration scope: ‘all` (default), `nodeWide` (`[]` only), or `scop

  • sort_by (Symbol, Stigg::Models::V1::Events::Beta::CustomerRetrieveGovernanceParams::SortBy) (defaults to: nil)

    Sort key: ‘utilization` (default, cross-capability-safe), `currentUsage`, `usage

  • x_account_id (String) (defaults to: nil)
  • x_environment_id (String) (defaults to: nil)
  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 96

Instance Attribute Details

#afterString?

Return items that come after this cursor

Returns:

  • (String, nil)


22
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 22

optional :after, String

#currency_idsArray<String>?

Currency ids to include, repeated per value (e.g. ‘?currencyIds=credits`). Omit both featureIds and currencyIds for tree mode.

Returns:

  • (Array<String>, nil)


29
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 29

optional :currency_ids, Stigg::Internal::Type::ArrayOf[String]

#entity_id_searchString?

Case-insensitive substring match on the entity id (‘%`/`_` matched literally).

Returns:

  • (String, nil)


35
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 35

optional :entity_id_search, String

#entity_type_idsArray<String>?

Filter to one or more entity types, repeated per value (e.g. ‘?entityTypeIds=team&entityTypeIds=user`).

Returns:

  • (Array<String>, nil)


42
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 42

optional :entity_type_ids, Stigg::Internal::Type::ArrayOf[String]

#feature_idsArray<String>?

Feature ids to include, repeated per value (e.g. ‘?featureIds=ai-tokens&featureIds=seats`). Omit both featureIds and currencyIds for tree mode — every node in the hierarchy with no usage configuration attached.

Returns:

  • (Array<String>, nil)


51
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 51

optional :feature_ids, Stigg::Internal::Type::ArrayOf[String]

#idString

Returns:

  • (String)


16
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 16

required :id, String

#limitInteger?

Maximum number of items to return

Returns:

  • (Integer, nil)


57
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 57

optional :limit, Integer

#min_utilizationFloat?

Only nodes with utilization ≥ this value (e.g. 0.8 for ≥80%, 1 for at/over limit).

Returns:

  • (Float, nil)


64
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 64

optional :min_utilization, Float

#orderSymbol, ...

Sort direction: ‘asc` or `desc` (default `desc`).



70
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 70

optional :order, enum: -> { Stigg::V1::Events::Beta::CustomerRetrieveGovernanceParams::Order }

#scopeSymbol, ...

Filter by configuration scope: ‘all` (default), `nodeWide` (`[]` only), or `scoped` (non-empty only).



77
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 77

optional :scope, enum: -> { Stigg::V1::Events::Beta::CustomerRetrieveGovernanceParams::Scope }

#sort_bySymbol, ...

Sort key: ‘utilization` (default, cross-capability-safe), `currentUsage`, `usageLimit`, `scopeSize`, `id`, or `createdAt`.



84
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 84

optional :sort_by, enum: -> { Stigg::V1::Events::Beta::CustomerRetrieveGovernanceParams::SortBy }

#x_account_idString?

Returns:

  • (String, nil)


89
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 89

optional :x_account_id, String

#x_environment_idString?

Returns:

  • (String, nil)


94
# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 94

optional :x_environment_id, String

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/events/beta/customer_retrieve_governance_params.rb', line 136