Class: Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, currency_id: nil, dimensions: nil, feature_id: nil, requested_usage: nil, requested_values: nil, resource_id: nil, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckParams for more details.

Parameters:

  • id (String)
  • currency_id (String) (defaults to: nil)

    Currency ID (refId) to check for credit entitlements. Mutually exclusive with ‘f

  • dimensions (Hash{Symbol=>String}) (defaults to: nil)

    Optional attribution map (e.g. ‘dimensions=u1`). When provided, the resp

  • feature_id (String) (defaults to: nil)

    Feature ID (refId) to check. Mutually exclusive with ‘currencyId`.

  • requested_usage (Integer) (defaults to: nil)

    Requested usage amount to evaluate against the entitlement limit (numeric featur

  • requested_values (Array<String>) (defaults to: nil)

    Requested values to evaluate against allowed values (enum features only)

  • resource_id (String) (defaults to: nil)

    Resource ID to scope the entitlement check to a specific resource

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 58

Instance Attribute Details

#currency_idString?

Currency ID (refId) to check for credit entitlements. Mutually exclusive with ‘featureId`.

Returns:

  • (String, nil)


24
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 24

optional :currency_id, String

#dimensionsHash{Symbol=>String}?

Optional attribution map (e.g. ‘dimensions=u1`). When provided, the response includes a `chains` array with per-entity governance limits.

Returns:

  • (Hash{Symbol=>String}, nil)


31
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 31

optional :dimensions, Stigg::Internal::Type::HashOf[String]

#feature_idString?

Feature ID (refId) to check. Mutually exclusive with ‘currencyId`.

Returns:

  • (String, nil)


37
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 37

optional :feature_id, String

#idString

Returns:

  • (String)


17
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 17

required :id, String

#requested_usageInteger?

Requested usage amount to evaluate against the entitlement limit (numeric features only)

Returns:

  • (Integer, nil)


44
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 44

optional :requested_usage, Integer

#requested_valuesArray<String>?

Requested values to evaluate against allowed values (enum features only)

Returns:

  • (Array<String>, nil)


50
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 50

optional :requested_values, Stigg::Internal::Type::ArrayOf[String]

#resource_idString?

Resource ID to scope the entitlement check to a specific resource

Returns:

  • (String, nil)


56
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 56

optional :resource_id, String