Class: Stigg::Models::V1::Events::CreditGetUsageResponse::Data::Series
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::CreditGetUsageResponse::Data::Series
- Defined in:
- lib/stigg/models/v1/events/credit_get_usage_response.rb
Defined Under Namespace
Classes: Point
Instance Attribute Summary collapse
-
#feature_id ⇒ String
The feature ID.
-
#feature_name ⇒ String
The display name of the feature.
-
#points ⇒ Array<Stigg::Models::V1::Events::CreditGetUsageResponse::Data::Series::Point>
Time-series data points for this feature.
-
#total_credits ⇒ Float
Total credits consumed by this feature in the time range.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#feature_id ⇒ String
The feature ID
93 |
# File 'lib/stigg/models/v1/events/credit_get_usage_response.rb', line 93 required :feature_id, String, api_name: :featureId |
#feature_name ⇒ String
The display name of the feature
99 |
# File 'lib/stigg/models/v1/events/credit_get_usage_response.rb', line 99 required :feature_name, String, api_name: :featureName |
#points ⇒ Array<Stigg::Models::V1::Events::CreditGetUsageResponse::Data::Series::Point>
Time-series data points for this feature
105 106 |
# File 'lib/stigg/models/v1/events/credit_get_usage_response.rb', line 105 required :points, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::Events::CreditGetUsageResponse::Data::Series::Point] } |
#total_credits ⇒ Float
Total credits consumed by this feature in the time range
112 |
# File 'lib/stigg/models/v1/events/credit_get_usage_response.rb', line 112 required :total_credits, Float, api_name: :totalCredits |