Class: Stigg::Models::V1::Events::CreditListLedgerResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::CreditListLedgerResponse
- Defined in:
- lib/stigg/models/v1/events/credit_list_ledger_response.rb
Overview
Defined Under Namespace
Modules: EventType
Instance Attribute Summary collapse
-
#amount ⇒ Float
The credit amount for this event.
-
#credit_currency_id ⇒ String
The credit currency ID.
-
#credit_grant_id ⇒ String
The credit grant ID associated with this event.
-
#customer_id ⇒ String
The customer ID this event belongs to.
-
#event_id ⇒ String?
The unique event identifier.
-
#event_type ⇒ Symbol, Stigg::Models::V1::Events::CreditListLedgerResponse::EventType
The type of credit event.
-
#feature_id ⇒ String?
The feature ID associated with this event.
-
#resource_id ⇒ String?
The resource ID this event is scoped to.
-
#timestamp ⇒ Time
The timestamp when the event occurred.
Instance Method Summary collapse
-
#initialize(amount:, credit_currency_id:, credit_grant_id:, customer_id:, event_id:, event_type:, feature_id:, resource_id:, timestamp:) ⇒ Object
constructor
A credit ledger event representing a change to credit balance.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, credit_currency_id:, credit_grant_id:, customer_id:, event_id:, event_type:, feature_id:, resource_id:, timestamp:) ⇒ Object
A credit ledger event representing a change to credit balance
|
|
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 65
|
Instance Attribute Details
#amount ⇒ Float
The credit amount for this event
13 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 13 required :amount, Float |
#credit_currency_id ⇒ String
The credit currency ID
19 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 19 required :credit_currency_id, String, api_name: :creditCurrencyId |
#credit_grant_id ⇒ String
The credit grant ID associated with this event
25 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 25 required :credit_grant_id, String, api_name: :creditGrantId |
#customer_id ⇒ String
The customer ID this event belongs to
31 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 31 required :customer_id, String, api_name: :customerId |
#event_id ⇒ String?
The unique event identifier
37 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 37 required :event_id, String, api_name: :eventId, nil?: true |
#event_type ⇒ Symbol, Stigg::Models::V1::Events::CreditListLedgerResponse::EventType
The type of credit event
43 44 45 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 43 required :event_type, enum: -> { Stigg::Models::V1::Events::CreditListLedgerResponse::EventType }, api_name: :eventType |
#feature_id ⇒ String?
The feature ID associated with this event
51 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 51 required :feature_id, String, api_name: :featureId, nil?: true |
#resource_id ⇒ String?
The resource ID this event is scoped to
57 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 57 required :resource_id, String, api_name: :resourceId, nil?: true |
#timestamp ⇒ Time
The timestamp when the event occurred
63 |
# File 'lib/stigg/models/v1/events/credit_list_ledger_response.rb', line 63 required :timestamp, Time |