Class: Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/events/credits/custom_currency_create_params.rb
Overview
Defined Under Namespace
Classes: Units
Instance Attribute Summary collapse
-
#description ⇒ String?
Description of the currency.
-
#display_name ⇒ String
The display name of the custom currency.
-
#id ⇒ String
The unique identifier for the new custom currency.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata to attach to the custom currency.
-
#symbol ⇒ String?
The symbol used to represent the custom currency.
-
#units ⇒ Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams::Units?
Singular and plural unit labels for a custom currency.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
Description of the currency
29 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 29 optional :description, String |
#display_name ⇒ String
The display name of the custom currency
23 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 23 required :display_name, String, api_name: :displayName |
#id ⇒ String
The unique identifier for the new custom currency
17 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 17 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata to attach to the custom currency
35 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 35 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#symbol ⇒ String?
The symbol used to represent the custom currency
41 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 41 optional :symbol, String |
#units ⇒ Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams::Units?
Singular and plural unit labels for a custom currency. Both fields are required when supplied.
48 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 48 optional :units, -> { Stigg::V1::Events::Credits::CustomCurrencyCreateParams::Units } |