Class: Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams::Units
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Credits::CustomCurrencyCreateParams::Units
- Defined in:
- lib/stigg/models/v1/events/credits/custom_currency_create_params.rb
Instance Attribute Summary collapse
-
#plural ⇒ String
Plural form of the unit label.
-
#singular ⇒ String
Singular form of the unit label.
Instance Method Summary collapse
-
#initialize(plural:, singular:) ⇒ Object
constructor
Singular and plural unit labels for a custom currency.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(plural:, singular:) ⇒ Object
Singular and plural unit labels for a custom currency. Both fields are required when supplied.
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 69 class Units < Stigg::Internal::Type::BaseModel # @!attribute plural # Plural form of the unit label # # @return [String] required :plural, String # @!attribute singular # Singular form of the unit label # # @return [String] required :singular, String # @!method initialize(plural:, singular:) # Singular and plural unit labels for a custom currency. Both fields are required # when supplied. # # @param plural [String] Plural form of the unit label # # @param singular [String] Singular form of the unit label end |
Instance Attribute Details
#plural ⇒ String
Plural form of the unit label
74 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 74 required :plural, String |
#singular ⇒ String
Singular form of the unit label
80 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_create_params.rb', line 80 required :singular, String |