Class: Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/events/credits/custom_currency_update_params.rb
Overview
Defined Under Namespace
Classes: Units
Instance Attribute Summary collapse
- #currency_id ⇒ String
-
#description ⇒ String?
A human-readable description of the custom currency.
-
#display_name ⇒ String?
The display name of the custom currency.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata to attach to the custom currency.
-
#symbol ⇒ String?
The symbol used to represent the custom currency.
-
#units ⇒ Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateParams::Units?
Singular and plural unit labels for a custom currency.
Attributes included from Internal::Type::RequestParameters
Method Summary
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#currency_id ⇒ String
16 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 16 required :currency_id, String |
#description ⇒ String?
A human-readable description of the custom currency. Send an empty string to clear.
23 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 23 optional :description, String, nil?: true |
#display_name ⇒ String?
The display name of the custom currency
29 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 29 optional :display_name, String, api_name: :displayName |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata to attach to the custom currency
35 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 35 optional :metadata, Stigg::Internal::Type::HashOf[String], nil?: true |
#symbol ⇒ String?
The symbol used to represent the custom currency. Send an empty string to clear.
41 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 41 optional :symbol, String, nil?: true |
#units ⇒ Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateParams::Units?
Singular and plural unit labels for a custom currency. Both fields are required when supplied.
48 |
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 48 optional :units, -> { Stigg::V1::Events::Credits::CustomCurrencyUpdateParams::Units } |