Class: Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateParams::Units

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/events/credits/custom_currency_update_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(plural:, singular:) ⇒ Object

Singular and plural unit labels for a custom currency. Both fields are required when supplied.

Parameters:

  • plural (String)

    Plural form of the unit label

  • singular (String)

    Singular form of the unit label



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 69

class Units < Stigg::Internal::Type::BaseModel
  # @!attribute plural
  #   Plural form of the unit label
  #
  #   @return [String]
  required :plural, String

  # @!attribute singular
  #   Singular form of the unit label
  #
  #   @return [String]
  required :singular, String

  # @!method initialize(plural:, singular:)
  #   Singular and plural unit labels for a custom currency. Both fields are required
  #   when supplied.
  #
  #   @param plural [String] Plural form of the unit label
  #
  #   @param singular [String] Singular form of the unit label
end

Instance Attribute Details

#pluralString

Plural form of the unit label

Returns:

  • (String)


74
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 74

required :plural, String

#singularString

Singular form of the unit label

Returns:

  • (String)


80
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_params.rb', line 80

required :singular, String