Class: Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/events/credits/custom_currency_update_response.rb

Overview

See Also:

Defined Under Namespace

Classes: Units

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, created_at:, description:, display_name:, metadata:, symbol:, units:, updated_at:) ⇒ Object

A custom currency used to denominate credit-based entitlements and pricing

Parameters:

  • id (String)

    The unique identifier for the custom currency

  • archived_at (Time, nil)

    Timestamp of when the record was deleted

  • created_at (Time)

    Timestamp of when the record was created

  • description (String, nil)

    Description of the currency

  • display_name (String)

    The display name of the custom currency

  • metadata (Hash{Symbol=>String})

    Metadata associated with the entity

  • symbol (String, nil)

    The symbol used to represent the custom currency

  • units (Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateResponse::Data::Units, nil)

    Singular and plural unit labels for a custom currency

  • updated_at (Time)

    Timestamp of when the record was last updated



# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 79

Instance Attribute Details

#archived_atTime?

Timestamp of when the record was deleted

Returns:

  • (Time, nil)


33
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 33

required :archived_at, Time, api_name: :archivedAt, nil?: true

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


39
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 39

required :created_at, Time, api_name: :createdAt

#descriptionString?

Description of the currency

Returns:

  • (String, nil)


45
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 45

required :description, String, nil?: true

#display_nameString

The display name of the custom currency

Returns:

  • (String)


51
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 51

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the custom currency

Returns:

  • (String)


27
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 27

required :id, String

#metadataHash{Symbol=>String}

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String})


57
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 57

required :metadata, Stigg::Internal::Type::HashOf[String]

#symbolString?

The symbol used to represent the custom currency

Returns:

  • (String, nil)


63
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 63

required :symbol, String, nil?: true

#unitsStigg::Models::V1::Events::Credits::CustomCurrencyUpdateResponse::Data::Units?

Singular and plural unit labels for a custom currency



69
70
71
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 69

required :units,
-> { Stigg::Models::V1::Events::Credits::CustomCurrencyUpdateResponse::Data::Units },
nil?: true

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


77
# File 'lib/stigg/models/v1/events/credits/custom_currency_update_response.rb', line 77

required :updated_at, Time, api_name: :updatedAt