Class: Stigg::Models::V1::Events::Credits::GrantCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Credits::GrantCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/events/credits/grant_create_params.rb
Overview
Defined Under Namespace
Modules: GrantType, PaymentCollectionMethod Classes: BillingInformation, Cost
Instance Attribute Summary collapse
-
#amount ⇒ Float
The credit amount to grant.
-
#await_payment_confirmation ⇒ Boolean?
Whether to wait for payment confirmation before returning (default: true).
-
#billing_information ⇒ Stigg::Models::V1::Events::Credits::GrantCreateParams::BillingInformation?
Billing information for the credit grant.
-
#comment ⇒ String?
An optional comment on the credit grant.
-
#cost ⇒ Stigg::Models::V1::Events::Credits::GrantCreateParams::Cost?
The monetary cost of the credit grant.
-
#currency_id ⇒ String
The credit currency ID (required).
-
#customer_id ⇒ String
The customer ID to grant credits to (required).
-
#display_name ⇒ String
The display name for the credit grant.
-
#effective_at ⇒ Time?
The date when the credit grant becomes effective.
-
#expire_at ⇒ Time?
The date when the credit grant expires.
-
#grant_type ⇒ Symbol, Stigg::Models::V1::Events::Credits::GrantCreateParams::GrantType
The type of credit grant (PAID, PROMOTIONAL, RECURRING).
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the credit grant.
-
#payment_collection_method ⇒ Symbol, ...
The payment collection method (CHARGE, INVOICE, NONE).
-
#priority ⇒ Integer?
The priority of the credit grant (lower number = higher priority).
-
#resource_id ⇒ String?
The resource ID to scope the grant to.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
constructor
The billing address.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(city: nil, country: nil, line1: nil, line2: nil, postal_code: nil, state: nil) ⇒ Object
The billing address
|
|
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 111
|
Instance Attribute Details
#amount ⇒ Float
The credit amount to grant
17 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 17 required :amount, Float |
#await_payment_confirmation ⇒ Boolean?
Whether to wait for payment confirmation before returning (default: true)
49 50 51 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 49 optional :await_payment_confirmation, Stigg::Internal::Type::Boolean, api_name: :awaitPaymentConfirmation |
#billing_information ⇒ Stigg::Models::V1::Events::Credits::GrantCreateParams::BillingInformation?
Billing information for the credit grant
57 58 59 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 57 optional :billing_information, -> { Stigg::V1::Events::Credits::GrantCreateParams::BillingInformation }, api_name: :billingInformation |
#comment ⇒ String?
An optional comment on the credit grant
65 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 65 optional :comment, String |
#cost ⇒ Stigg::Models::V1::Events::Credits::GrantCreateParams::Cost?
The monetary cost of the credit grant
71 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 71 optional :cost, -> { Stigg::V1::Events::Credits::GrantCreateParams::Cost } |
#currency_id ⇒ String
The credit currency ID (required)
23 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 23 required :currency_id, String, api_name: :currencyId |
#customer_id ⇒ String
The customer ID to grant credits to (required)
29 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 29 required :customer_id, String, api_name: :customerId |
#display_name ⇒ String
The display name for the credit grant
35 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 35 required :display_name, String, api_name: :displayName |
#effective_at ⇒ Time?
The date when the credit grant becomes effective
77 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 77 optional :effective_at, Time, api_name: :effectiveAt |
#expire_at ⇒ Time?
The date when the credit grant expires
83 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 83 optional :expire_at, Time, api_name: :expireAt |
#grant_type ⇒ Symbol, Stigg::Models::V1::Events::Credits::GrantCreateParams::GrantType
The type of credit grant (PAID, PROMOTIONAL, RECURRING)
41 42 43 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 41 required :grant_type, enum: -> { Stigg::V1::Events::Credits::GrantCreateParams::GrantType }, api_name: :grantType |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the credit grant
89 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 89 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#payment_collection_method ⇒ Symbol, ...
The payment collection method (CHARGE, INVOICE, NONE)
95 96 97 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 95 optional :payment_collection_method, enum: -> { Stigg::V1::Events::Credits::GrantCreateParams::PaymentCollectionMethod }, api_name: :paymentCollectionMethod |
#priority ⇒ Integer?
The priority of the credit grant (lower number = higher priority)
103 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 103 optional :priority, Integer |
#resource_id ⇒ String?
The resource ID to scope the grant to
109 |
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 109 optional :resource_id, String, api_name: :resourceId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/events/credits/grant_create_params.rb', line 153
|