Class: Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus

Inherits:
Internal::Type::BaseModel
  • Object
show all
Defined in:
lib/stigg/models/v1/events/data_export/destination_delete_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(finished_at:, status:, transfer_id:, blamed_party: nil, failure_message: nil, rows_transferred: nil) ⇒ Object

Latest sync snapshot for the destination, refreshed by the provider webhook

Parameters:

  • finished_at (String)

    ISO8601 timestamp of when the latest sync finished

  • status (String)

    Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED)

  • transfer_id (String)

    Provider transfer ID of the latest sync

  • blamed_party (String) (defaults to: nil)

    Party responsible for a failed sync, as reported by the data-export provider

  • failure_message (String) (defaults to: nil)

    Customer-friendly failure message, when the latest sync failed

  • rows_transferred (Float) (defaults to: nil)

    Number of rows transferred in the latest sync



# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 119

Instance Attribute Details

#blamed_partyString?

Party responsible for a failed sync, as reported by the data-export provider

Returns:

  • (String, nil)


105
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 105

optional :blamed_party, String, api_name: :blamedParty

#failure_messageString?

Customer-friendly failure message, when the latest sync failed

Returns:

  • (String, nil)


111
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 111

optional :failure_message, String, api_name: :failureMessage

#finished_atString

ISO8601 timestamp of when the latest sync finished

Returns:

  • (String)


87
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 87

required :finished_at, String, api_name: :finishedAt

#rows_transferredFloat?

Number of rows transferred in the latest sync

Returns:

  • (Float, nil)


117
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 117

optional :rows_transferred, Float, api_name: :rowsTransferred

#statusString

Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED)

Returns:

  • (String)


93
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 93

required :status, String

#transfer_idString

Provider transfer ID of the latest sync

Returns:

  • (String)


99
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 99

required :transfer_id, String, api_name: :transferId