Class: Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/events/data_export_list_models_response.rb

Defined Under Namespace

Classes: Model

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(groups:) ⇒ Object

Grouped catalog of every data-export model a destination can opt into.

Parameters:



34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 34

class Group < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   Stable group identifier
  #
  #   @return [String]
  required :id, String

  # @!attribute display_name
  #   Customer-facing group label
  #
  #   @return [String]
  required :display_name, String, api_name: :displayName

  # @!attribute models
  #   Models in this group
  #
  #   @return [Array<Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model>]
  required :models,
           -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model] }

  # @!method initialize(id:, display_name:, models:)
  #   A group of related data-export models, mirroring the public docs taxonomy.
  #
  #   @param id [String] Stable group identifier
  #
  #   @param display_name [String] Customer-facing group label
  #
  #   @param models [Array<Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model>] Models in this group

  class Model < Stigg::Internal::Type::BaseModel
    # @!attribute id
    #   Wire identifier — what gets persisted on the destination and registered with the
    #   provider
    #
    #   @return [String]
    required :id, String

    # @!attribute display_name
    #   Customer-facing label for the model
    #
    #   @return [String]
    required :display_name, String, api_name: :displayName

    # @!method initialize(id:, display_name:)
    #   Some parameter documentations has been truncated, see
    #   {Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model}
    #   for more details.
    #
    #   A single data-export model the customer can opt into.
    #
    #   @param id [String] Wire identifier — what gets persisted on the destination and registered with the
    #
    #   @param display_name [String] Customer-facing label for the model
  end
end

Instance Attribute Details

#display_nameString

Customer-facing group label

Returns:

  • (String)


45
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 45

required :display_name, String, api_name: :displayName

#idString

Stable group identifier

Returns:

  • (String)


39
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 39

required :id, String

#modelsArray<Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model>

Models in this group



51
52
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 51

required :models,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model] }