Class: Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/events/data_export_list_models_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, display_name:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model for more details.

A single data-export model the customer can opt into.

Parameters:

  • id (String)

    Wire identifier — what gets persisted on the destination and registered with the

  • display_name (String)

    Customer-facing label for the model



63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 63

class Model < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   Wire identifier — what gets persisted on the destination and registered with the
  #   provider
  #
  #   @return [String]
  required :id, String

  # @!attribute display_name
  #   Customer-facing label for the model
  #
  #   @return [String]
  required :display_name, String, api_name: :displayName

  # @!method initialize(id:, display_name:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1::Events::DataExportListModelsResponse::Data::Group::Model}
  #   for more details.
  #
  #   A single data-export model the customer can opt into.
  #
  #   @param id [String] Wire identifier — what gets persisted on the destination and registered with the
  #
  #   @param display_name [String] Customer-facing label for the model
end

Instance Attribute Details

#display_nameString

Customer-facing label for the model

Returns:

  • (String)


75
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 75

required :display_name, String, api_name: :displayName

#idString

Wire identifier — what gets persisted on the destination and registered with the provider

Returns:

  • (String)


69
# File 'lib/stigg/models/v1/events/data_export_list_models_response.rb', line 69

required :id, String