Class: Stigg::Models::V1::FeatureCreateFeatureParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/feature_create_feature_params.rb

Overview

Defined Under Namespace

Modules: FeatureStatus, FeatureType, MeterType Classes: EnumConfiguration, UnitTransformation

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Class Method Summary collapse

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(display_name:, value:) ⇒ Object

Parameters:

  • display_name (String)

    The display name for the enum configuration entity

  • value (String)

    The unique value identifier for the enum configuration entity



# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 92

Instance Attribute Details

#descriptionString?

The description for the feature

Returns:

  • (String, nil)


35
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 35

optional :description, String

#display_nameString

The display name for the feature

Returns:

  • (String)


21
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 21

required :display_name, String, api_name: :displayName

#enum_configurationArray<Stigg::Models::V1::FeatureCreateFeatureParams::EnumConfiguration>?

The configuration data for the feature



41
42
43
44
45
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 41

optional :enum_configuration,
-> {
  Stigg::Internal::Type::ArrayOf[Stigg::V1::FeatureCreateFeatureParams::EnumConfiguration]
},
api_name: :enumConfiguration

#feature_statusSymbol, ...

The status of the feature



51
52
53
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 51

optional :feature_status,
enum: -> { Stigg::V1::FeatureCreateFeatureParams::FeatureStatus },
api_name: :featureStatus

#feature_typeSymbol, Stigg::Models::V1::FeatureCreateFeatureParams::FeatureType

The type of the feature



27
28
29
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 27

required :feature_type,
enum: -> { Stigg::V1::FeatureCreateFeatureParams::FeatureType },
api_name: :featureType

#feature_unitsString?

The units for the feature

Returns:

  • (String, nil)


59
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 59

optional :feature_units, String, api_name: :featureUnits

#feature_units_pluralString?

The plural units for the feature

Returns:

  • (String, nil)


65
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 65

optional :feature_units_plural, String, api_name: :featureUnitsPlural

#idString

The unique identifier for the feature

Returns:

  • (String)


15
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 15

required :id, String

#metadataHash{Symbol=>String}?

The additional metadata for the feature

Returns:

  • (Hash{Symbol=>String}, nil)


71
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 71

optional :metadata, Stigg::Internal::Type::HashOf[String]

#meter_typeSymbol, ...

The meter type for the feature



77
78
79
80
81
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 77

optional :meter_type,
enum: -> {
  Stigg::V1::FeatureCreateFeatureParams::MeterType
},
api_name: :meterType

#unit_transformationStigg::Models::V1::FeatureCreateFeatureParams::UnitTransformation?

Unit transformation to be applied to the reported usage



87
88
89
90
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 87

optional :unit_transformation,
-> { Stigg::V1::FeatureCreateFeatureParams::UnitTransformation },
api_name: :unitTransformation,
nil?: true

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 125