Class: Stigg::Models::V1::FeatureListFeaturesResponse::EnumConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureListFeaturesResponse::EnumConfiguration
- Defined in:
- lib/stigg/models/v1/feature_list_features_response.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name for the enum configuration entity.
-
#value ⇒ String
The unique value identifier for the enum configuration entity.
Instance Method Summary collapse
-
#initialize(id:, created_at:, description:, display_name:, enum_configuration:, feature_status:, feature_type:, feature_units:, feature_units_plural:, metadata:, meter_type:, unit_transformation:, updated_at:) ⇒ Object
constructor
Feature configuration object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, description:, display_name:, enum_configuration:, feature_status:, feature_type:, feature_units:, feature_units_plural:, metadata:, meter_type:, unit_transformation:, updated_at:) ⇒ Object
Feature configuration object
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 127 class EnumConfiguration < Stigg::Internal::Type::BaseModel # @!attribute display_name # The display name for the enum configuration entity # # @return [String] required :display_name, String, api_name: :displayName # @!attribute value # The unique value identifier for the enum configuration entity # # @return [String] required :value, String # @!method initialize(display_name:, value:) # @param display_name [String] The display name for the enum configuration entity # # @param value [String] The unique value identifier for the enum configuration entity end |
Instance Attribute Details
#display_name ⇒ String
The display name for the enum configuration entity
132 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 132 required :display_name, String, api_name: :displayName |
#value ⇒ String
The unique value identifier for the enum configuration entity
138 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 138 required :value, String |