Class: Stigg::Models::V1::FeatureUpdateFeatureParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureUpdateFeatureParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/feature_update_feature_params.rb
Overview
Defined Under Namespace
Classes: EnumConfiguration, Meter, UnitTransformation
Instance Attribute Summary collapse
-
#description ⇒ String?
The description for the feature.
-
#display_name ⇒ String?
The display name for the feature.
-
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration>?
The configuration data for the feature.
-
#feature_units ⇒ String?
The units for the feature.
-
#feature_units_plural ⇒ String?
The plural units for the feature.
- #id ⇒ String
-
#metadata ⇒ Hash{Symbol=>String}?
The additional metadata for the feature.
- #meter ⇒ Stigg::Models::V1::FeatureUpdateFeatureParams::Meter?
-
#unit_transformation ⇒ Stigg::Models::V1::FeatureUpdateFeatureParams::UnitTransformation?
Unit transformation to be applied to the reported usage.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(display_name:, value:) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_name:, value:) ⇒ Object
|
|
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 104
|
Instance Attribute Details
#description ⇒ String?
The description for the feature
20 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 20 optional :description, String |
#display_name ⇒ String?
The display name for the feature
26 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 26 optional :display_name, String, api_name: :displayName |
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration>?
The configuration data for the feature
32 33 34 35 36 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 32 optional :enum_configuration, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::FeatureUpdateFeatureParams::EnumConfiguration] }, api_name: :enumConfiguration |
#feature_units ⇒ String?
The units for the feature
42 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 42 optional :feature_units, String, api_name: :featureUnits |
#feature_units_plural ⇒ String?
The plural units for the feature
48 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 48 optional :feature_units_plural, String, api_name: :featureUnitsPlural |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 14 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
The additional metadata for the feature
54 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 54 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#meter ⇒ Stigg::Models::V1::FeatureUpdateFeatureParams::Meter?
59 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 59 optional :meter, -> { Stigg::V1::FeatureUpdateFeatureParams::Meter } |
#unit_transformation ⇒ Stigg::Models::V1::FeatureUpdateFeatureParams::UnitTransformation?
Unit transformation to be applied to the reported usage
65 66 67 68 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 65 optional :unit_transformation, -> { Stigg::V1::FeatureUpdateFeatureParams::UnitTransformation }, api_name: :unitTransformation, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 220
|