Class: Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration
- Defined in:
- lib/stigg/models/v1/feature_update_feature_params.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name for the enum configuration entity.
-
#value ⇒ String
The unique value identifier for the enum configuration entity.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, description: nil, display_name: nil, enum_configuration: nil, feature_units: nil, feature_units_plural: nil, metadata: nil, meter: nil, unit_transformation: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 105 class EnumConfiguration < Stigg::Internal::Type::BaseModel # @!attribute display_name # The display name for the enum configuration entity # # @return [String] required :display_name, String, api_name: :displayName # @!attribute value # The unique value identifier for the enum configuration entity # # @return [String] required :value, String # @!method initialize(display_name:, value:) # @param display_name [String] The display name for the enum configuration entity # # @param value [String] The unique value identifier for the enum configuration entity end |
Instance Attribute Details
#display_name ⇒ String
The display name for the enum configuration entity
110 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 110 required :display_name, String, api_name: :displayName |
#value ⇒ String
The unique value identifier for the enum configuration entity
116 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 116 required :value, String |