Class: Stigg::Models::V1::Plan::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/plan.rb

Overview

See Also:

Defined Under Namespace

Modules: PricingType, Status Classes: DefaultTrialConfig, Entitlement

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, billing_id:, compatible_addon_ids:, created_at:, default_trial_config:, description:, display_name:, entitlements:, is_latest:, metadata:, parent_plan_id:, pricing_type:, product_id:, status:, updated_at:, version_number:) ⇒ Object

Plan configuration object

Parameters:

  • id (String)

    The unique identifier for the entity

  • billing_id (String, nil)

    The unique identifier for the entity in the billing provider

  • compatible_addon_ids (Array<String>, nil)
  • created_at (Time)

    Timestamp of when the record was created

  • default_trial_config (Stigg::Models::V1::Plan::Data::DefaultTrialConfig, nil)

    Default trial configuration for the plan

  • description (String, nil)

    The description of the package

  • display_name (String)

    The display name of the package

  • entitlements (Array<Stigg::Models::V1::Plan::Data::Entitlement>)

    List of entitlements of the package

  • is_latest (Boolean, nil)

    Indicates if the package is the latest version

  • metadata (Hash{Symbol=>String})

    Metadata associated with the entity

  • parent_plan_id (String, nil)

    The ID of the parent plan, if applicable

  • pricing_type (Symbol, Stigg::Models::V1::Plan::Data::PricingType, nil)

    The pricing type of the package

  • product_id (String)

    The product id of the package

  • status (Symbol, Stigg::Models::V1::Plan::Data::Status)

    The status of the package

  • updated_at (Time)

    Timestamp of when the record was last updated

  • version_number (Integer)

    The version number of the package



# File 'lib/stigg/models/v1/plan.rb', line 125

Instance Attribute Details

#billing_idString?

The unique identifier for the entity in the billing provider

Returns:

  • (String, nil)


31
# File 'lib/stigg/models/v1/plan.rb', line 31

required :billing_id, String, api_name: :billingId, nil?: true

#compatible_addon_idsArray<String>?

Returns:

  • (Array<String>, nil)


36
37
38
39
# File 'lib/stigg/models/v1/plan.rb', line 36

required :compatible_addon_ids,
Stigg::Internal::Type::ArrayOf[String],
api_name: :compatibleAddonIds,
nil?: true

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


45
# File 'lib/stigg/models/v1/plan.rb', line 45

required :created_at, Time, api_name: :createdAt

#default_trial_configStigg::Models::V1::Plan::Data::DefaultTrialConfig?

Default trial configuration for the plan



51
52
53
54
# File 'lib/stigg/models/v1/plan.rb', line 51

required :default_trial_config,
-> { Stigg::V1::Plan::Data::DefaultTrialConfig },
api_name: :defaultTrialConfig,
nil?: true

#descriptionString?

The description of the package

Returns:

  • (String, nil)


60
# File 'lib/stigg/models/v1/plan.rb', line 60

required :description, String, nil?: true

#display_nameString

The display name of the package

Returns:

  • (String)


66
# File 'lib/stigg/models/v1/plan.rb', line 66

required :display_name, String, api_name: :displayName

#entitlementsArray<Stigg::Models::V1::Plan::Data::Entitlement>

List of entitlements of the package



72
# File 'lib/stigg/models/v1/plan.rb', line 72

required :entitlements, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::Plan::Data::Entitlement] }

#idString

The unique identifier for the entity

Returns:

  • (String)


25
# File 'lib/stigg/models/v1/plan.rb', line 25

required :id, String

#is_latestBoolean?

Indicates if the package is the latest version

Returns:

  • (Boolean, nil)


78
# File 'lib/stigg/models/v1/plan.rb', line 78

required :is_latest, Stigg::Internal::Type::Boolean, api_name: :isLatest, nil?: true

#metadataHash{Symbol=>String}

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String})


84
# File 'lib/stigg/models/v1/plan.rb', line 84

required :metadata, Stigg::Internal::Type::HashOf[String]

#parent_plan_idString?

The ID of the parent plan, if applicable

Returns:

  • (String, nil)


90
# File 'lib/stigg/models/v1/plan.rb', line 90

required :parent_plan_id, String, api_name: :parentPlanId, nil?: true

#pricing_typeSymbol, ...

The pricing type of the package



96
97
98
99
# File 'lib/stigg/models/v1/plan.rb', line 96

required :pricing_type,
enum: -> { Stigg::V1::Plan::Data::PricingType },
api_name: :pricingType,
nil?: true

#product_idString

The product id of the package

Returns:

  • (String)


105
# File 'lib/stigg/models/v1/plan.rb', line 105

required :product_id, String, api_name: :productId

#statusSymbol, Stigg::Models::V1::Plan::Data::Status

The status of the package



111
# File 'lib/stigg/models/v1/plan.rb', line 111

required :status, enum: -> { Stigg::V1::Plan::Data::Status }

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


117
# File 'lib/stigg/models/v1/plan.rb', line 117

required :updated_at, Time, api_name: :updatedAt

#version_numberInteger

The version number of the package

Returns:

  • (Integer)


123
# File 'lib/stigg/models/v1/plan.rb', line 123

required :version_number, Integer, api_name: :versionNumber

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/plan.rb', line 244