Class: Stigg::Models::V1::PlanCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/plan_create_params.rb
Overview
Defined Under Namespace
Modules: PricingType, Status Classes: DefaultTrialConfig
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#default_trial_config ⇒ Stigg::Models::V1::PlanCreateParams::DefaultTrialConfig?
Default trial configuration for the plan.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String
The display name of the package.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity.
-
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable.
-
#pricing_type ⇒ Symbol, ...
The pricing type of the package.
-
#product_id ⇒ String
The product ID to associate the plan with.
-
#status ⇒ Symbol, ...
The status of the package.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
33 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 33 optional :billing_id, String, api_name: :billingId, nil?: true |
#default_trial_config ⇒ Stigg::Models::V1::PlanCreateParams::DefaultTrialConfig?
Default trial configuration for the plan
39 40 41 42 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 39 optional :default_trial_config, -> { Stigg::V1::PlanCreateParams::DefaultTrialConfig }, api_name: :defaultTrialConfig, nil?: true |
#description ⇒ String?
The description of the package
48 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 48 optional :description, String, nil?: true |
#display_name ⇒ String
The display name of the package
21 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 21 required :display_name, String, api_name: :displayName |
#id ⇒ String
The unique identifier for the entity
15 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 15 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity
54 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 54 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable
60 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 60 optional :parent_plan_id, String, api_name: :parentPlanId, nil?: true |
#pricing_type ⇒ Symbol, ...
The pricing type of the package
66 67 68 69 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 66 optional :pricing_type, enum: -> { Stigg::V1::PlanCreateParams::PricingType }, api_name: :pricingType, nil?: true |
#product_id ⇒ String
The product ID to associate the plan with
27 |
# File 'lib/stigg/models/v1/plan_create_params.rb', line 27 required :product_id, String, api_name: :productId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_create_params.rb', line 183
|