Class: Stigg::Models::V1::PlanListOverageChargesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanListOverageChargesResponse
- Defined in:
- lib/stigg/models/v1/plan_list_overage_charges_response.rb
Overview
Defined Under Namespace
Modules: BillingCadence, BillingModel, BillingPeriod, CreditGrantCadence, TiersMode Classes: CreditRate, Price, Tier
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingCadence
The billing cadence (RECURRING or ONE_OFF).
-
#billing_country_code ⇒ String?
ISO country code for localized pricing, if any.
-
#billing_id ⇒ String?
Identifier in the external billing integration (e.g. Stripe price id), if any.
-
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED, MINIMUM_SPEND).
-
#billing_period ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingPeriod
The billing period (MONTHLY or ANNUALLY).
-
#block_size ⇒ Float?
Block size for usage-based pricing.
-
#created_at ⇒ Time
Timestamp when the charge was created.
-
#credit_grant_cadence ⇒ Symbol, ...
When credits are granted (for credit-based pricing).
-
#credit_rate ⇒ Stigg::Models::V1::PlanListOverageChargesResponse::CreditRate?
Credit rate configuration for credit-based pricing.
-
#crm_id ⇒ String?
Identifier in the linked CRM, if any.
-
#crm_link_url ⇒ String?
Deep link to the charge in the linked CRM, if any.
-
#feature_id ⇒ String?
The feature this charge meters, if metered.
-
#id ⇒ String
Unique identifier of the charge.
-
#max_unit_quantity ⇒ Float?
Maximum unit quantity that can be purchased.
-
#min_unit_quantity ⇒ Float?
Minimum unit quantity that can be purchased.
-
#price ⇒ Stigg::Models::V1::PlanListOverageChargesResponse::Price?
The flat price amount and currency, when applicable.
-
#tiers ⇒ Array<Stigg::Models::V1::PlanListOverageChargesResponse::Tier>?
Tiered pricing rows when the charge is tiered.
-
#tiers_mode ⇒ Symbol, ...
Tiered pricing mode (VOLUME or GRADUATED) when the charge is tiered.
-
#top_up_custom_currency_id ⇒ String?
Custom currency identifier for top-up pricing, if any.
-
#used_in_subscriptions ⇒ Boolean?
True if this charge is referenced by at least one subscription.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(amount:, currency_id:, cost_formula: nil) ⇒ Object
constructor
Credit rate configuration for credit-based pricing.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, currency_id:, cost_formula: nil) ⇒ Object
Credit rate configuration for credit-based pricing
|
|
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 148
|
Instance Attribute Details
#billing_cadence ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingCadence
The billing cadence (RECURRING or ONE_OFF)
18 19 20 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 18 required :billing_cadence, enum: -> { Stigg::Models::V1::PlanListOverageChargesResponse::BillingCadence }, api_name: :billingCadence |
#billing_country_code ⇒ String?
ISO country code for localized pricing, if any
48 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 48 optional :billing_country_code, String, api_name: :billingCountryCode, nil?: true |
#billing_id ⇒ String?
Identifier in the external billing integration (e.g. Stripe price id), if any
54 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 54 optional :billing_id, String, api_name: :billingId, nil?: true |
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED, MINIMUM_SPEND)
26 27 28 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 26 required :billing_model, enum: -> { Stigg::Models::V1::PlanListOverageChargesResponse::BillingModel }, api_name: :billingModel |
#billing_period ⇒ Symbol, Stigg::Models::V1::PlanListOverageChargesResponse::BillingPeriod
The billing period (MONTHLY or ANNUALLY)
34 35 36 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 34 required :billing_period, enum: -> { Stigg::Models::V1::PlanListOverageChargesResponse::BillingPeriod }, api_name: :billingPeriod |
#block_size ⇒ Float?
Block size for usage-based pricing
60 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 60 optional :block_size, Float, api_name: :blockSize, nil?: true |
#created_at ⇒ Time
Timestamp when the charge was created
42 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 42 required :created_at, Time, api_name: :createdAt |
#credit_grant_cadence ⇒ Symbol, ...
When credits are granted (for credit-based pricing)
66 67 68 69 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 66 optional :credit_grant_cadence, enum: -> { Stigg::Models::V1::PlanListOverageChargesResponse::CreditGrantCadence }, api_name: :creditGrantCadence, nil?: true |
#credit_rate ⇒ Stigg::Models::V1::PlanListOverageChargesResponse::CreditRate?
Credit rate configuration for credit-based pricing
75 76 77 78 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 75 optional :credit_rate, -> { Stigg::Models::V1::PlanListOverageChargesResponse::CreditRate }, api_name: :creditRate, nil?: true |
#crm_id ⇒ String?
Identifier in the linked CRM, if any
84 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 84 optional :crm_id, String, api_name: :crmId, nil?: true |
#crm_link_url ⇒ String?
Deep link to the charge in the linked CRM, if any
90 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 90 optional :crm_link_url, String, api_name: :crmLinkUrl, nil?: true |
#feature_id ⇒ String?
The feature this charge meters, if metered
96 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 96 optional :feature_id, String, api_name: :featureId, nil?: true |
#id ⇒ String
Unique identifier of the charge
12 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 12 required :id, String |
#max_unit_quantity ⇒ Float?
Maximum unit quantity that can be purchased
102 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 102 optional :max_unit_quantity, Float, api_name: :maxUnitQuantity, nil?: true |
#min_unit_quantity ⇒ Float?
Minimum unit quantity that can be purchased
108 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 108 optional :min_unit_quantity, Float, api_name: :minUnitQuantity, nil?: true |
#price ⇒ Stigg::Models::V1::PlanListOverageChargesResponse::Price?
The flat price amount and currency, when applicable
114 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 114 optional :price, -> { Stigg::Models::V1::PlanListOverageChargesResponse::Price }, nil?: true |
#tiers ⇒ Array<Stigg::Models::V1::PlanListOverageChargesResponse::Tier>?
Tiered pricing rows when the charge is tiered
120 121 122 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 120 optional :tiers, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::PlanListOverageChargesResponse::Tier] }, nil?: true |
#tiers_mode ⇒ Symbol, ...
Tiered pricing mode (VOLUME or GRADUATED) when the charge is tiered
128 129 130 131 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 128 optional :tiers_mode, enum: -> { Stigg::Models::V1::PlanListOverageChargesResponse::TiersMode }, api_name: :tiersMode, nil?: true |
#top_up_custom_currency_id ⇒ String?
Custom currency identifier for top-up pricing, if any
137 |
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 137 optional :top_up_custom_currency_id, String, api_name: :topUpCustomCurrencyId, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_list_overage_charges_response.rb', line 205
|