Class: Stigg::Models::V1::PlanListResponse::DefaultTrialConfig

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/plan_list_response.rb

Overview

Defined Under Namespace

Modules: TrialEndBehavior, Units Classes: Budget

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(has_soft_limit:, limit:) ⇒ Object

Budget configuration for the trial

Parameters:

  • has_soft_limit (Boolean)

    Whether the budget limit is a soft limit (allows overage) or hard limit

  • limit (Float)

    The budget limit amount



# File 'lib/stigg/models/v1/plan_list_response.rb', line 177

Instance Attribute Details

#budgetStigg::Models::V1::PlanListResponse::DefaultTrialConfig::Budget?

Budget configuration for the trial



166
# File 'lib/stigg/models/v1/plan_list_response.rb', line 166

optional :budget, -> { Stigg::Models::V1::PlanListResponse::DefaultTrialConfig::Budget }, nil?: true

#durationFloat

The duration of the trial in the specified units

Returns:

  • (Float)


154
# File 'lib/stigg/models/v1/plan_list_response.rb', line 154

required :duration, Float

#trial_end_behaviorSymbol, ...

Behavior when the trial ends (CONVERT_TO_PAID or CANCEL_SUBSCRIPTION)



172
173
174
175
# File 'lib/stigg/models/v1/plan_list_response.rb', line 172

optional :trial_end_behavior,
enum: -> { Stigg::Models::V1::PlanListResponse::DefaultTrialConfig::TrialEndBehavior },
api_name: :trialEndBehavior,
nil?: true

#unitsSymbol, Stigg::Models::V1::PlanListResponse::DefaultTrialConfig::Units

The time unit for the trial duration (DAY or MONTH)



160
# File 'lib/stigg/models/v1/plan_list_response.rb', line 160

required :units, enum: -> { Stigg::Models::V1::PlanListResponse::DefaultTrialConfig::Units }

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/plan_list_response.rb', line 197