Class: Stigg::Models::V1::PlanUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/plan_update_params.rb
Overview
Defined Under Namespace
Classes: Charges, DefaultTrialConfig
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#charges ⇒ Stigg::Models::V1::PlanUpdateParams::Charges?
Pricing configuration to set on the plan draft.
- #compatible_addon_ids ⇒ Array<String>?
-
#default_trial_config ⇒ Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig?
Default trial configuration for the plan.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String?
The display name of the package.
- #id ⇒ String
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity.
-
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
20 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 20 optional :billing_id, String, api_name: :billingId, nil?: true |
#charges ⇒ Stigg::Models::V1::PlanUpdateParams::Charges?
Pricing configuration to set on the plan draft
26 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 26 optional :charges, -> { Stigg::V1::PlanUpdateParams::Charges } |
#compatible_addon_ids ⇒ Array<String>?
31 32 33 34 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 31 optional :compatible_addon_ids, Stigg::Internal::Type::ArrayOf[String], api_name: :compatibleAddonIds, nil?: true |
#default_trial_config ⇒ Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig?
Default trial configuration for the plan
40 41 42 43 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 40 optional :default_trial_config, -> { Stigg::V1::PlanUpdateParams::DefaultTrialConfig }, api_name: :defaultTrialConfig, nil?: true |
#description ⇒ String?
The description of the package
49 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 49 optional :description, String, nil?: true |
#display_name ⇒ String?
The display name of the package
55 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 55 optional :display_name, String, api_name: :displayName |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 14 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity
61 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 61 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable
67 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 67 optional :parent_plan_id, String, api_name: :parentPlanId, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2164
|