Class: Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel
- Defined in:
- lib/stigg/models/v1/plan_update_params.rb,
sig/stigg/models/v1/plan_update_params.rbs
Defined Under Namespace
Classes: CreditEntitlement, Entitlement, PricePeriod
Instance Attribute Summary collapse
-
#credit_entitlement ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement?
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan.
-
#currency_id ⇒ String?
The refId of the custom currency this credit overage applies to.
-
#entitlement ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement?
Entitlement configuration for the overage feature.
-
#feature_id ⇒ String?
The feature ID for overage pricing.
-
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod>
Price periods for overage pricing.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
498 |
# File 'sig/stigg/models/v1/plan_update_params.rbs', line 498
def initialize: (
|
Instance Attribute Details
#credit_entitlement ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement?
Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan
397 398 399 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 397 optional :credit_entitlement, -> { Stigg::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement }, api_name: :creditEntitlement |
#currency_id ⇒ String?
The refId of the custom currency this credit overage applies to
405 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 405 optional :currency_id, String, api_name: :currencyId |
#entitlement ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement?
Entitlement configuration for the overage feature
411 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 411 optional :entitlement, -> { Stigg::V1::PlanUpdateParams::Charges::OveragePricingModel::Entitlement } |
#feature_id ⇒ String?
The feature ID for overage pricing
417 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 417 optional :feature_id, String, api_name: :featureId |
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod>
Price periods for overage pricing
386 387 388 389 390 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 386 required :price_periods, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::PlanUpdateParams::Charges::OveragePricingModel::PricePeriod] }, api_name: :pricePeriods |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1046
|
Instance Method Details
#to_hash ⇒ {
506 |
# File 'sig/stigg/models/v1/plan_update_params.rbs', line 506
def to_hash: -> {
|