Class: Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/plan_update_params.rb,
sig/stigg/models/v1/plan_update_params.rbs

Overview

See Also:

  • Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel#credit_entitlement

Defined Under Namespace

Modules: Cadence

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(amount:, cadence:, custom_currency_id:) ⇒ Object

Credit entitlement to grant when a credit overage targets a currency not yet granted on the plan

Parameters:



# File 'lib/stigg/models/v1/plan_update_params.rb', line 1123

Instance Attribute Details

#amountFloat

The base credit balance granted per cadence

Parameters:

  • value (Float)

Returns:

  • (Float)


1108
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1108

required :amount, Float

#cadenceSymbol, Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement::Cadence

The credit grant cadence (MONTH or YEAR)

Parameters:

  • value (Stigg::Models::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement::cadence)

Returns:



1114
1115
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1114

required :cadence,
enum: -> { Stigg::V1::PlanUpdateParams::Charges::OveragePricingModel::CreditEntitlement::Cadence }

#custom_currency_idString

The refId of the custom currency to grant

Parameters:

  • value (String)

Returns:

  • (String)


1121
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1121

required :custom_currency_id, String, api_name: :customCurrencyId

Instance Method Details

#to_hash{

Returns:

  • ({)


1531
# File 'sig/stigg/models/v1/plan_update_params.rbs', line 1531

def to_hash: -> {