Class: Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel
- Defined in:
- lib/stigg/models/v1/plan_update_params.rb,
sig/stigg/models/v1/plan_update_params.rbs
Defined Under Namespace
Modules: BillingCadence, BillingModel, ResetPeriod, TiersMode Classes: MonthlyResetPeriodConfiguration, PricePeriod, WeeklyResetPeriodConfiguration, YearlyResetPeriodConfiguration
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF).
-
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED).
-
#feature_id ⇒ String?
The feature ID this pricing model is associated with.
-
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999).
-
#min_unit_quantity ⇒ Integer?
Minimum number of units.
-
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration.
-
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required).
-
#reset_period ⇒ Symbol, ...
The usage reset period.
-
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED).
-
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing.
-
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration.
-
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
constructor
A pricing model configuration with billing details and price periods.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
A pricing model configuration with billing details and price periods.
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1445
|
Instance Attribute Details
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF)
1371 1372 1373 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1371 optional :billing_cadence, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::BillingCadence }, api_name: :billingCadence |
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED)
1353 1354 1355 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1353 required :billing_model, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::BillingModel }, api_name: :billingModel |
#feature_id ⇒ String?
The feature ID this pricing model is associated with
1379 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1379 optional :feature_id, String, api_name: :featureId |
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999)
1385 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1385 optional :max_unit_quantity, Integer, api_name: :maxUnitQuantity |
#min_unit_quantity ⇒ Integer?
Minimum number of units
1391 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1391 optional :min_unit_quantity, Integer, api_name: :minUnitQuantity |
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration
1397 1398 1399 1400 1401 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1397 optional :monthly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration }, api_name: :monthlyResetPeriodConfiguration |
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required)
1361 1362 1363 1364 1365 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1361 required :price_periods, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod] }, api_name: :pricePeriods |
#reset_period ⇒ Symbol, ...
The usage reset period
1407 1408 1409 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1407 optional :reset_period, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::ResetPeriod }, api_name: :resetPeriod |
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED)
1415 1416 1417 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1415 optional :tiers_mode, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::TiersMode }, api_name: :tiersMode |
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing
1423 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1423 optional :top_up_custom_currency_id, String, api_name: :topUpCustomCurrencyId |
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration
1429 1430 1431 1432 1433 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1429 optional :weekly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration }, api_name: :weeklyResetPeriodConfiguration |
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration
1439 1440 1441 1442 1443 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1439 optional :yearly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration }, api_name: :yearlyResetPeriodConfiguration |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1484
|
Instance Method Details
#to_hash ⇒ {
1823 |
# File 'sig/stigg/models/v1/plan_update_params.rbs', line 1823
def to_hash: -> {
|