Class: Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig
- Defined in:
- lib/stigg/models/v1/plan_update_params.rb
Defined Under Namespace
Modules: TrialEndBehavior, Units Classes: Budget
Instance Attribute Summary collapse
-
#budget ⇒ Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig::Budget?
Budget configuration for the trial.
-
#duration ⇒ Float
The duration of the trial in the specified units.
-
#trial_end_behavior ⇒ Symbol, ...
Behavior when the trial ends (CONVERT_TO_PAID or CANCEL_SUBSCRIPTION).
-
#units ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig::Units
The time unit for the trial duration (DAY or MONTH).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(has_soft_limit:, limit:) ⇒ Object
constructor
Budget configuration for the trial.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(has_soft_limit:, limit:) ⇒ Object
Budget configuration for the trial
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2199
|
Instance Attribute Details
#budget ⇒ Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig::Budget?
Budget configuration for the trial
2188 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2188 optional :budget, -> { Stigg::V1::PlanUpdateParams::DefaultTrialConfig::Budget }, nil?: true |
#duration ⇒ Float
The duration of the trial in the specified units
2176 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2176 required :duration, Float |
#trial_end_behavior ⇒ Symbol, ...
Behavior when the trial ends (CONVERT_TO_PAID or CANCEL_SUBSCRIPTION)
2194 2195 2196 2197 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2194 optional :trial_end_behavior, enum: -> { Stigg::V1::PlanUpdateParams::DefaultTrialConfig::TrialEndBehavior }, api_name: :trialEndBehavior, nil?: true |
#units ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::DefaultTrialConfig::Units
The time unit for the trial duration (DAY or MONTH)
2182 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2182 required :units, enum: -> { Stigg::V1::PlanUpdateParams::DefaultTrialConfig::Units } |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 2219
|