Class: Stigg::Models::V1::Plans::EntitlementListResponse::Pagination

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/plans/entitlement_list_response.rb

Overview

See Also:

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(next_:, prev:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::Plans::EntitlementListResponse::Pagination for more details.

Pagination metadata including cursors for navigating through results

Parameters:

  • next_ (String, nil)

    Cursor for fetching the next page of results, or null if no additional pages exi

  • prev (String, nil)

    Cursor for fetching the previous page of results, or null if at the beginning



# File 'lib/stigg/models/v1/plans/entitlement_list_response.rb', line 524

Instance Attribute Details

#next_String?

Cursor for fetching the next page of results, or null if no additional pages exist

Returns:

  • (String, nil)


516
# File 'lib/stigg/models/v1/plans/entitlement_list_response.rb', line 516

required :next_, String, api_name: :next, nil?: true

#prevString?

Cursor for fetching the previous page of results, or null if at the beginning

Returns:

  • (String, nil)


522
# File 'lib/stigg/models/v1/plans/entitlement_list_response.rb', line 522

required :prev, String, nil?: true