Class: Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature
- Defined in:
- lib/stigg/models/v1/plans/plan_entitlement.rb
Defined Under Namespace
Modules: Behavior, HiddenFromWidget, ResetPeriod, ResetPeriodConfiguration
Instance Attribute Summary collapse
-
#behavior ⇒ Symbol, Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::Behavior
Entitlement behavior (Increment or Override).
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#description ⇒ String?
Optional description of the entitlement.
-
#display_name_override ⇒ String?
Override display name for the entitlement.
-
#enum_values ⇒ Array<String>?
Allowed enum values (for feature entitlements).
-
#has_soft_limit ⇒ Boolean?
Whether the usage limit is a soft limit (for feature entitlements).
-
#has_unlimited_usage ⇒ Boolean?
Whether usage is unlimited (for feature entitlements).
-
#hidden_from_widgets ⇒ Array<Symbol, Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::HiddenFromWidget>
Widget types where this entitlement is hidden.
-
#id ⇒ String
Unique identifier of the entitlement.
-
#is_custom ⇒ Boolean?
Whether this is a custom entitlement.
-
#is_granted ⇒ Boolean
Whether the entitlement is granted.
-
#order ⇒ Float?
Display order of the entitlement.
-
#reset_period ⇒ Symbol, ...
Usage reset period (for feature entitlements).
-
#reset_period_configuration ⇒ Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, ...
Reset period configuration (for feature entitlements).
-
#type ⇒ Symbol, :FEATURE
Entitlement type (FEATURE or CREDIT).
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
-
#usage_limit ⇒ Float?
Usage limit (for feature entitlements).
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, behavior:, created_at:, description:, display_name_override:, enum_values:, has_soft_limit:, has_unlimited_usage:, hidden_from_widgets:, is_custom:, is_granted:, order:, reset_period:, reset_period_configuration:, updated_at:, usage_limit:, type: :FEATURE) ⇒ Object
constructor
Feature entitlement response.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, behavior:, created_at:, description:, display_name_override:, enum_values:, has_soft_limit:, has_unlimited_usage:, hidden_from_widgets:, is_custom:, is_granted:, order:, reset_period:, reset_period_configuration:, updated_at:, usage_limit:, type: :FEATURE) ⇒ Object
Feature entitlement response
|
|
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 152
|
Instance Attribute Details
#behavior ⇒ Symbol, Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::Behavior
Entitlement behavior (Increment or Override)
45 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 45 required :behavior, enum: -> { Stigg::V1::Plans::PlanEntitlement::Data::Feature::Behavior } |
#created_at ⇒ Time
Timestamp of when the record was created
51 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 51 required :created_at, Time, api_name: :createdAt |
#description ⇒ String?
Optional description of the entitlement
57 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 57 required :description, String, nil?: true |
#display_name_override ⇒ String?
Override display name for the entitlement
63 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 63 required :display_name_override, String, api_name: :displayNameOverride, nil?: true |
#enum_values ⇒ Array<String>?
Allowed enum values (for feature entitlements)
69 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 69 required :enum_values, Stigg::Internal::Type::ArrayOf[String], api_name: :enumValues, nil?: true |
#has_soft_limit ⇒ Boolean?
Whether the usage limit is a soft limit (for feature entitlements)
75 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 75 required :has_soft_limit, Stigg::Internal::Type::Boolean, api_name: :hasSoftLimit, nil?: true |
#has_unlimited_usage ⇒ Boolean?
Whether usage is unlimited (for feature entitlements)
81 82 83 84 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 81 required :has_unlimited_usage, Stigg::Internal::Type::Boolean, api_name: :hasUnlimitedUsage, nil?: true |
#hidden_from_widgets ⇒ Array<Symbol, Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::HiddenFromWidget>
Widget types where this entitlement is hidden
90 91 92 93 94 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 90 required :hidden_from_widgets, -> { Stigg::Internal::Type::ArrayOf[enum: Stigg::V1::Plans::PlanEntitlement::Data::Feature::HiddenFromWidget] }, api_name: :hiddenFromWidgets |
#id ⇒ String
Unique identifier of the entitlement
39 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 39 required :id, String |
#is_custom ⇒ Boolean?
Whether this is a custom entitlement
100 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 100 required :is_custom, Stigg::Internal::Type::Boolean, api_name: :isCustom, nil?: true |
#is_granted ⇒ Boolean
Whether the entitlement is granted
106 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 106 required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted |
#order ⇒ Float?
Display order of the entitlement
112 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 112 required :order, Float, nil?: true |
#reset_period ⇒ Symbol, ...
Usage reset period (for feature entitlements)
118 119 120 121 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 118 required :reset_period, enum: -> { Stigg::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriod }, api_name: :resetPeriod, nil?: true |
#reset_period_configuration ⇒ Stigg::Models::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration::YearlyResetPeriodConfig, ...
Reset period configuration (for feature entitlements)
127 128 129 130 131 132 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 127 required :reset_period_configuration, union: -> { Stigg::V1::Plans::PlanEntitlement::Data::Feature::ResetPeriodConfiguration }, api_name: :resetPeriodConfiguration, nil?: true |
#type ⇒ Symbol, :FEATURE
Entitlement type (FEATURE or CREDIT)
138 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 138 required :type, const: :FEATURE |
#updated_at ⇒ Time
Timestamp of when the record was last updated
144 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 144 required :updated_at, Time, api_name: :updatedAt |
#usage_limit ⇒ Float?
Usage limit (for feature entitlements)
150 |
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 150 required :usage_limit, Float, api_name: :usageLimit, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plans/plan_entitlement.rb', line 198
|