Class: Stigg::Models::V1::Product::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/product.rb

Overview

See Also:

Defined Under Namespace

Modules: Status Classes: ProductSettings

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, created_at:, description:, display_name:, metadata:, multiple_subscriptions:, status:, updated_at:, product_settings: nil) ⇒ Object

Product configuration object

Parameters:

  • id (String)

    The unique identifier for the entity

  • created_at (Time)

    Timestamp of when the record was created

  • description (String, nil)

    Description of the product

  • display_name (String)

    Display name of the product

  • metadata (Hash{Symbol=>String})

    Metadata associated with the entity

  • multiple_subscriptions (Boolean)

    Indicates if multiple subscriptions to this product are allowed

  • status (Symbol, Stigg::Models::V1::Product::Data::Status)

    The status of the product

  • updated_at (Time)

    Timestamp of when the record was last updated

  • product_settings (Stigg::Models::V1::Product::Data::ProductSettings) (defaults to: nil)

    Product behavior settings for subscription lifecycle management.



# File 'lib/stigg/models/v1/product.rb', line 79

Instance Attribute Details

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


31
# File 'lib/stigg/models/v1/product.rb', line 31

required :created_at, Time, api_name: :createdAt

#descriptionString?

Description of the product

Returns:

  • (String, nil)


37
# File 'lib/stigg/models/v1/product.rb', line 37

required :description, String, nil?: true

#display_nameString

Display name of the product

Returns:

  • (String)


43
# File 'lib/stigg/models/v1/product.rb', line 43

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the entity

Returns:

  • (String)


25
# File 'lib/stigg/models/v1/product.rb', line 25

required :id, String

#metadataHash{Symbol=>String}

Metadata associated with the entity

Returns:

  • (Hash{Symbol=>String})


49
# File 'lib/stigg/models/v1/product.rb', line 49

required :metadata, Stigg::Internal::Type::HashOf[String]

#multiple_subscriptionsBoolean

Indicates if multiple subscriptions to this product are allowed

Returns:

  • (Boolean)


55
# File 'lib/stigg/models/v1/product.rb', line 55

required :multiple_subscriptions, Stigg::Internal::Type::Boolean, api_name: :multipleSubscriptions

#product_settingsStigg::Models::V1::Product::Data::ProductSettings?

Product behavior settings for subscription lifecycle management.



73
74
75
76
77
# File 'lib/stigg/models/v1/product.rb', line 73

optional :product_settings,
-> {
  Stigg::V1::Product::Data::ProductSettings
},
api_name: :productSettings

#statusSymbol, Stigg::Models::V1::Product::Data::Status

The status of the product



61
# File 'lib/stigg/models/v1/product.rb', line 61

required :status, enum: -> { Stigg::V1::Product::Data::Status }

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


67
# File 'lib/stigg/models/v1/product.rb', line 67

required :updated_at, Time, api_name: :updatedAt

Class Method Details

.valuesArray<Symbol>

Returns:

  • (Array<Symbol>)


# File 'lib/stigg/models/v1/product.rb', line 109