Class: Stigg::Models::V1::ProductCreateProductParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/product_create_product_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, display_name:, description: nil, metadata: nil, multiple_subscriptions: nil, request_options: {}) ⇒ Object

Parameters:

  • id (String)

    The unique identifier for the entity

  • display_name (String)

    Display name of the product

  • description (String, nil) (defaults to: nil)

    Description of the product

  • metadata (Hash{Symbol=>String}, nil) (defaults to: nil)

    Additional metadata for the product

  • multiple_subscriptions (Boolean) (defaults to: nil)

    Indicates if multiple subscriptions to this product are allowed

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/product_create_product_params.rb', line 41

Instance Attribute Details

#descriptionString?

Description of the product

Returns:

  • (String, nil)


27
# File 'lib/stigg/models/v1/product_create_product_params.rb', line 27

optional :description, String, nil?: true

#display_nameString

Display name of the product

Returns:

  • (String)


21
# File 'lib/stigg/models/v1/product_create_product_params.rb', line 21

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the entity

Returns:

  • (String)


15
# File 'lib/stigg/models/v1/product_create_product_params.rb', line 15

required :id, String

#metadataHash{Symbol=>String}?

Additional metadata for the product

Returns:

  • (Hash{Symbol=>String}, nil)


33
# File 'lib/stigg/models/v1/product_create_product_params.rb', line 33

optional :metadata, Stigg::Internal::Type::HashOf[String], nil?: true

#multiple_subscriptionsBoolean?

Indicates if multiple subscriptions to this product are allowed

Returns:

  • (Boolean, nil)


39
# File 'lib/stigg/models/v1/product_create_product_params.rb', line 39

optional :multiple_subscriptions, Stigg::Internal::Type::Boolean, api_name: :multipleSubscriptions