Class: Stigg::Models::V1::ProductListProductsResponse::ProductSettings
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::ProductListProductsResponse::ProductSettings
- Defined in:
- lib/stigg/models/v1/product_list_products_response.rb
Overview
Defined Under Namespace
Modules: SubscriptionCancellationTime, SubscriptionEndSetup, SubscriptionStartSetup
Instance Attribute Summary collapse
-
#downgrade_plan_id ⇒ String?
ID of the plan to downgrade to at the end of the billing period.
-
#prorate_at_end_of_billing_period ⇒ Boolean?
Indicates if the subscription should be prorated at the end of the billing period.
-
#subscription_cancellation_time ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionCancellationTime
Time when the subscription will be cancelled.
-
#subscription_end_setup ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionEndSetup
Setup for the end of the subscription.
-
#subscription_start_plan_id ⇒ String?
ID of the plan to start the subscription with.
-
#subscription_start_setup ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionStartSetup
Setup for the start of the subscription.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(subscription_cancellation_time:, subscription_end_setup:, subscription_start_setup:, downgrade_plan_id: nil, prorate_at_end_of_billing_period: nil, subscription_start_plan_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see ProductSettings for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(subscription_cancellation_time:, subscription_end_setup:, subscription_start_setup:, downgrade_plan_id: nil, prorate_at_end_of_billing_period: nil, subscription_start_plan_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::ProductListProductsResponse::ProductSettings for more details.
Product behavior settings for subscription lifecycle management.
|
|
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 146
|
Instance Attribute Details
#downgrade_plan_id ⇒ String?
ID of the plan to downgrade to at the end of the billing period
128 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 128 optional :downgrade_plan_id, String, api_name: :downgradePlanId, nil?: true |
#prorate_at_end_of_billing_period ⇒ Boolean?
Indicates if the subscription should be prorated at the end of the billing period
135 136 137 138 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 135 optional :prorate_at_end_of_billing_period, Stigg::Internal::Type::Boolean, api_name: :prorateAtEndOfBillingPeriod, nil?: true |
#subscription_cancellation_time ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionCancellationTime
Time when the subscription will be cancelled
104 105 106 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 104 required :subscription_cancellation_time, enum: -> { Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionCancellationTime }, api_name: :subscriptionCancellationTime |
#subscription_end_setup ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionEndSetup
Setup for the end of the subscription
112 113 114 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 112 required :subscription_end_setup, enum: -> { Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionEndSetup }, api_name: :subscriptionEndSetup |
#subscription_start_plan_id ⇒ String?
ID of the plan to start the subscription with
144 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 144 optional :subscription_start_plan_id, String, api_name: :subscriptionStartPlanId, nil?: true |
#subscription_start_setup ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionStartSetup
Setup for the start of the subscription
120 121 122 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 120 required :subscription_start_setup, enum: -> { Stigg::Models::V1::ProductListProductsResponse::ProductSettings::SubscriptionStartSetup }, api_name: :subscriptionStartSetup |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 175
|