Class: Stigg::Models::V1::ProductUpdateProductParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::ProductUpdateProductParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/product_update_product_params.rb
Overview
Defined Under Namespace
Classes: ProductSettings, UsageResetCutoffRule
Instance Attribute Summary collapse
-
#description ⇒ String?
Description of the product.
-
#display_name ⇒ String?
Display name of the product.
- #id ⇒ String
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product.
-
#multiple_subscriptions ⇒ Boolean?
Indicates if multiple subscriptions to this product are allowed.
- #product_settings ⇒ Stigg::Models::V1::ProductUpdateProductParams::ProductSettings?
-
#usage_reset_cutoff_rule ⇒ Stigg::Models::V1::ProductUpdateProductParams::UsageResetCutoffRule?
Rule defining when usage resets upon subscription update.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#description ⇒ String?
Description of the product
20 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 20 optional :description, String, nil?: true |
#display_name ⇒ String?
Display name of the product
26 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 26 optional :display_name, String, api_name: :displayName |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 14 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata for the product
32 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 32 optional :metadata, Stigg::Internal::Type::HashOf[String], nil?: true |
#multiple_subscriptions ⇒ Boolean?
Indicates if multiple subscriptions to this product are allowed
38 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 38 optional :multiple_subscriptions, Stigg::Internal::Type::Boolean, api_name: :multipleSubscriptions |
#product_settings ⇒ Stigg::Models::V1::ProductUpdateProductParams::ProductSettings?
43 44 45 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 43 optional :product_settings, -> { Stigg::V1::ProductUpdateProductParams::ProductSettings }, api_name: :productSettings |
#usage_reset_cutoff_rule ⇒ Stigg::Models::V1::ProductUpdateProductParams::UsageResetCutoffRule?
Rule defining when usage resets upon subscription update.
51 52 53 |
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 51 optional :usage_reset_cutoff_rule, -> { Stigg::V1::ProductUpdateProductParams::UsageResetCutoffRule }, api_name: :usageResetCutoffRule |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/product_update_product_params.rb', line 177
|