Class: Stigg::Models::V1::SubscriptionDelegateParams

Inherits:
Internal::Type::BaseModel show all
Extended by:
Internal::Type::RequestParameters::Converter
Includes:
Internal::Type::RequestParameters
Defined in:
lib/stigg/models/v1/subscription_delegate_params.rb

Overview

Instance Attribute Summary collapse

Attributes included from Internal::Type::RequestParameters

#request_options

Instance Method Summary collapse

Methods included from Internal::Type::RequestParameters::Converter

dump_request

Methods included from Internal::Type::RequestParameters

included

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, target_customer_id:, request_options: {}) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1::SubscriptionDelegateParams for more details.

Parameters:

  • id (String)
  • target_customer_id (String)

    The unique identifier of the customer who will assume payment responsibility for

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}) (defaults to: {})


# File 'lib/stigg/models/v1/subscription_delegate_params.rb', line 24

Instance Attribute Details

#idString

Returns:

  • (String)


14
# File 'lib/stigg/models/v1/subscription_delegate_params.rb', line 14

required :id, String

#target_customer_idString

The unique identifier of the customer who will assume payment responsibility for this subscription. This customer must already exist in your Stigg account and have a valid payment method if the subscription requires payment.

Returns:

  • (String)


22
# File 'lib/stigg/models/v1/subscription_delegate_params.rb', line 22

required :target_customer_id, String, api_name: :targetCustomerId