Class: Stigg::Models::V1::SubscriptionProvisionParams::PriceOverride::CreditRate
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::SubscriptionProvisionParams::PriceOverride::CreditRate
- Defined in:
- lib/stigg/models/v1/subscription_provision_params.rb
Overview
Instance Attribute Summary collapse
-
#amount ⇒ Float
The credit rate amount.
-
#cost_formula ⇒ String?
A custom formula for calculating cost based on single event dimensions.
-
#currency_id ⇒ String
The custom currency refId for the credit rate.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#amount ⇒ Float
The credit rate amount
1375 |
# File 'lib/stigg/models/v1/subscription_provision_params.rb', line 1375 required :amount, Float |
#cost_formula ⇒ String?
A custom formula for calculating cost based on single event dimensions
1387 |
# File 'lib/stigg/models/v1/subscription_provision_params.rb', line 1387 optional :cost_formula, String, api_name: :costFormula, nil?: true |
#currency_id ⇒ String
The custom currency refId for the credit rate
1381 |
# File 'lib/stigg/models/v1/subscription_provision_params.rb', line 1381 required :currency_id, String, api_name: :currencyId |