Class: Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0
- Defined in:
- lib/stigg/models/v1/subscription_provision_response.rb
Defined Under Namespace
Modules: AccessDeniedReason, ResetPeriod, Type Classes: Feature
Instance Attribute Summary collapse
- #access_denied_reason ⇒ Symbol, ...
- #current_usage ⇒ Float?
-
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
- #feature ⇒ Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature?
- #has_unlimited_usage ⇒ Boolean?
- #is_granted ⇒ Boolean
- #reset_period ⇒ Symbol, ...
- #type ⇒ Symbol, Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Type
- #usage_limit ⇒ Float?
-
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured.
-
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured.
-
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured.
-
#valid_until ⇒ Time?
The next time the entitlement should be recalculated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access_denied_reason:, is_granted:, type:, current_usage: nil, entitlement_updated_at: nil, feature: nil, has_unlimited_usage: nil, reset_period: nil, usage_limit: nil, usage_period_anchor: nil, usage_period_end: nil, usage_period_start: nil, valid_until: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see UnionObjectVariant0 for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_denied_reason:, is_granted:, type:, current_usage: nil, entitlement_updated_at: nil, feature: nil, has_unlimited_usage: nil, reset_period: nil, usage_limit: nil, usage_period_anchor: nil, usage_period_end: nil, usage_period_start: nil, valid_until: nil) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0 for more details.
|
|
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 172
|
Instance Attribute Details
#access_denied_reason ⇒ Symbol, ...
94 95 96 97 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 94 required :access_denied_reason, enum: -> { Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::AccessDeniedReason }, api_name: :accessDeniedReason, nil?: true |
#current_usage ⇒ Float?
113 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 113 optional :current_usage, Float, api_name: :currentUsage |
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
119 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 119 optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt |
#feature ⇒ Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature?
124 125 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 124 optional :feature, -> { Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Feature } |
#has_unlimited_usage ⇒ Boolean?
130 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 130 optional :has_unlimited_usage, Stigg::Internal::Type::Boolean, api_name: :hasUnlimitedUsage |
#is_granted ⇒ Boolean
102 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 102 required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted |
#reset_period ⇒ Symbol, ...
135 136 137 138 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 135 optional :reset_period, enum: -> { Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::ResetPeriod }, api_name: :resetPeriod, nil?: true |
#type ⇒ Symbol, Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Type
107 108 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 107 required :type, enum: -> { Stigg::Models::V1::SubscriptionProvisionResponse::Data::Entitlement::UnionObjectVariant0::Type } |
#usage_limit ⇒ Float?
143 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 143 optional :usage_limit, Float, api_name: :usageLimit, nil?: true |
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured
150 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 150 optional :usage_period_anchor, Time, api_name: :usagePeriodAnchor |
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured
157 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 157 optional :usage_period_end, Time, api_name: :usagePeriodEnd |
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured
164 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 164 optional :usage_period_start, Time, api_name: :usagePeriodStart |
#valid_until ⇒ Time?
The next time the entitlement should be recalculated
170 |
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 170 optional :valid_until, Time, api_name: :validUntil |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/subscription_provision_response.rb', line 222
|