Class: Stigg::Models::V1::SubscriptionUpdateParams::PriceOverride

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/subscription_update_params.rb

Defined Under Namespace

Modules: Currency

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(addon_id: nil, amount: nil, base_charge: nil, currency: nil, currency_id: nil, feature_id: nil) ⇒ Object

Parameters:

  • addon_id (String) (defaults to: nil)

    Addon ID

  • amount (Float) (defaults to: nil)

    The price amount

  • base_charge (Boolean) (defaults to: nil)

    Whether this is a base charge override

  • currency (Symbol, Stigg::Models::V1::SubscriptionUpdateParams::PriceOverride::Currency) (defaults to: nil)

    The price currency

  • currency_id (String) (defaults to: nil)

    The corresponding custom currency id of the recurring credits price

  • feature_id (String) (defaults to: nil)

    Feature ID



# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1123

Instance Attribute Details

#addon_idString?

Addon ID

Returns:

  • (String, nil)


1091
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1091

optional :addon_id, String, api_name: :addonId

#amountFloat?

The price amount

Returns:

  • (Float, nil)


1097
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1097

optional :amount, Float

#base_chargeBoolean?

Whether this is a base charge override

Returns:

  • (Boolean, nil)


1103
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1103

optional :base_charge, Stigg::Internal::Type::Boolean, api_name: :baseCharge

#currencySymbol, ...

The price currency



1109
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1109

optional :currency, enum: -> { Stigg::V1::SubscriptionUpdateParams::PriceOverride::Currency }

#currency_idString?

The corresponding custom currency id of the recurring credits price

Returns:

  • (String, nil)


1115
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1115

optional :currency_id, String, api_name: :currencyId

#feature_idString?

Feature ID

Returns:

  • (String, nil)


1121
# File 'lib/stigg/models/v1/subscription_update_params.rb', line 1121

optional :feature_id, String, api_name: :featureId