Class: Stigg::Models::V1::UsageEstimateCostParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::UsageEstimateCostParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/usage_estimate_cost_params.rb,
sig/stigg/models/v1/usage_estimate_cost_params.rbs
Overview
Defined Under Namespace
Modules: Dimension, UpdateBehavior
Instance Attribute Summary collapse
-
#customer_id ⇒ String
Customer id.
-
#dimensions ⇒ Hash{Symbol=>String, Float, Boolean}?
Additional dimensions for the usage report.
-
#feature_id ⇒ String
Feature id.
-
#resource_id ⇒ String?
Resource id.
-
#update_behavior ⇒ Symbol, ...
The method by which the usage value should be updated.
-
#value ⇒ Integer
The value to report for usage.
- #x_account_id ⇒ String?
- #x_environment_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize ⇒ Object constructor
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize ⇒ Object
49 |
# File 'sig/stigg/models/v1/usage_estimate_cost_params.rbs', line 49
def initialize: (
|
Instance Attribute Details
#customer_id ⇒ String
Customer id
15 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 15 required :customer_id, String, api_name: :customerId |
#dimensions ⇒ Hash{Symbol=>String, Float, Boolean}?
Additional dimensions for the usage report
33 34 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 33 optional :dimensions, -> { Stigg::Internal::Type::HashOf[union: Stigg::V1::UsageEstimateCostParams::Dimension] } |
#feature_id ⇒ String
Feature id
21 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 21 required :feature_id, String, api_name: :featureId |
#resource_id ⇒ String?
Resource id
40 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 40 optional :resource_id, String, api_name: :resourceId, nil?: true |
#update_behavior ⇒ Symbol, ...
The method by which the usage value should be updated
46 47 48 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 46 optional :update_behavior, enum: -> { Stigg::V1::UsageEstimateCostParams::UpdateBehavior }, api_name: :updateBehavior |
#value ⇒ Integer
The value to report for usage
27 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 27 required :value, Integer |
#x_account_id ⇒ String?
53 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 53 optional :x_account_id, String |
#x_environment_id ⇒ String?
58 |
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 58 optional :x_environment_id, String |
Class Method Details
.variants ⇒ Array(String, Float, Boolean)
|
|
# File 'lib/stigg/models/v1/usage_estimate_cost_params.rb', line 88
|
Instance Method Details
#to_hash ⇒ {
61 |
# File 'sig/stigg/models/v1/usage_estimate_cost_params.rbs', line 61
def to_hash: -> {
|