Class: Stigg::Models::V1::UsageHistoryResponse::Data::Series

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/usage_history_response.rb

Defined Under Namespace

Classes: Point, Tag

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(is_reset_point:, timestamp:, value:) ⇒ Object

Some parameter documentations has been truncated, see Point for more details.

Single usage data point

Parameters:

  • is_reset_point (Boolean)

    Indicates whether there was usage reset in this point, see ‘markers` for details

  • timestamp (Time)

    Timestamp of the usage history point

  • value (Float)

    Value of the usage history point



# File 'lib/stigg/models/v1/usage_history_response.rb', line 117

Instance Attribute Details

#pointsArray<Stigg::Models::V1::UsageHistoryResponse::Data::Series::Point>

Points in the usage history series



81
82
# File 'lib/stigg/models/v1/usage_history_response.rb', line 81

required :points,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::UsageHistoryResponse::Data::Series::Point] }

#tagsArray<Stigg::Models::V1::UsageHistoryResponse::Data::Series::Tag>

Tags for the usage history series



88
89
# File 'lib/stigg/models/v1/usage_history_response.rb', line 88

required :tags,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::UsageHistoryResponse::Data::Series::Tag] }