Class: Stigg::Models::V1::UsageHistoryResponse::Data::Series::Point

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/usage_history_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(points:, tags:) ⇒ Object

Usage data points with tags

Parameters:



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
# File 'lib/stigg/models/v1/usage_history_response.rb', line 98

class Point < Stigg::Internal::Type::BaseModel
  # @!attribute is_reset_point
  #   Indicates whether there was usage reset in this point, see `markers` for details
  #
  #   @return [Boolean]
  required :is_reset_point, Stigg::Internal::Type::Boolean, api_name: :isResetPoint

  # @!attribute timestamp
  #   Timestamp of the usage history point
  #
  #   @return [Time]
  required :timestamp, Time

  # @!attribute value
  #   Value of the usage history point
  #
  #   @return [Float]
  required :value, Float

  # @!method initialize(is_reset_point:, timestamp:, value:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1::UsageHistoryResponse::Data::Series::Point} for more details.
  #
  #   Single usage data point
  #
  #   @param is_reset_point [Boolean] Indicates whether there was usage reset in this point, see `markers` for details
  #
  #   @param timestamp [Time] Timestamp of the usage history point
  #
  #   @param value [Float] Value of the usage history point
end

Instance Attribute Details

#is_reset_pointBoolean

Indicates whether there was usage reset in this point, see ‘markers` for details

Returns:

  • (Boolean)


103
# File 'lib/stigg/models/v1/usage_history_response.rb', line 103

required :is_reset_point, Stigg::Internal::Type::Boolean, api_name: :isResetPoint

#timestampTime

Timestamp of the usage history point

Returns:

  • (Time)


109
# File 'lib/stigg/models/v1/usage_history_response.rb', line 109

required :timestamp, Time

#valueFloat

Value of the usage history point

Returns:

  • (Float)


115
# File 'lib/stigg/models/v1/usage_history_response.rb', line 115

required :value, Float