Class: Stigg::Models::V1Beta::Customers::AssignmentListParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::AssignmentListParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1_beta/customers/assignment_list_params.rb,
sig/stigg/models/v1_beta/customers/assignment_list_params.rbs
Overview
Instance Attribute Summary collapse
-
#after ⇒ String?
Return items that come after this cursor.
-
#before ⇒ String?
Return items that come before this cursor.
-
#currency_id ⇒ String?
Filter assignments to a specific currency, by its ID.
-
#entity_id ⇒ String?
Filter assignments to a specific entity ID.
-
#feature_id ⇒ String?
Filter assignments to a specific feature, by its ID.
- #id ⇒ String
-
#limit ⇒ Integer?
Maximum number of items to return.
- #x_account_id ⇒ String?
- #x_environment_id ⇒ String?
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, after: nil, before: nil, currency_id: nil, entity_id: nil, feature_id: nil, limit: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see AssignmentListParams for more details.
- #to_hash ⇒ {
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, after: nil, before: nil, currency_id: nil, entity_id: nil, feature_id: nil, limit: nil, x_account_id: nil, x_environment_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1Beta::Customers::AssignmentListParams for more details.
|
|
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 65
|
Instance Attribute Details
#after ⇒ String?
Return items that come after this cursor
21 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 21 optional :after, String |
#before ⇒ String?
Return items that come before this cursor
27 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 27 optional :before, String |
#currency_id ⇒ String?
Filter assignments to a specific currency, by its ID. Mutually exclusive with
featureId.
34 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 34 optional :currency_id, String |
#entity_id ⇒ String?
Filter assignments to a specific entity ID
40 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 40 optional :entity_id, String |
#feature_id ⇒ String?
Filter assignments to a specific feature, by its ID. Mutually exclusive with
currencyId.
47 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 47 optional :feature_id, String |
#id ⇒ String
15 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 15 required :id, String |
#limit ⇒ Integer?
Maximum number of items to return
53 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 53 optional :limit, Integer |
#x_account_id ⇒ String?
58 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 58 optional :x_account_id, String |
#x_environment_id ⇒ String?
63 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_params.rb', line 63 optional :x_environment_id, String |
Instance Method Details
#to_hash ⇒ {
70 |
# File 'sig/stigg/models/v1_beta/customers/assignment_list_params.rbs', line 70
def to_hash: -> {
|