Class: Stigg::Models::V1Beta::Customers::EntityRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::EntityRetrieveResponse::Data
- Defined in:
- lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity.
-
#type_id ⇒ String
The entity type identifier this entity instantiates.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
constructor
A stored entity instance tracked by the governance service for a given customer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
A stored entity instance tracked by the governance service for a given customer
|
|
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 58
|
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
32 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 32 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
38 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 38 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the entity
26 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 26 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity
44 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 44 required :metadata, Stigg::Internal::Type::HashOf[String] |
#type_id ⇒ String
The entity type identifier this entity instantiates
50 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 50 required :type_id, String, api_name: :typeId |
#updated_at ⇒ Time
Timestamp of when the record was last updated
56 |
# File 'lib/stigg/models/v1_beta/customers/entity_retrieve_response.rb', line 56 required :updated_at, Time, api_name: :updatedAt |