Class: Stigg::Models::V1Beta::Customers::EntityUpsertResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1_beta/customers/entity_upsert_response.rb,
sig/stigg/models/v1_beta/customers/entity_upsert_response.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, archived_at:, created_at:, display_name:, entity_type_id:, metadata:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1Beta::Customers::EntityUpsertResponse::Data for more details.

A stored entity instance tracked by the governance service for a given customer

Parameters:

  • id (String)

    The unique identifier for the entity

  • archived_at (Time, nil)

    Timestamp of when the record was deleted

  • created_at (Time)

    Timestamp of when the record was created

  • display_name (String, nil)

    Human-readable name for the entity, or null when none is set — in which case cli

  • entity_type_id (String)

    The entity type identifier this entity instantiates

  • metadata (Hash{Symbol=>String})

    Free-form key/value metadata attached to the entity

  • updated_at (Time)

    Timestamp of when the record was last updated



20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 20

class Data < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   The unique identifier for the entity
  #
  #   @return [String]
  required :id, String

  # @!attribute archived_at
  #   Timestamp of when the record was deleted
  #
  #   @return [Time, nil]
  required :archived_at, Time, api_name: :archivedAt, nil?: true

  # @!attribute created_at
  #   Timestamp of when the record was created
  #
  #   @return [Time]
  required :created_at, Time, api_name: :createdAt

  # @!attribute display_name
  #   Human-readable name for the entity, or null when none is set — in which case
  #   clients display the entity ID
  #
  #   @return [String, nil]
  required :display_name, String, api_name: :displayName, nil?: true

  # @!attribute entity_type_id
  #   The entity type identifier this entity instantiates
  #
  #   @return [String]
  required :entity_type_id, String, api_name: :entityTypeId

  # @!attribute metadata
  #   Free-form key/value metadata attached to the entity
  #
  #   @return [Hash{Symbol=>String}]
  required :metadata, Stigg::Internal::Type::HashOf[String]

  # @!attribute updated_at
  #   Timestamp of when the record was last updated
  #
  #   @return [Time]
  required :updated_at, Time, api_name: :updatedAt

  # @!method initialize(id:, archived_at:, created_at:, display_name:, entity_type_id:, metadata:, updated_at:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1Beta::Customers::EntityUpsertResponse::Data} for more details.
  #
  #   A stored entity instance tracked by the governance service for a given customer
  #
  #   @param id [String] The unique identifier for the entity
  #
  #   @param archived_at [Time, nil] Timestamp of when the record was deleted
  #
  #   @param created_at [Time] Timestamp of when the record was created
  #
  #   @param display_name [String, nil] Human-readable name for the entity, or null when none is set — in which case cli
  #
  #   @param entity_type_id [String] The entity type identifier this entity instantiates
  #
  #   @param metadata [Hash{Symbol=>String}] Free-form key/value metadata attached to the entity
  #
  #   @param updated_at [Time] Timestamp of when the record was last updated
end

Instance Attribute Details

#archived_atTime?

Timestamp of when the record was deleted

Parameters:

  • value (Time, nil)

Returns:

  • (Time, nil)


31
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 31

required :archived_at, Time, api_name: :archivedAt, nil?: true

#created_atTime

Timestamp of when the record was created

Parameters:

  • value (Time)

Returns:

  • (Time)


37
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 37

required :created_at, Time, api_name: :createdAt

#display_nameString?

Human-readable name for the entity, or null when none is set — in which case clients display the entity ID

Parameters:

  • value (String, nil)

Returns:

  • (String, nil)


44
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 44

required :display_name, String, api_name: :displayName, nil?: true

#entity_type_idString

The entity type identifier this entity instantiates

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 50

required :entity_type_id, String, api_name: :entityTypeId

#idString

The unique identifier for the entity

Parameters:

  • value (String)

Returns:

  • (String)


25
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 25

required :id, String

#metadataHash{Symbol=>String}

Free-form key/value metadata attached to the entity

Parameters:

  • value (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String})


56
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 56

required :metadata, Stigg::Internal::Type::HashOf[String]

#updated_atTime

Timestamp of when the record was last updated

Parameters:

  • value (Time)

Returns:

  • (Time)


62
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 62

required :updated_at, Time, api_name: :updatedAt

Instance Method Details

#to_hash{

Returns:

  • ({)


57
# File 'sig/stigg/models/v1_beta/customers/entity_upsert_response.rbs', line 57

def to_hash: -> {