Class: Stigg::Models::V1Beta::EntityListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::EntityListResponse
- Defined in:
- lib/stigg/models/v1_beta/entity_list_response.rb
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity.
-
#type_id ⇒ String
The entity type identifier this entity instantiates.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
constructor
A stored entity instance tracked by the governance service for a given customer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
A stored entity instance tracked by the governance service for a given customer
|
|
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 44
|
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
18 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 18 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
24 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 24 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the entity
12 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity
30 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 30 required :metadata, Stigg::Internal::Type::HashOf[String] |
#type_id ⇒ String
The entity type identifier this entity instantiates
36 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 36 required :type_id, String, api_name: :typeId |
#updated_at ⇒ Time
Timestamp of when the record was last updated
42 |
# File 'lib/stigg/models/v1_beta/entity_list_response.rb', line 42 required :updated_at, Time, api_name: :updatedAt |