Class: Stigg::Models::V1Beta::EntityRetrieveResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::EntityRetrieveResponse::Data
- Defined in:
- lib/stigg/models/v1_beta/entity_retrieve_response.rb
Overview
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity.
-
#type_id ⇒ String
The entity type identifier this entity instantiates.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
constructor
A stored entity instance tracked by the governance service for a given customer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
A stored entity instance tracked by the governance service for a given customer
|
|
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 57
|
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
31 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 31 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
37 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 37 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the entity
25 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 25 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity
43 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 43 required :metadata, Stigg::Internal::Type::HashOf[String] |
#type_id ⇒ String
The entity type identifier this entity instantiates
49 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 49 required :type_id, String, api_name: :typeId |
#updated_at ⇒ Time
Timestamp of when the record was last updated
55 |
# File 'lib/stigg/models/v1_beta/entity_retrieve_response.rb', line 55 required :updated_at, Time, api_name: :updatedAt |