Class: Stigg::Models::V1Beta::EntityTypeUpsertParams::Type

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1_beta/entity_type_upsert_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, attribution_keys:, display_name:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1Beta::EntityTypeUpsertParams::Type for more details.

A single entity type definition.

Parameters:

  • id (String)

    The unique identifier for the entity

  • attribution_keys (Array<String>)

    Dimension keys used to attribute usage events to instances of this type (e.g. [“

  • display_name (String)

    The display name for the entity type



36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 36

class Type < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   The unique identifier for the entity
  #
  #   @return [String]
  required :id, String

  # @!attribute attribution_keys
  #   Dimension keys used to attribute usage events to instances of this type (e.g.
  #   ["orgId"]). Empty array means no attribution.
  #
  #   @return [Array<String>]
  required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys

  # @!attribute display_name
  #   The display name for the entity type
  #
  #   @return [String]
  required :display_name, String, api_name: :displayName

  # @!method initialize(id:, attribution_keys:, display_name:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1Beta::EntityTypeUpsertParams::Type} for more details.
  #
  #   A single entity type definition.
  #
  #   @param id [String] The unique identifier for the entity
  #
  #   @param attribution_keys [Array<String>] Dimension keys used to attribute usage events to instances of this type (e.g. ["
  #
  #   @param display_name [String] The display name for the entity type
end

Instance Attribute Details

#attribution_keysArray<String>

Dimension keys used to attribute usage events to instances of this type (e.g. [“orgId”]). Empty array means no attribution.

Returns:

  • (Array<String>)


48
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 48

required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys

#display_nameString

The display name for the entity type

Returns:

  • (String)


54
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 54

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the entity

Returns:

  • (String)


41
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 41

required :id, String