Class: Stigg::Models::Internal::Beta::EventQueueProvisionParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::Internal::Beta::EventQueueProvisionParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/internal/beta/event_queue_provision_params.rb
Overview
Defined Under Namespace
Instance Attribute Summary collapse
-
#allowed_assume_role_arns ⇒ Array<String>?
Additional IAM role ARNs allowed to assume the external role for queue access.
-
#create_low_priority_queues ⇒ Boolean?
Whether to create separate low-priority queues for standard topic events.
-
#event_types ⇒ Array<Symbol, Stigg::Models::Internal::Beta::EventQueueProvisionParams::EventType>?
Event types to subscribe to.
-
#region ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueProvisionParams::Region
AWS region for the SQS queue (e.g., us-east-1, eu-west-1).
-
#suffix ⇒ String?
Optional suffix to allow multiple queues for the same environment and region.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(region:, allowed_assume_role_arns: nil, create_low_priority_queues: nil, event_types: nil, suffix: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EventQueueProvisionParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(region:, allowed_assume_role_arns: nil, create_low_priority_queues: nil, event_types: nil, suffix: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::Internal::Beta::EventQueueProvisionParams for more details.
|
|
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 49
|
Instance Attribute Details
#allowed_assume_role_arns ⇒ Array<String>?
Additional IAM role ARNs allowed to assume the external role for queue access
22 23 24 |
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 22 optional :allowed_assume_role_arns, Stigg::Internal::Type::ArrayOf[String], api_name: :allowedAssumeRoleArns |
#create_low_priority_queues ⇒ Boolean?
Whether to create separate low-priority queues for standard topic events
30 31 32 |
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 30 optional :create_low_priority_queues, Stigg::Internal::Type::Boolean, api_name: :createLowPriorityQueues |
#event_types ⇒ Array<Symbol, Stigg::Models::Internal::Beta::EventQueueProvisionParams::EventType>?
Event types to subscribe to. Defaults to entitlements, measurements, and migrations.
39 40 41 |
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 39 optional :event_types, -> { Stigg::Internal::Type::ArrayOf[enum: Stigg::Models::Internal::Beta::EventQueueProvisionParams::EventType] }, api_name: :eventTypes |
#region ⇒ Symbol, Stigg::Models::Internal::Beta::EventQueueProvisionParams::Region
AWS region for the SQS queue (e.g., us-east-1, eu-west-1)
16 |
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 16 required :region, enum: -> { Stigg::Models::Internal::Beta::EventQueueProvisionParams::Region } |
#suffix ⇒ String?
Optional suffix to allow multiple queues for the same environment and region
47 |
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 47 optional :suffix, String |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/internal/beta/event_queue_provision_params.rb', line 97
|