Class: Stigg::Models::V1::AddonCreateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonCreateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/addon_create_params.rb
Overview
Defined Under Namespace
Modules: PricingType, Status
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String
The display name of the package.
-
#id ⇒ String
The unique identifier for the entity.
-
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription.
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity.
-
#pricing_type ⇒ Symbol, ...
The pricing type of the package.
-
#product_id ⇒ String
The product id of the package.
-
#status ⇒ Symbol, ...
The status of the package.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, display_name:, product_id:, billing_id: nil, description: nil, max_quantity: nil, metadata: nil, pricing_type: nil, status: nil, request_options: {}) ⇒ Object
|
|
# File 'lib/stigg/models/v1/addon_create_params.rb', line 68
|
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
33 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 33 optional :billing_id, String, api_name: :billingId, nil?: true |
#description ⇒ String?
The description of the package
39 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 39 optional :description, String, nil?: true |
#display_name ⇒ String
The display name of the package
21 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 21 required :display_name, String, api_name: :displayName |
#id ⇒ String
The unique identifier for the entity
15 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 15 required :id, String |
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription
45 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 45 optional :max_quantity, Integer, api_name: :maxQuantity, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity
51 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 51 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#pricing_type ⇒ Symbol, ...
The pricing type of the package
57 58 59 60 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 57 optional :pricing_type, enum: -> { Stigg::V1::AddonCreateParams::PricingType }, api_name: :pricingType, nil?: true |
#product_id ⇒ String
The product id of the package
27 |
# File 'lib/stigg/models/v1/addon_create_params.rb', line 27 required :product_id, String, api_name: :productId |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/addon_create_params.rb', line 97
|