Class: Stigg::Models::V1::AddonListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonListResponse
- Defined in:
- lib/stigg/models/v1/addon_list_response.rb
Overview
Defined Under Namespace
Modules: PricingType, Status Classes: Entitlement
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#dependencies ⇒ Array<String>?
List of addons the addon is dependant on.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String
The display name of the package.
-
#entitlements ⇒ Array<Stigg::Models::V1::AddonListResponse::Entitlement>
List of entitlements of the package.
-
#id ⇒ String
The unique identifier for the entity.
-
#is_latest ⇒ Boolean?
Indicates if the package is the latest version.
-
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription.
-
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity.
-
#pricing_type ⇒ Symbol, ...
The pricing type of the package.
-
#product_id ⇒ String
The product id of the package.
-
#status ⇒ Symbol, Stigg::Models::V1::AddonListResponse::Status
The status of the package.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
-
#version_number ⇒ Integer
The version number of the package.
Class Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
18 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 18 required :billing_id, String, api_name: :billingId, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
24 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 24 required :created_at, Time, api_name: :createdAt |
#dependencies ⇒ Array<String>?
List of addons the addon is dependant on
30 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 30 required :dependencies, Stigg::Internal::Type::ArrayOf[String], nil?: true |
#description ⇒ String?
The description of the package
36 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 36 required :description, String, nil?: true |
#display_name ⇒ String
The display name of the package
42 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 42 required :display_name, String, api_name: :displayName |
#entitlements ⇒ Array<Stigg::Models::V1::AddonListResponse::Entitlement>
List of entitlements of the package
48 49 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 48 required :entitlements, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::AddonListResponse::Entitlement] } |
#id ⇒ String
The unique identifier for the entity
12 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 12 required :id, String |
#is_latest ⇒ Boolean?
Indicates if the package is the latest version
55 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 55 required :is_latest, Stigg::Internal::Type::Boolean, api_name: :isLatest, nil?: true |
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription
61 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 61 required :max_quantity, Integer, api_name: :maxQuantity, nil?: true |
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity
67 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 67 required :metadata, Stigg::Internal::Type::HashOf[String] |
#pricing_type ⇒ Symbol, ...
The pricing type of the package
73 74 75 76 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 73 required :pricing_type, enum: -> { Stigg::Models::V1::AddonListResponse::PricingType }, api_name: :pricingType, nil?: true |
#product_id ⇒ String
The product id of the package
82 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 82 required :product_id, String, api_name: :productId |
#status ⇒ Symbol, Stigg::Models::V1::AddonListResponse::Status
The status of the package
88 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 88 required :status, enum: -> { Stigg::Models::V1::AddonListResponse::Status } |
#updated_at ⇒ Time
Timestamp of when the record was last updated
94 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 94 required :updated_at, Time, api_name: :updatedAt |
#version_number ⇒ Integer
The version number of the package
100 |
# File 'lib/stigg/models/v1/addon_list_response.rb', line 100 required :version_number, Integer, api_name: :versionNumber |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/addon_list_response.rb', line 161
|