Class: Stigg::Models::V1::AddonUpdateParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::AddonUpdateParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/addon_update_params.rb
Overview
Defined Under Namespace
Modules: Status Classes: Charges
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#charges ⇒ Stigg::Models::V1::AddonUpdateParams::Charges?
Pricing configuration to set on the addon draft.
-
#dependencies ⇒ Array<String>?
List of addons the addon is dependant on.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String?
The display name of the package.
- #id ⇒ String
-
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription.
-
#metadata ⇒ Hash{Symbol=>String}?
Metadata associated with the entity.
-
#status ⇒ Symbol, ...
The status of the package.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
20 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 20 optional :billing_id, String, api_name: :billingId, nil?: true |
#charges ⇒ Stigg::Models::V1::AddonUpdateParams::Charges?
Pricing configuration to set on the addon draft
26 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 26 optional :charges, -> { Stigg::V1::AddonUpdateParams::Charges } |
#dependencies ⇒ Array<String>?
List of addons the addon is dependant on
32 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 32 optional :dependencies, Stigg::Internal::Type::ArrayOf[String], nil?: true |
#description ⇒ String?
The description of the package
38 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 38 optional :description, String, nil?: true |
#display_name ⇒ String?
The display name of the package
44 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 44 optional :display_name, String, api_name: :displayName |
#id ⇒ String
14 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 14 required :id, String |
#max_quantity ⇒ Integer?
The maximum quantity of this addon that can be added to a subscription
50 |
# File 'lib/stigg/models/v1/addon_update_params.rb', line 50 optional :max_quantity, Integer, api_name: :maxQuantity, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/addon_update_params.rb', line 2159
|