Class: Stigg::Models::V1::CreditGetUsageResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CreditGetUsageResponse::Data
- Defined in:
- lib/stigg/models/v1/credit_get_usage_response.rb
Overview
Defined Under Namespace
Classes: Currency, Pagination, Series
Instance Attribute Summary collapse
-
#currency ⇒ Stigg::Models::V1::CreditGetUsageResponse::Data::Currency?
The custom currency used for credit measurement.
-
#pagination ⇒ Stigg::Models::V1::CreditGetUsageResponse::Data::Pagination
Cursor-based pagination for the returned series.
-
#series ⇒ Array<Stigg::Models::V1::CreditGetUsageResponse::Data::Series>
Credit usage series grouped by feature.
Instance Method Summary collapse
-
#initialize(next_:, prev:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Pagination for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(next_:, prev:) ⇒ Object
Some parameter documentations has been truncated, see Pagination for more details.
Cursor-based pagination for the returned series. ‘next`/`prev` are opaque cursors; pass them back as `after`/`before` to traverse pages. The series axis is `groupBy` when provided, otherwise `featureId`
|
|
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 42
|
Instance Attribute Details
#currency ⇒ Stigg::Models::V1::CreditGetUsageResponse::Data::Currency?
The custom currency used for credit measurement
25 |
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 25 required :currency, -> { Stigg::Models::V1::CreditGetUsageResponse::Data::Currency }, nil?: true |
#pagination ⇒ Stigg::Models::V1::CreditGetUsageResponse::Data::Pagination
Cursor-based pagination for the returned series. ‘next`/`prev` are opaque cursors; pass them back as `after`/`before` to traverse pages. The series axis is `groupBy` when provided, otherwise `featureId`
33 |
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 33 required :pagination, -> { Stigg::Models::V1::CreditGetUsageResponse::Data::Pagination } |