Class: Stigg::Models::V1::CreditGetUsageResponse::Data::Series

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/credit_get_usage_response.rb

Defined Under Namespace

Classes: Point, Tag

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(timestamp:, value:) ⇒ Object

A single data point in the credit usage time series

Parameters:

  • timestamp (Time)

    The timestamp of the data point

  • value (Float)

    The credit usage value at this point



# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 146

Instance Attribute Details

#feature_idString?

The feature ID; null when grouping by dimensions only

Returns:

  • (String, nil)


92
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 92

required :feature_id, String, api_name: :featureId, nil?: true

#feature_nameString?

The display name of the feature; null when grouping by dimensions only

Returns:

  • (String, nil)


98
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 98

required :feature_name, String, api_name: :featureName, nil?: true

#pointsArray<Stigg::Models::V1::CreditGetUsageResponse::Data::Series::Point>

Time-series data points for this feature



104
105
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 104

required :points,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CreditGetUsageResponse::Data::Series::Point] }

#tagsArray<Stigg::Models::V1::CreditGetUsageResponse::Data::Series::Tag>?

Dimension key/value pairs identifying this series when groupBy is applied



117
118
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 117

optional :tags,
-> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CreditGetUsageResponse::Data::Series::Tag] }

#total_creditsFloat

Total credits consumed by this feature in the time range

Returns:

  • (Float)


111
# File 'lib/stigg/models/v1/credit_get_usage_response.rb', line 111

required :total_credits, Float, api_name: :totalCredits