Class: Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature
- Defined in:
- lib/stigg/models/v1/customer_check_entitlement_response.rb
Defined Under Namespace
Modules: AccessDeniedReason, ResetPeriod Classes: Feature
Instance Attribute Summary collapse
- #access_denied_reason ⇒ Symbol, ...
- #current_usage ⇒ Float?
-
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
- #feature ⇒ Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature::Feature?
- #has_unlimited_usage ⇒ Boolean?
- #is_granted ⇒ Boolean
- #reset_period ⇒ Symbol, ...
- #type ⇒ Symbol, :FEATURE
- #usage_limit ⇒ Float?
-
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured.
-
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured.
-
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured.
-
#valid_until ⇒ Time?
The next time the entitlement should be recalculated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(access_denied_reason:, is_granted:, current_usage: nil, entitlement_updated_at: nil, feature: nil, has_unlimited_usage: nil, reset_period: nil, usage_limit: nil, usage_period_anchor: nil, usage_period_end: nil, usage_period_start: nil, valid_until: nil, type: :FEATURE) ⇒ Object
constructor
Some parameter documentations has been truncated, see Feature for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(access_denied_reason:, is_granted:, current_usage: nil, entitlement_updated_at: nil, feature: nil, has_unlimited_usage: nil, reset_period: nil, usage_limit: nil, usage_period_anchor: nil, usage_period_end: nil, usage_period_start: nil, valid_until: nil, type: :FEATURE) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature for more details.
|
|
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 108
|
Instance Attribute Details
#access_denied_reason ⇒ Symbol, ...
32 33 34 35 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 32 required :access_denied_reason, enum: -> { Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature::AccessDeniedReason }, api_name: :accessDeniedReason, nil?: true |
#current_usage ⇒ Float?
50 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 50 optional :current_usage, Float, api_name: :currentUsage |
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
56 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 56 optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt |
#feature ⇒ Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature::Feature?
61 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 61 optional :feature, -> { Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature::Feature } |
#has_unlimited_usage ⇒ Boolean?
66 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 66 optional :has_unlimited_usage, Stigg::Internal::Type::Boolean, api_name: :hasUnlimitedUsage |
#is_granted ⇒ Boolean
40 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 40 required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted |
#reset_period ⇒ Symbol, ...
71 72 73 74 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 71 optional :reset_period, enum: -> { Stigg::Models::V1::CustomerCheckEntitlementResponse::Data::Feature::ResetPeriod }, api_name: :resetPeriod, nil?: true |
#type ⇒ Symbol, :FEATURE
45 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 45 required :type, const: :FEATURE |
#usage_limit ⇒ Float?
79 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 79 optional :usage_limit, Float, api_name: :usageLimit, nil?: true |
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured
86 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 86 optional :usage_period_anchor, Time, api_name: :usagePeriodAnchor |
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured
93 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 93 optional :usage_period_end, Time, api_name: :usagePeriodEnd |
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured
100 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 100 optional :usage_period_start, Time, api_name: :usagePeriodStart |
#valid_until ⇒ Time?
The next time the entitlement should be recalculated
106 |
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 106 optional :valid_until, Time, api_name: :validUntil |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_check_entitlement_response.rb', line 158
|