Class: Stigg::Models::V1::CustomerImportParams::Customer

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1/customer_import_params.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, email:, name:, billing_id: nil, metadata: nil, payment_method_id: nil, salesforce_id: nil, updated_at: nil) ⇒ Object

Parameters:

  • id (String)

    Customer slug

  • email (String, nil)

    The email of the customer

  • name (String, nil)

    The name of the customer

  • billing_id (String) (defaults to: nil)

    Id in the billing provider

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Additional metadata

  • payment_method_id (String) (defaults to: nil)

    Billing provider payment method id

  • salesforce_id (String) (defaults to: nil)

    The unique identifier for the customer in Salesforce integration

  • updated_at (Time) (defaults to: nil)

    Timestamp of when the record was last updated



30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
# File 'lib/stigg/models/v1/customer_import_params.rb', line 30

class Customer < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   Customer slug
  #
  #   @return [String]
  required :id, String

  # @!attribute email
  #   The email of the customer
  #
  #   @return [String, nil]
  required :email, String, nil?: true

  # @!attribute name
  #   The name of the customer
  #
  #   @return [String, nil]
  required :name, String, nil?: true

  # @!attribute billing_id
  #   Id in the billing provider
  #
  #   @return [String, nil]
  optional :billing_id, String, api_name: :billingId

  # @!attribute metadata
  #   Additional metadata
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :metadata, Stigg::Internal::Type::HashOf[String]

  # @!attribute payment_method_id
  #   Billing provider payment method id
  #
  #   @return [String, nil]
  optional :payment_method_id, String, api_name: :paymentMethodId

  # @!attribute salesforce_id
  #   The unique identifier for the customer in Salesforce integration
  #
  #   @return [String, nil]
  optional :salesforce_id, String, api_name: :salesforceId

  # @!attribute updated_at
  #   Timestamp of when the record was last updated
  #
  #   @return [Time, nil]
  optional :updated_at, Time, api_name: :updatedAt

  # @!method initialize(id:, email:, name:, billing_id: nil, metadata: nil, payment_method_id: nil, salesforce_id: nil, updated_at: nil)
  #   @param id [String] Customer slug
  #
  #   @param email [String, nil] The email of the customer
  #
  #   @param name [String, nil] The name of the customer
  #
  #   @param billing_id [String] Id in the billing provider
  #
  #   @param metadata [Hash{Symbol=>String}] Additional metadata
  #
  #   @param payment_method_id [String] Billing provider payment method id
  #
  #   @param salesforce_id [String] The unique identifier for the customer in Salesforce integration
  #
  #   @param updated_at [Time] Timestamp of when the record was last updated
end

Instance Attribute Details

#billing_idString?

Id in the billing provider

Returns:

  • (String, nil)


53
# File 'lib/stigg/models/v1/customer_import_params.rb', line 53

optional :billing_id, String, api_name: :billingId

#emailString?

The email of the customer

Returns:

  • (String, nil)


41
# File 'lib/stigg/models/v1/customer_import_params.rb', line 41

required :email, String, nil?: true

#idString

Customer slug

Returns:

  • (String)


35
# File 'lib/stigg/models/v1/customer_import_params.rb', line 35

required :id, String

#metadataHash{Symbol=>String}?

Additional metadata

Returns:

  • (Hash{Symbol=>String}, nil)


59
# File 'lib/stigg/models/v1/customer_import_params.rb', line 59

optional :metadata, Stigg::Internal::Type::HashOf[String]

#nameString?

The name of the customer

Returns:

  • (String, nil)


47
# File 'lib/stigg/models/v1/customer_import_params.rb', line 47

required :name, String, nil?: true

#payment_method_idString?

Billing provider payment method id

Returns:

  • (String, nil)


65
# File 'lib/stigg/models/v1/customer_import_params.rb', line 65

optional :payment_method_id, String, api_name: :paymentMethodId

#salesforce_idString?

The unique identifier for the customer in Salesforce integration

Returns:

  • (String, nil)


71
# File 'lib/stigg/models/v1/customer_import_params.rb', line 71

optional :salesforce_id, String, api_name: :salesforceId

#updated_atTime?

Timestamp of when the record was last updated

Returns:

  • (Time, nil)


77
# File 'lib/stigg/models/v1/customer_import_params.rb', line 77

optional :updated_at, Time, api_name: :updatedAt