Class: Stigg::Models::V1::CustomerListInvoicesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListInvoicesResponse
- Defined in:
- lib/stigg/models/v1/customer_list_invoices_response.rb,
sig/stigg/models/v1/customer_list_invoices_response.rbs
Overview
Defined Under Namespace
Modules: State Classes: LineItem
Instance Attribute Summary collapse
-
#contract_external_id ⇒ String?
External ID of the contract the invoice belongs to: your contract ref when mapped, otherwise the Received contract ID.
-
#currency ⇒ String?
The ISO-4217 currency code of the invoice.
-
#customer_external_id ⇒ String?
External ID of the customer the invoice belongs to: your customer ref when mapped, otherwise the Received customer ID.
-
#discount ⇒ Float?
The total discount amount.
-
#due_date ⇒ Time?
The date payment is due.
-
#invoice_external_id ⇒ String?
External ID for the invoice: the mapped external ID when one exists, otherwise the invoice ID.
-
#invoice_id ⇒ String
The billing provider (Received) invoice ID.
-
#invoice_number ⇒ String?
The invoice document number (or draft number while the invoice is unissued).
-
#issue_date ⇒ Time?
The date the invoice was issued.
-
#line_items ⇒ Array<Stigg::Models::V1::CustomerListInvoicesResponse::LineItem>
The invoice line items.
-
#paid_date ⇒ Time?
The date the invoice was reconciled as paid; present once reconciled.
-
#state ⇒ Symbol, Stigg::Models::V1::CustomerListInvoicesResponse::State
The invoice status (open, paid, or canceled).
-
#subtotal ⇒ Float?
The pre-tax subtotal.
-
#tax ⇒ Float?
The total tax amount.
-
#total ⇒ Float?
The total amount due.
Instance Method Summary collapse
-
#initialize(amount:, description:, product_external_id:, quantity:, unit_price:) ⇒ Object
constructor
A single line item on an invoice.
- #to_hash ⇒ {
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(amount:, description:, product_external_id:, quantity:, unit_price:) ⇒ Object
A single line item on an invoice.
|
|
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 170
|
Instance Attribute Details
#contract_external_id ⇒ String?
External ID of the contract the invoice belongs to: your contract ref when mapped, otherwise the Received contract ID
13 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 13 required :contract_external_id, String, api_name: :contractExternalId, nil?: true |
#currency ⇒ String?
The ISO-4217 currency code of the invoice
19 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 19 required :currency, String, nil?: true |
#customer_external_id ⇒ String?
External ID of the customer the invoice belongs to: your customer ref when mapped, otherwise the Received customer ID
26 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 26 required :customer_external_id, String, api_name: :customerExternalId, nil?: true |
#discount ⇒ Float?
The total discount amount
32 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 32 required :discount, Float, nil?: true |
#due_date ⇒ Time?
The date payment is due
38 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 38 required :due_date, Time, api_name: :dueDate, nil?: true |
#invoice_external_id ⇒ String?
External ID for the invoice: the mapped external ID when one exists, otherwise the invoice ID
45 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 45 required :invoice_external_id, String, api_name: :invoiceExternalId, nil?: true |
#invoice_id ⇒ String
The billing provider (Received) invoice ID
51 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 51 required :invoice_id, String, api_name: :invoiceId |
#invoice_number ⇒ String?
The invoice document number (or draft number while the invoice is unissued)
57 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 57 required :invoice_number, String, api_name: :invoiceNumber, nil?: true |
#issue_date ⇒ Time?
The date the invoice was issued
63 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 63 required :issue_date, Time, api_name: :issueDate, nil?: true |
#line_items ⇒ Array<Stigg::Models::V1::CustomerListInvoicesResponse::LineItem>
The invoice line items
69 70 71 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 69 required :line_items, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::CustomerListInvoicesResponse::LineItem] }, api_name: :lineItems |
#paid_date ⇒ Time?
The date the invoice was reconciled as paid; present once reconciled
77 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 77 required :paid_date, Time, api_name: :paidDate, nil?: true |
#state ⇒ Symbol, Stigg::Models::V1::CustomerListInvoicesResponse::State
The invoice status (open, paid, or canceled)
83 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 83 required :state, enum: -> { Stigg::Models::V1::CustomerListInvoicesResponse::State } |
#subtotal ⇒ Float?
The pre-tax subtotal
89 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 89 required :subtotal, Float, nil?: true |
#tax ⇒ Float?
The total tax amount
95 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 95 required :tax, Float, nil?: true |
#total ⇒ Float?
The total amount due
101 |
# File 'lib/stigg/models/v1/customer_list_invoices_response.rb', line 101 required :total, Float, nil?: true |
Instance Method Details
#to_hash ⇒ {
72 |
# File 'sig/stigg/models/v1/customer_list_invoices_response.rbs', line 72
def to_hash: -> {
|