Class: Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerListResponse::Passthrough::Stripe::TaxID
- Defined in:
- lib/stigg/models/v1/customer_list_response.rb
Instance Attribute Summary collapse
-
#type ⇒ String
The type of tax exemption identifier, such as VAT.
-
#value ⇒ String
The actual tax identifier value.
Method Summary
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, #initialize, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
This class inherits a constructor from Stigg::Internal::Type::BaseModel
Instance Attribute Details
#type ⇒ String
The type of tax exemption identifier, such as VAT.
608 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 608 required :type, String |
#value ⇒ String
The actual tax identifier value
614 |
# File 'lib/stigg/models/v1/customer_list_response.rb', line 614 required :value, String |