Class: Stigg::Models::V1::CustomerResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::CustomerResponse::Data
- Defined in:
- lib/stigg/models/v1/customer_response.rb
Overview
Defined Under Namespace
Modules: BillingCurrency, CouponID Classes: DefaultPaymentMethod, Integration, Passthrough
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#billing_currency ⇒ Symbol, ...
The billing currency of the customer.
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
-
#coupon_id ⇒ String, ...
Customer level coupon.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#default_payment_method ⇒ Stigg::Models::V1::CustomerResponse::Data::DefaultPaymentMethod?
The default payment method details.
-
#email ⇒ String?
The email of the customer.
-
#id ⇒ String
Customer slug.
-
#integrations ⇒ Array<Stigg::Models::V1::CustomerResponse::Data::Integration>?
List of integrations.
-
#language ⇒ String?
Language to use for this customer.
-
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata.
-
#name ⇒ String?
The name of the customer.
-
#passthrough ⇒ Stigg::Models::V1::CustomerResponse::Data::Passthrough?
Vendor-specific billing passthrough fields.
-
#timezone ⇒ String?
Timezone to use for this customer.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, updated_at:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil) ⇒ Object
constructor
A customer can be either an organization or an individual.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, updated_at:, billing_currency: nil, billing_id: nil, coupon_id: nil, default_payment_method: nil, email: nil, integrations: nil, language: nil, metadata: nil, name: nil, passthrough: nil, timezone: nil) ⇒ Object
A customer can be either an organization or an individual
|
|
# File 'lib/stigg/models/v1/customer_response.rb', line 121
|
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
31 |
# File 'lib/stigg/models/v1/customer_response.rb', line 31 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#billing_currency ⇒ Symbol, ...
The billing currency of the customer
49 50 51 52 |
# File 'lib/stigg/models/v1/customer_response.rb', line 49 optional :billing_currency, enum: -> { Stigg::V1::CustomerResponse::Data::BillingCurrency }, api_name: :billingCurrency, nil?: true |
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
58 |
# File 'lib/stigg/models/v1/customer_response.rb', line 58 optional :billing_id, String, api_name: :billingId, nil?: true |
#coupon_id ⇒ String, ...
Customer level coupon
64 65 66 67 |
# File 'lib/stigg/models/v1/customer_response.rb', line 64 optional :coupon_id, union: -> { Stigg::V1::CustomerResponse::Data::CouponID }, api_name: :couponId, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
37 |
# File 'lib/stigg/models/v1/customer_response.rb', line 37 required :created_at, Time, api_name: :createdAt |
#default_payment_method ⇒ Stigg::Models::V1::CustomerResponse::Data::DefaultPaymentMethod?
The default payment method details
73 74 75 76 |
# File 'lib/stigg/models/v1/customer_response.rb', line 73 optional :default_payment_method, -> { Stigg::V1::CustomerResponse::Data::DefaultPaymentMethod }, api_name: :defaultPaymentMethod, nil?: true |
#email ⇒ String?
The email of the customer
82 |
# File 'lib/stigg/models/v1/customer_response.rb', line 82 optional :email, String, nil?: true |
#id ⇒ String
Customer slug
25 |
# File 'lib/stigg/models/v1/customer_response.rb', line 25 required :id, String |
#integrations ⇒ Array<Stigg::Models::V1::CustomerResponse::Data::Integration>?
List of integrations
88 89 |
# File 'lib/stigg/models/v1/customer_response.rb', line 88 optional :integrations, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::CustomerResponse::Data::Integration] } |
#language ⇒ String?
Language to use for this customer
95 |
# File 'lib/stigg/models/v1/customer_response.rb', line 95 optional :language, String, nil?: true |
#metadata ⇒ Hash{Symbol=>String}?
Additional metadata
101 |
# File 'lib/stigg/models/v1/customer_response.rb', line 101 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#name ⇒ String?
The name of the customer
107 |
# File 'lib/stigg/models/v1/customer_response.rb', line 107 optional :name, String, nil?: true |
#passthrough ⇒ Stigg::Models::V1::CustomerResponse::Data::Passthrough?
Vendor-specific billing passthrough fields.
113 |
# File 'lib/stigg/models/v1/customer_response.rb', line 113 optional :passthrough, -> { Stigg::V1::CustomerResponse::Data::Passthrough } |
#timezone ⇒ String?
Timezone to use for this customer
119 |
# File 'lib/stigg/models/v1/customer_response.rb', line 119 optional :timezone, String, nil?: true |
#updated_at ⇒ Time
Timestamp of when the record was last updated
43 |
# File 'lib/stigg/models/v1/customer_response.rb', line 43 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/customer_response.rb', line 277
|