Class: Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb
Overview
Instance Attribute Summary collapse
-
#currency_id ⇒ String?
Currency ID (refId) to check for credit entitlements.
-
#dimensions ⇒ Hash{Symbol=>String}?
Optional attribution map (e.g. ‘dimensions=u1`).
-
#feature_id ⇒ String?
Feature ID (refId) to check.
- #id ⇒ String
-
#requested_usage ⇒ Integer?
Requested usage amount to evaluate against the entitlement limit (numeric features only).
-
#requested_values ⇒ Array<String>?
Requested values to evaluate against allowed values (enum features only).
-
#resource_id ⇒ String?
Resource ID to scope the entitlement check to a specific resource.
Attributes included from Internal::Type::RequestParameters
Instance Method Summary collapse
-
#initialize(id:, currency_id: nil, dimensions: nil, feature_id: nil, requested_usage: nil, requested_values: nil, resource_id: nil, request_options: {}) ⇒ Object
constructor
Some parameter documentations has been truncated, see EntitlementCheckParams for more details.
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, currency_id: nil, dimensions: nil, feature_id: nil, requested_usage: nil, requested_values: nil, resource_id: nil, request_options: {}) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckParams for more details.
|
|
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 58
|
Instance Attribute Details
#currency_id ⇒ String?
Currency ID (refId) to check for credit entitlements. Mutually exclusive with ‘featureId`.
24 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 24 optional :currency_id, String |
#dimensions ⇒ Hash{Symbol=>String}?
Optional attribution map (e.g. ‘dimensions=u1`). When provided, the response includes a `chains` array with per-entity governance limits.
31 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 31 optional :dimensions, Stigg::Internal::Type::HashOf[String] |
#feature_id ⇒ String?
Feature ID (refId) to check. Mutually exclusive with ‘currencyId`.
37 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 37 optional :feature_id, String |
#id ⇒ String
17 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 17 required :id, String |
#requested_usage ⇒ Integer?
Requested usage amount to evaluate against the entitlement limit (numeric features only)
44 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 44 optional :requested_usage, Integer |
#requested_values ⇒ Array<String>?
Requested values to evaluate against allowed values (enum features only)
50 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 50 optional :requested_values, Stigg::Internal::Type::ArrayOf[String] |
#resource_id ⇒ String?
Resource ID to scope the entitlement check to a specific resource
56 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_params.rb', line 56 optional :resource_id, String |