Class: Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit
- Defined in:
- lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb
Defined Under Namespace
Modules: AccessDeniedReason Classes: Chain, Currency
Instance Attribute Summary collapse
- #access_denied_reason ⇒ Symbol, ...
-
#chains ⇒ Array<Array<Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Chain>>?
Per-entity rollups, one chain per resolved dimension.
-
#currency ⇒ Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Currency
The currency associated with a credit entitlement.
- #current_usage ⇒ Float
-
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
- #is_granted ⇒ Boolean
- #type ⇒ Symbol, :CREDIT
- #usage_limit ⇒ Float
-
#usage_period_end ⇒ Time?
The end date of the current billing period for recurring credit grants.
-
#usage_updated_at ⇒ Time
Timestamp of the last update to the credit usage.
-
#valid_until ⇒ Time?
The next time the entitlement should be recalculated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(currency_id:, display_name:, description: nil, metadata: nil, unit_plural: nil, unit_singular: nil) ⇒ Object
constructor
The currency associated with a credit entitlement.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(currency_id:, display_name:, description: nil, metadata: nil, unit_plural: nil, unit_singular: nil) ⇒ Object
The currency associated with a credit entitlement.
|
|
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 381
|
Instance Attribute Details
#access_denied_reason ⇒ Symbol, ...
313 314 315 316 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 313 required :access_denied_reason, enum: -> { Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::AccessDeniedReason }, api_name: :accessDeniedReason, nil?: true |
#chains ⇒ Array<Array<Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Chain>>?
Per-entity rollups, one chain per resolved dimension. Omitted when dimensions was not provided.
356 357 358 359 360 361 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 356 optional :chains, -> do Stigg::Internal::Type::ArrayOf[ Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Chain] ] end |
#currency ⇒ Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Currency
The currency associated with a credit entitlement.
322 323 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 322 required :currency, -> { Stigg::Models::V1::Events::Beta::Customers::EntitlementCheckResponse::Data::Credit::Currency } |
#current_usage ⇒ Float
328 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 328 required :current_usage, Float, api_name: :currentUsage |
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
367 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 367 optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt |
#is_granted ⇒ Boolean
333 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 333 required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted |
#type ⇒ Symbol, :CREDIT
338 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 338 required :type, const: :CREDIT |
#usage_limit ⇒ Float
343 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 343 required :usage_limit, Float, api_name: :usageLimit |
#usage_period_end ⇒ Time?
The end date of the current billing period for recurring credit grants.
373 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 373 optional :usage_period_end, Time, api_name: :usagePeriodEnd |
#usage_updated_at ⇒ Time
Timestamp of the last update to the credit usage.
349 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 349 required :usage_updated_at, Time, api_name: :usageUpdatedAt |
#valid_until ⇒ Time?
The next time the entitlement should be recalculated
379 |
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 379 optional :valid_until, Time, api_name: :validUntil |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/events/beta/customers/entitlement_check_response.rb', line 429
|