Class: Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination
- Defined in:
- lib/stigg/models/v1/events/data_export/destination_delete_response.rb
Defined Under Namespace
Classes: LastSyncStatus
Instance Attribute Summary collapse
-
#connected_at ⇒ String
ISO8601 timestamp of when the destination was connected.
-
#connection_status ⇒ String?
Connection status of the destination (connected, failed).
-
#destination_id ⇒ String
Provider destination ID.
-
#last_sync_status ⇒ Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus?
Latest sync snapshot for the destination, refreshed by the provider webhook.
-
#type ⇒ String
Destination type (snowflake, bigquery, …).
Instance Method Summary collapse
-
#initialize(connected_at:, destination_id:, type:, connection_status: nil, last_sync_status: nil) ⇒ Object
constructor
A single destination entry under the DATA_EXPORT integration.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(connected_at:, destination_id:, type:, connection_status: nil, last_sync_status: nil) ⇒ Object
A single destination entry under the DATA_EXPORT integration.
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 35 class Destination < Stigg::Internal::Type::BaseModel # @!attribute connected_at # ISO8601 timestamp of when the destination was connected # # @return [String] required :connected_at, String, api_name: :connectedAt # @!attribute destination_id # Provider destination ID # # @return [String] required :destination_id, String, api_name: :destinationId # @!attribute type # Destination type (snowflake, bigquery, ...) # # @return [String] required :type, String # @!attribute connection_status # Connection status of the destination (connected, failed) # # @return [String, nil] optional :connection_status, String, api_name: :connectionStatus # @!attribute last_sync_status # Latest sync snapshot for the destination, refreshed by the provider webhook # # @return [Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus, nil] optional :last_sync_status, -> { Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus }, api_name: :lastSyncStatus # @!method initialize(connected_at:, destination_id:, type:, connection_status: nil, last_sync_status: nil) # A single destination entry under the DATA_EXPORT integration. # # @param connected_at [String] ISO8601 timestamp of when the destination was connected # # @param destination_id [String] Provider destination ID # # @param type [String] Destination type (snowflake, bigquery, ...) # # @param connection_status [String] Connection status of the destination (connected, failed) # # @param last_sync_status [Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus] Latest sync snapshot for the destination, refreshed by the provider webhook # @see Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination#last_sync_status class LastSyncStatus < Stigg::Internal::Type::BaseModel # @!attribute finished_at # ISO8601 timestamp of when the latest sync finished # # @return [String] required :finished_at, String, api_name: :finishedAt # @!attribute status # Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED) # # @return [String] required :status, String # @!attribute transfer_id # Provider transfer ID of the latest sync # # @return [String] required :transfer_id, String, api_name: :transferId # @!attribute blamed_party # Party responsible for a failed sync, as reported by the data-export provider # # @return [String, nil] optional :blamed_party, String, api_name: :blamedParty # @!attribute failure_message # Customer-friendly failure message, when the latest sync failed # # @return [String, nil] optional :failure_message, String, api_name: :failureMessage # @!attribute rows_transferred # Number of rows transferred in the latest sync # # @return [Float, nil] optional :rows_transferred, Float, api_name: :rowsTransferred # @!method initialize(finished_at:, status:, transfer_id:, blamed_party: nil, failure_message: nil, rows_transferred: nil) # Latest sync snapshot for the destination, refreshed by the provider webhook # # @param finished_at [String] ISO8601 timestamp of when the latest sync finished # # @param status [String] Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED) # # @param transfer_id [String] Provider transfer ID of the latest sync # # @param blamed_party [String] Party responsible for a failed sync, as reported by the data-export provider # # @param failure_message [String] Customer-friendly failure message, when the latest sync failed # # @param rows_transferred [Float] Number of rows transferred in the latest sync end end |
Instance Attribute Details
#connected_at ⇒ String
ISO8601 timestamp of when the destination was connected
40 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 40 required :connected_at, String, api_name: :connectedAt |
#connection_status ⇒ String?
Connection status of the destination (connected, failed)
58 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 58 optional :connection_status, String, api_name: :connectionStatus |
#destination_id ⇒ String
Provider destination ID
46 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 46 required :destination_id, String, api_name: :destinationId |
#last_sync_status ⇒ Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus?
Latest sync snapshot for the destination, refreshed by the provider webhook
64 65 66 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 64 optional :last_sync_status, -> { Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus }, api_name: :lastSyncStatus |
#type ⇒ String
Destination type (snowflake, bigquery, …)
52 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 52 required :type, String |