Class: Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Events::DataExport::DestinationDeleteResponse::Data::Destination::LastSyncStatus
- Defined in:
- lib/stigg/models/v1/events/data_export/destination_delete_response.rb
Overview
Instance Attribute Summary collapse
-
#blamed_party ⇒ String?
Party responsible for a failed sync, as reported by the data-export provider.
-
#failure_message ⇒ String?
Customer-friendly failure message, when the latest sync failed.
-
#finished_at ⇒ String
ISO8601 timestamp of when the latest sync finished.
-
#rows_transferred ⇒ Float?
Number of rows transferred in the latest sync.
-
#status ⇒ String
Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED).
-
#transfer_id ⇒ String
Provider transfer ID of the latest sync.
Instance Method Summary collapse
-
#initialize(finished_at:, status:, transfer_id:, blamed_party: nil, failure_message: nil, rows_transferred: nil) ⇒ Object
constructor
Latest sync snapshot for the destination, refreshed by the provider webhook.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(finished_at:, status:, transfer_id:, blamed_party: nil, failure_message: nil, rows_transferred: nil) ⇒ Object
Latest sync snapshot for the destination, refreshed by the provider webhook
|
|
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 119
|
Instance Attribute Details
#blamed_party ⇒ String?
Party responsible for a failed sync, as reported by the data-export provider
105 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 105 optional :blamed_party, String, api_name: :blamedParty |
#failure_message ⇒ String?
Customer-friendly failure message, when the latest sync failed
111 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 111 optional :failure_message, String, api_name: :failureMessage |
#finished_at ⇒ String
ISO8601 timestamp of when the latest sync finished
87 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 87 required :finished_at, String, api_name: :finishedAt |
#rows_transferred ⇒ Float?
Number of rows transferred in the latest sync
117 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 117 optional :rows_transferred, Float, api_name: :rowsTransferred |
#status ⇒ String
Sync status (PENDING, RUNNING, INCOMPLETE, FAILED, SUCCEEDED, CANCELLED)
93 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 93 required :status, String |
#transfer_id ⇒ String
Provider transfer ID of the latest sync
99 |
# File 'lib/stigg/models/v1/events/data_export/destination_delete_response.rb', line 99 required :transfer_id, String, api_name: :transferId |