Class: Stigg::Models::V1::Feature::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Feature::Data
- Defined in:
- lib/stigg/models/v1/feature.rb
Overview
Defined Under Namespace
Modules: FeatureStatus, FeatureType, MeterType Classes: EnumConfiguration, UnitTransformation
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#description ⇒ String?
The description for the feature.
-
#display_name ⇒ String
The display name for the feature.
-
#enum_configuration ⇒ Array<Stigg::Models::V1::Feature::Data::EnumConfiguration>?
The configuration data for the feature.
-
#feature_status ⇒ Symbol, Stigg::Models::V1::Feature::Data::FeatureStatus
The status of the feature.
-
#feature_type ⇒ Symbol, Stigg::Models::V1::Feature::Data::FeatureType
The type of the feature.
-
#feature_units ⇒ String?
The units for the feature.
-
#feature_units_plural ⇒ String?
The plural units for the feature.
-
#id ⇒ String
The unique identifier for the feature.
-
#metadata ⇒ Hash{Symbol=>String}
The additional metadata for the feature.
-
#meter_type ⇒ Symbol, Stigg::Models::V1::Feature::Data::MeterType
The meter type for the feature.
-
#unit_transformation ⇒ Stigg::Models::V1::Feature::Data::UnitTransformation?
Unit transformation to be applied to the reported usage.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(display_name:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_name:, value:) ⇒ Object
|
|
# File 'lib/stigg/models/v1/feature.rb', line 151
|
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the record was created
31 |
# File 'lib/stigg/models/v1/feature.rb', line 31 required :created_at, Time, api_name: :createdAt |
#description ⇒ String?
The description for the feature
37 |
# File 'lib/stigg/models/v1/feature.rb', line 37 required :description, String, nil?: true |
#display_name ⇒ String
The display name for the feature
43 |
# File 'lib/stigg/models/v1/feature.rb', line 43 required :display_name, String, api_name: :displayName |
#enum_configuration ⇒ Array<Stigg::Models::V1::Feature::Data::EnumConfiguration>?
The configuration data for the feature
49 50 51 52 |
# File 'lib/stigg/models/v1/feature.rb', line 49 required :enum_configuration, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::Feature::Data::EnumConfiguration] }, api_name: :enumConfiguration, nil?: true |
#feature_status ⇒ Symbol, Stigg::Models::V1::Feature::Data::FeatureStatus
The status of the feature
58 59 60 61 62 |
# File 'lib/stigg/models/v1/feature.rb', line 58 required :feature_status, enum: -> { Stigg::V1::Feature::Data::FeatureStatus }, api_name: :featureStatus |
#feature_type ⇒ Symbol, Stigg::Models::V1::Feature::Data::FeatureType
The type of the feature
68 |
# File 'lib/stigg/models/v1/feature.rb', line 68 required :feature_type, enum: -> { Stigg::V1::Feature::Data::FeatureType }, api_name: :featureType |
#feature_units ⇒ String?
The units for the feature
74 |
# File 'lib/stigg/models/v1/feature.rb', line 74 required :feature_units, String, api_name: :featureUnits, nil?: true |
#feature_units_plural ⇒ String?
The plural units for the feature
80 |
# File 'lib/stigg/models/v1/feature.rb', line 80 required :feature_units_plural, String, api_name: :featureUnitsPlural, nil?: true |
#id ⇒ String
The unique identifier for the feature
25 |
# File 'lib/stigg/models/v1/feature.rb', line 25 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
The additional metadata for the feature
86 |
# File 'lib/stigg/models/v1/feature.rb', line 86 required :metadata, Stigg::Internal::Type::HashOf[String] |
#meter_type ⇒ Symbol, Stigg::Models::V1::Feature::Data::MeterType
The meter type for the feature
92 |
# File 'lib/stigg/models/v1/feature.rb', line 92 required :meter_type, enum: -> { Stigg::V1::Feature::Data::MeterType }, api_name: :meterType |
#unit_transformation ⇒ Stigg::Models::V1::Feature::Data::UnitTransformation?
Unit transformation to be applied to the reported usage
98 99 100 101 |
# File 'lib/stigg/models/v1/feature.rb', line 98 required :unit_transformation, -> { Stigg::V1::Feature::Data::UnitTransformation }, api_name: :unitTransformation, nil?: true |
#updated_at ⇒ Time
Timestamp of when the record was last updated
107 |
# File 'lib/stigg/models/v1/feature.rb', line 107 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/feature.rb', line 167
|