Class: Stigg::Models::V1::FeatureCreateFeatureParams
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureCreateFeatureParams
- Extended by:
- Internal::Type::RequestParameters::Converter
- Includes:
- Internal::Type::RequestParameters
- Defined in:
- lib/stigg/models/v1/feature_create_feature_params.rb
Overview
Defined Under Namespace
Modules: FeatureStatus, FeatureType, MeterType Classes: EnumConfiguration, UnitTransformation
Instance Attribute Summary collapse
-
#description ⇒ String?
The description for the feature.
-
#display_name ⇒ String
The display name for the feature.
-
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureCreateFeatureParams::EnumConfiguration>?
The configuration data for the feature.
-
#feature_status ⇒ Symbol, ...
The status of the feature.
-
#feature_type ⇒ Symbol, Stigg::Models::V1::FeatureCreateFeatureParams::FeatureType
The type of the feature.
-
#feature_units ⇒ String?
The units for the feature.
-
#feature_units_plural ⇒ String?
The plural units for the feature.
-
#id ⇒ String
The unique identifier for the feature.
-
#metadata ⇒ Hash{Symbol=>String}?
The additional metadata for the feature.
-
#meter_type ⇒ Symbol, ...
The meter type for the feature.
-
#unit_transformation ⇒ Stigg::Models::V1::FeatureCreateFeatureParams::UnitTransformation?
Unit transformation to be applied to the reported usage.
Attributes included from Internal::Type::RequestParameters
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(display_name:, value:) ⇒ Object constructor
Methods included from Internal::Type::RequestParameters::Converter
Methods included from Internal::Type::RequestParameters
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_name:, value:) ⇒ Object
|
|
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 92
|
Instance Attribute Details
#description ⇒ String?
The description for the feature
35 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 35 optional :description, String |
#display_name ⇒ String
The display name for the feature
21 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 21 required :display_name, String, api_name: :displayName |
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureCreateFeatureParams::EnumConfiguration>?
The configuration data for the feature
41 42 43 44 45 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 41 optional :enum_configuration, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::FeatureCreateFeatureParams::EnumConfiguration] }, api_name: :enumConfiguration |
#feature_status ⇒ Symbol, ...
The status of the feature
51 52 53 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 51 optional :feature_status, enum: -> { Stigg::V1::FeatureCreateFeatureParams::FeatureStatus }, api_name: :featureStatus |
#feature_type ⇒ Symbol, Stigg::Models::V1::FeatureCreateFeatureParams::FeatureType
The type of the feature
27 28 29 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 27 required :feature_type, enum: -> { Stigg::V1::FeatureCreateFeatureParams::FeatureType }, api_name: :featureType |
#feature_units ⇒ String?
The units for the feature
59 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 59 optional :feature_units, String, api_name: :featureUnits |
#feature_units_plural ⇒ String?
The plural units for the feature
65 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 65 optional :feature_units_plural, String, api_name: :featureUnitsPlural |
#id ⇒ String
The unique identifier for the feature
15 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 15 required :id, String |
#metadata ⇒ Hash{Symbol=>String}?
The additional metadata for the feature
71 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 71 optional :metadata, Stigg::Internal::Type::HashOf[String] |
#meter_type ⇒ Symbol, ...
The meter type for the feature
77 78 79 80 81 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 77 optional :meter_type, enum: -> { Stigg::V1::FeatureCreateFeatureParams::MeterType }, api_name: :meterType |
#unit_transformation ⇒ Stigg::Models::V1::FeatureCreateFeatureParams::UnitTransformation?
Unit transformation to be applied to the reported usage
87 88 89 90 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 87 optional :unit_transformation, -> { Stigg::V1::FeatureCreateFeatureParams::UnitTransformation }, api_name: :unitTransformation, nil?: true |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 125
|