Class: Stigg::Models::V1::FeatureCreateFeatureParams::UnitTransformation
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureCreateFeatureParams::UnitTransformation
- Defined in:
- lib/stigg/models/v1/feature_create_feature_params.rb
Defined Under Namespace
Modules: Round
Instance Attribute Summary collapse
-
#divide ⇒ Integer
Divide usage by this number.
-
#feature_units ⇒ String?
Singular feature units after the transformation.
-
#feature_units_plural ⇒ String?
Plural feature units after the transformation.
-
#round ⇒ Symbol, ...
After division, either round the result up or down.
Instance Method Summary collapse
-
#initialize(divide:, feature_units: nil, feature_units_plural: nil, round: nil) ⇒ Object
constructor
Unit transformation to be applied to the reported usage.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(divide:, feature_units: nil, feature_units_plural: nil, round: nil) ⇒ Object
Unit transformation to be applied to the reported usage
|
|
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 197
|
Instance Attribute Details
#divide ⇒ Integer
Divide usage by this number
177 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 177 required :divide, Integer |
#feature_units ⇒ String?
Singular feature units after the transformation
183 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 183 optional :feature_units, String, api_name: :featureUnits |
#feature_units_plural ⇒ String?
Plural feature units after the transformation
189 |
# File 'lib/stigg/models/v1/feature_create_feature_params.rb', line 189 optional :feature_units_plural, String, api_name: :featureUnitsPlural |