Class: Stigg::Models::V1::FeatureListFeaturesResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureListFeaturesResponse
- Defined in:
- lib/stigg/models/v1/feature_list_features_response.rb
Overview
Defined Under Namespace
Modules: FeatureStatus, FeatureType, MeterType Classes: EnumConfiguration, UnitTransformation
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#description ⇒ String?
The description for the feature.
-
#display_name ⇒ String
The display name for the feature.
-
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureListFeaturesResponse::EnumConfiguration>?
The configuration data for the feature.
-
#feature_status ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::FeatureStatus
The status of the feature.
-
#feature_type ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::FeatureType
The type of the feature.
-
#feature_units ⇒ String?
The units for the feature.
-
#feature_units_plural ⇒ String?
The plural units for the feature.
-
#id ⇒ String
The unique identifier for the feature.
-
#metadata ⇒ Hash{Symbol=>String}
The additional metadata for the feature.
-
#meter_type ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::MeterType
The meter type for the feature.
-
#unit_transformation ⇒ Stigg::Models::V1::FeatureListFeaturesResponse::UnitTransformation?
Unit transformation to be applied to the reported usage.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
- #initialize(display_name:, value:) ⇒ Object constructor
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(display_name:, value:) ⇒ Object
|
|
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 140
|
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the record was created
18 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 18 required :created_at, Time, api_name: :createdAt |
#description ⇒ String?
The description for the feature
24 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 24 required :description, String, nil?: true |
#display_name ⇒ String
The display name for the feature
30 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 30 required :display_name, String, api_name: :displayName |
#enum_configuration ⇒ Array<Stigg::Models::V1::FeatureListFeaturesResponse::EnumConfiguration>?
The configuration data for the feature
36 37 38 39 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 36 required :enum_configuration, -> { Stigg::Internal::Type::ArrayOf[Stigg::Models::V1::FeatureListFeaturesResponse::EnumConfiguration] }, api_name: :enumConfiguration, nil?: true |
#feature_status ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::FeatureStatus
The status of the feature
45 46 47 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 45 required :feature_status, enum: -> { Stigg::Models::V1::FeatureListFeaturesResponse::FeatureStatus }, api_name: :featureStatus |
#feature_type ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::FeatureType
The type of the feature
53 54 55 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 53 required :feature_type, enum: -> { Stigg::Models::V1::FeatureListFeaturesResponse::FeatureType }, api_name: :featureType |
#feature_units ⇒ String?
The units for the feature
61 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 61 required :feature_units, String, api_name: :featureUnits, nil?: true |
#feature_units_plural ⇒ String?
The plural units for the feature
67 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 67 required :feature_units_plural, String, api_name: :featureUnitsPlural, nil?: true |
#id ⇒ String
The unique identifier for the feature
12 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
The additional metadata for the feature
73 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 73 required :metadata, Stigg::Internal::Type::HashOf[String] |
#meter_type ⇒ Symbol, Stigg::Models::V1::FeatureListFeaturesResponse::MeterType
The meter type for the feature
79 80 81 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 79 required :meter_type, enum: -> { Stigg::Models::V1::FeatureListFeaturesResponse::MeterType }, api_name: :meterType |
#unit_transformation ⇒ Stigg::Models::V1::FeatureListFeaturesResponse::UnitTransformation?
Unit transformation to be applied to the reported usage
87 88 89 90 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 87 required :unit_transformation, -> { Stigg::Models::V1::FeatureListFeaturesResponse::UnitTransformation }, api_name: :unitTransformation, nil?: true |
#updated_at ⇒ Time
Timestamp of when the record was last updated
96 |
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 96 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/feature_list_features_response.rb', line 156
|