Class: Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::FeatureUpdateFeatureParams::EnumConfiguration
- Defined in:
- lib/stigg/models/v1/feature_update_feature_params.rb
Instance Attribute Summary collapse
-
#display_name ⇒ String
The display name for the enum configuration entity.
-
#value ⇒ String
The unique value identifier for the enum configuration entity.
Instance Method Summary collapse
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, description: nil, display_name: nil, enum_configuration: nil, feature_units: nil, feature_units_plural: nil, metadata: nil, meter: nil, unit_transformation: nil, request_options: {}) ⇒ Object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 91 class EnumConfiguration < Stigg::Internal::Type::BaseModel # @!attribute display_name # The display name for the enum configuration entity # # @return [String] required :display_name, String, api_name: :displayName # @!attribute value # The unique value identifier for the enum configuration entity # # @return [String] required :value, String # @!method initialize(display_name:, value:) # @param display_name [String] The display name for the enum configuration entity # # @param value [String] The unique value identifier for the enum configuration entity end |
Instance Attribute Details
#display_name ⇒ String
The display name for the enum configuration entity
96 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 96 required :display_name, String, api_name: :displayName |
#value ⇒ String
The unique value identifier for the enum configuration entity
102 |
# File 'lib/stigg/models/v1/feature_update_feature_params.rb', line 102 required :value, String |