Class: Stigg::Models::V1::Plan::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::Plan::Data
- Defined in:
- lib/stigg/models/v1/plan.rb
Overview
Defined Under Namespace
Modules: PricingType, Status Classes: DefaultTrialConfig, Entitlement
Instance Attribute Summary collapse
-
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider.
- #compatible_addon_ids ⇒ Array<String>?
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#default_trial_config ⇒ Stigg::Models::V1::Plan::Data::DefaultTrialConfig?
Default trial configuration for the plan.
-
#description ⇒ String?
The description of the package.
-
#display_name ⇒ String
The display name of the package.
-
#entitlements ⇒ Array<Stigg::Models::V1::Plan::Data::Entitlement>
List of entitlements of the package.
-
#id ⇒ String
The unique identifier for the entity.
-
#is_latest ⇒ Boolean?
Indicates if the package is the latest version.
-
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity.
-
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable.
-
#pricing_type ⇒ Symbol, ...
The pricing type of the package.
-
#product_id ⇒ String
The product id of the package.
-
#status ⇒ Symbol, Stigg::Models::V1::Plan::Data::Status
The status of the package.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
-
#version_number ⇒ Integer
The version number of the package.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, billing_id:, compatible_addon_ids:, created_at:, default_trial_config:, description:, display_name:, entitlements:, is_latest:, metadata:, parent_plan_id:, pricing_type:, product_id:, status:, updated_at:, version_number:) ⇒ Object
constructor
Plan configuration object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, billing_id:, compatible_addon_ids:, created_at:, default_trial_config:, description:, display_name:, entitlements:, is_latest:, metadata:, parent_plan_id:, pricing_type:, product_id:, status:, updated_at:, version_number:) ⇒ Object
Plan configuration object
|
|
# File 'lib/stigg/models/v1/plan.rb', line 125
|
Instance Attribute Details
#billing_id ⇒ String?
The unique identifier for the entity in the billing provider
31 |
# File 'lib/stigg/models/v1/plan.rb', line 31 required :billing_id, String, api_name: :billingId, nil?: true |
#compatible_addon_ids ⇒ Array<String>?
36 37 38 39 |
# File 'lib/stigg/models/v1/plan.rb', line 36 required :compatible_addon_ids, Stigg::Internal::Type::ArrayOf[String], api_name: :compatibleAddonIds, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
45 |
# File 'lib/stigg/models/v1/plan.rb', line 45 required :created_at, Time, api_name: :createdAt |
#default_trial_config ⇒ Stigg::Models::V1::Plan::Data::DefaultTrialConfig?
Default trial configuration for the plan
51 52 53 54 |
# File 'lib/stigg/models/v1/plan.rb', line 51 required :default_trial_config, -> { Stigg::V1::Plan::Data::DefaultTrialConfig }, api_name: :defaultTrialConfig, nil?: true |
#description ⇒ String?
The description of the package
60 |
# File 'lib/stigg/models/v1/plan.rb', line 60 required :description, String, nil?: true |
#display_name ⇒ String
The display name of the package
66 |
# File 'lib/stigg/models/v1/plan.rb', line 66 required :display_name, String, api_name: :displayName |
#entitlements ⇒ Array<Stigg::Models::V1::Plan::Data::Entitlement>
List of entitlements of the package
72 |
# File 'lib/stigg/models/v1/plan.rb', line 72 required :entitlements, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::Plan::Data::Entitlement] } |
#id ⇒ String
The unique identifier for the entity
25 |
# File 'lib/stigg/models/v1/plan.rb', line 25 required :id, String |
#is_latest ⇒ Boolean?
Indicates if the package is the latest version
78 |
# File 'lib/stigg/models/v1/plan.rb', line 78 required :is_latest, Stigg::Internal::Type::Boolean, api_name: :isLatest, nil?: true |
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity
84 |
# File 'lib/stigg/models/v1/plan.rb', line 84 required :metadata, Stigg::Internal::Type::HashOf[String] |
#parent_plan_id ⇒ String?
The ID of the parent plan, if applicable
90 |
# File 'lib/stigg/models/v1/plan.rb', line 90 required :parent_plan_id, String, api_name: :parentPlanId, nil?: true |
#pricing_type ⇒ Symbol, ...
The pricing type of the package
96 97 98 99 |
# File 'lib/stigg/models/v1/plan.rb', line 96 required :pricing_type, enum: -> { Stigg::V1::Plan::Data::PricingType }, api_name: :pricingType, nil?: true |
#product_id ⇒ String
The product id of the package
105 |
# File 'lib/stigg/models/v1/plan.rb', line 105 required :product_id, String, api_name: :productId |
#status ⇒ Symbol, Stigg::Models::V1::Plan::Data::Status
The status of the package
111 |
# File 'lib/stigg/models/v1/plan.rb', line 111 required :status, enum: -> { Stigg::V1::Plan::Data::Status } |
#updated_at ⇒ Time
Timestamp of when the record was last updated
117 |
# File 'lib/stigg/models/v1/plan.rb', line 117 required :updated_at, Time, api_name: :updatedAt |
#version_number ⇒ Integer
The version number of the package
123 |
# File 'lib/stigg/models/v1/plan.rb', line 123 required :version_number, Integer, api_name: :versionNumber |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan.rb', line 244
|