Class: Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel
- Defined in:
- lib/stigg/models/v1/plan_update_params.rb
Defined Under Namespace
Modules: BillingCadence, BillingModel, ResetPeriod, TiersMode Classes: MonthlyResetPeriodConfiguration, PricePeriod, WeeklyResetPeriodConfiguration, YearlyResetPeriodConfiguration
Instance Attribute Summary collapse
-
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF).
-
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED).
-
#feature_id ⇒ String?
The feature ID this pricing model is associated with.
-
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999).
-
#min_unit_quantity ⇒ Integer?
Minimum number of units.
-
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration.
-
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required).
-
#reset_period ⇒ Symbol, ...
The usage reset period.
-
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED).
-
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing.
-
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration.
-
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
constructor
A pricing model configuration with billing details and price periods.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(billing_model:, price_periods:, billing_cadence: nil, feature_id: nil, max_unit_quantity: nil, min_unit_quantity: nil, monthly_reset_period_configuration: nil, reset_period: nil, tiers_mode: nil, top_up_custom_currency_id: nil, weekly_reset_period_configuration: nil, yearly_reset_period_configuration: nil) ⇒ Object
A pricing model configuration with billing details and price periods.
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1371
|
Instance Attribute Details
#billing_cadence ⇒ Symbol, ...
The billing cadence (RECURRING or ONE_OFF)
1297 1298 1299 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1297 optional :billing_cadence, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::BillingCadence }, api_name: :billingCadence |
#billing_model ⇒ Symbol, Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::BillingModel
The billing model (FLAT_FEE, PER_UNIT, USAGE_BASED, CREDIT_BASED)
1279 1280 1281 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1279 required :billing_model, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::BillingModel }, api_name: :billingModel |
#feature_id ⇒ String?
The feature ID this pricing model is associated with
1305 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1305 optional :feature_id, String, api_name: :featureId |
#max_unit_quantity ⇒ Integer?
Maximum number of units (max 999999)
1311 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1311 optional :max_unit_quantity, Integer, api_name: :maxUnitQuantity |
#min_unit_quantity ⇒ Integer?
Minimum number of units
1317 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1317 optional :min_unit_quantity, Integer, api_name: :minUnitQuantity |
#monthly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration?
Monthly reset period configuration
1323 1324 1325 1326 1327 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1323 optional :monthly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::MonthlyResetPeriodConfiguration }, api_name: :monthlyResetPeriodConfiguration |
#price_periods ⇒ Array<Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod>
Array of price period configurations (at least one required)
1287 1288 1289 1290 1291 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1287 required :price_periods, -> { Stigg::Internal::Type::ArrayOf[Stigg::V1::PlanUpdateParams::Charges::PricingModel::PricePeriod] }, api_name: :pricePeriods |
#reset_period ⇒ Symbol, ...
The usage reset period
1333 1334 1335 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1333 optional :reset_period, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::ResetPeriod }, api_name: :resetPeriod |
#tiers_mode ⇒ Symbol, ...
The tiered pricing mode (VOLUME or GRADUATED)
1341 1342 1343 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1341 optional :tiers_mode, enum: -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::TiersMode }, api_name: :tiersMode |
#top_up_custom_currency_id ⇒ String?
The custom currency ID for top-up pricing
1349 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1349 optional :top_up_custom_currency_id, String, api_name: :topUpCustomCurrencyId |
#weekly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration?
Weekly reset period configuration
1355 1356 1357 1358 1359 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1355 optional :weekly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::WeeklyResetPeriodConfiguration }, api_name: :weeklyResetPeriodConfiguration |
#yearly_reset_period_configuration ⇒ Stigg::Models::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration?
Yearly reset period configuration
1365 1366 1367 1368 1369 |
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1365 optional :yearly_reset_period_configuration, -> { Stigg::V1::PlanUpdateParams::Charges::PricingModel::YearlyResetPeriodConfiguration }, api_name: :yearlyResetPeriodConfiguration |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/plan_update_params.rb', line 1410
|