Class: Stigg::Models::V1::ProductListProductsResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1::ProductListProductsResponse
- Defined in:
- lib/stigg/models/v1/product_list_products_response.rb
Overview
Defined Under Namespace
Modules: Status Classes: ProductSettings
Instance Attribute Summary collapse
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#description ⇒ String?
Description of the product.
-
#display_name ⇒ String
Display name of the product.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity.
-
#multiple_subscriptions ⇒ Boolean
Indicates if multiple subscriptions to this product are allowed.
-
#product_settings ⇒ Stigg::Models::V1::ProductListProductsResponse::ProductSettings?
Product behavior settings for subscription lifecycle management.
-
#status ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::Status
The status of the product.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(id:, created_at:, description:, display_name:, metadata:, multiple_subscriptions:, status:, updated_at:, product_settings: nil) ⇒ Object
constructor
Product configuration object.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, created_at:, description:, display_name:, metadata:, multiple_subscriptions:, status:, updated_at:, product_settings: nil) ⇒ Object
Product configuration object
|
|
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 64
|
Instance Attribute Details
#created_at ⇒ Time
Timestamp of when the record was created
18 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 18 required :created_at, Time, api_name: :createdAt |
#description ⇒ String?
Description of the product
24 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 24 required :description, String, nil?: true |
#display_name ⇒ String
Display name of the product
30 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 30 required :display_name, String, api_name: :displayName |
#id ⇒ String
The unique identifier for the entity
12 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 12 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Metadata associated with the entity
36 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 36 required :metadata, Stigg::Internal::Type::HashOf[String] |
#multiple_subscriptions ⇒ Boolean
Indicates if multiple subscriptions to this product are allowed
42 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 42 required :multiple_subscriptions, Stigg::Internal::Type::Boolean, api_name: :multipleSubscriptions |
#product_settings ⇒ Stigg::Models::V1::ProductListProductsResponse::ProductSettings?
Product behavior settings for subscription lifecycle management.
60 61 62 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 60 optional :product_settings, -> { Stigg::Models::V1::ProductListProductsResponse::ProductSettings }, api_name: :productSettings |
#status ⇒ Symbol, Stigg::Models::V1::ProductListProductsResponse::Status
The status of the product
48 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 48 required :status, enum: -> { Stigg::Models::V1::ProductListProductsResponse::Status } |
#updated_at ⇒ Time
Timestamp of when the record was last updated
54 |
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 54 required :updated_at, Time, api_name: :updatedAt |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1/product_list_products_response.rb', line 94
|