Class: Stigg::Models::V1Beta::Customers::AssignmentListResponse
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::AssignmentListResponse
- Defined in:
- lib/stigg/models/v1_beta/customers/assignment_list_response.rb
Overview
Defined Under Namespace
Modules: Cadence
Instance Attribute Summary collapse
-
#cadence ⇒ Symbol, Stigg::Models::V1Beta::Customers::AssignmentListResponse::Cadence
Usage-reset cadence.
-
#capability_id ⇒ String
The capability refId this assignment grants.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#entity_id ⇒ String
The entity refId this assignment is attached to.
-
#id ⇒ String
Synthetic UUID identifier — also the cursor anchor for paginated lists.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
-
#usage_limit ⇒ Float
Maximum usage allowed within one cadence window.
Instance Method Summary collapse
-
#initialize(id:, cadence:, capability_id:, created_at:, entity_id:, updated_at:, usage_limit:) ⇒ Object
constructor
A capability assignment for an entity belonging to a customer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cadence:, capability_id:, created_at:, entity_id:, updated_at:, usage_limit:) ⇒ Object
A capability assignment for an entity belonging to a customer. Defines how much of the capability the entity may consume (‘usageLimit`) and how often the counter resets (`cadence`).
|
|
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 51
|
Instance Attribute Details
#cadence ⇒ Symbol, Stigg::Models::V1Beta::Customers::AssignmentListResponse::Cadence
Usage-reset cadence. Currently only ‘MONTH` is supported
19 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 19 required :cadence, enum: -> { Stigg::Models::V1Beta::Customers::AssignmentListResponse::Cadence } |
#capability_id ⇒ String
The capability refId this assignment grants
25 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 25 required :capability_id, String, api_name: :capabilityId |
#created_at ⇒ Time
Timestamp of when the record was created
31 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 31 required :created_at, Time, api_name: :createdAt |
#entity_id ⇒ String
The entity refId this assignment is attached to
37 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 37 required :entity_id, String, api_name: :entityId |
#id ⇒ String
Synthetic UUID identifier — also the cursor anchor for paginated lists
13 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 13 required :id, String |
#updated_at ⇒ Time
Timestamp of when the record was last updated
43 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 43 required :updated_at, Time, api_name: :updatedAt |
#usage_limit ⇒ Float
Maximum usage allowed within one cadence window
49 |
# File 'lib/stigg/models/v1_beta/customers/assignment_list_response.rb', line 49 required :usage_limit, Float, api_name: :usageLimit |