Class: Stigg::Models::V1Beta::Customers::AssignmentUpsertParams::Assignment
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::AssignmentUpsertParams::Assignment
- Defined in:
- lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb
Defined Under Namespace
Modules: Cadence
Instance Attribute Summary collapse
-
#cadence ⇒ Symbol, ...
Usage-reset cadence (required on create).
-
#capability_id ⇒ String
The capability refId this assignment grants.
-
#entity_id ⇒ String
The entity refId this assignment is attached to.
-
#usage_limit ⇒ Float?
Maximum usage allowed within one cadence window (required on create).
Instance Method Summary collapse
-
#initialize(capability_id:, entity_id:, cadence: nil, usage_limit: nil) ⇒ Object
constructor
A single assignment to create or update.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(capability_id:, entity_id:, cadence: nil, usage_limit: nil) ⇒ Object
A single assignment to create or update. The natural key is the ‘(entityId, capabilityId)` pair. On create both `usageLimit` and `cadence` are required; on update they may be omitted individually to preserve the existing value.
31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb', line 31 class Assignment < Stigg::Internal::Type::BaseModel # @!attribute capability_id # The capability refId this assignment grants # # @return [String] required :capability_id, String, api_name: :capabilityId # @!attribute entity_id # The entity refId this assignment is attached to # # @return [String] required :entity_id, String, api_name: :entityId # @!attribute cadence # Usage-reset cadence (required on create). Currently only `MONTH` is supported # # @return [Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertParams::Assignment::Cadence, nil] optional :cadence, enum: -> { Stigg::V1Beta::Customers::AssignmentUpsertParams::Assignment::Cadence } # @!attribute usage_limit # Maximum usage allowed within one cadence window (required on create) # # @return [Float, nil] optional :usage_limit, Float, api_name: :usageLimit # @!method initialize(capability_id:, entity_id:, cadence: nil, usage_limit: nil) # A single assignment to create or update. The natural key is the # `(entityId, capabilityId)` pair. On create both `usageLimit` and `cadence` are # required; on update they may be omitted individually to preserve the existing # value. # # @param capability_id [String] The capability refId this assignment grants # # @param entity_id [String] The entity refId this assignment is attached to # # @param cadence [Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertParams::Assignment::Cadence] Usage-reset cadence (required on create). Currently only `MONTH` is supported # # @param usage_limit [Float] Maximum usage allowed within one cadence window (required on create) # Usage-reset cadence (required on create). Currently only `MONTH` is supported # # @see Stigg::Models::V1Beta::Customers::AssignmentUpsertParams::Assignment#cadence module Cadence extend Stigg::Internal::Type::Enum MONTH = :MONTH # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#cadence ⇒ Symbol, ...
Usage-reset cadence (required on create). Currently only ‘MONTH` is supported
48 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb', line 48 optional :cadence, enum: -> { Stigg::V1Beta::Customers::AssignmentUpsertParams::Assignment::Cadence } |
#capability_id ⇒ String
The capability refId this assignment grants
36 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb', line 36 required :capability_id, String, api_name: :capabilityId |
#entity_id ⇒ String
The entity refId this assignment is attached to
42 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb', line 42 required :entity_id, String, api_name: :entityId |
#usage_limit ⇒ Float?
Maximum usage allowed within one cadence window (required on create)
54 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_params.rb', line 54 optional :usage_limit, Float, api_name: :usageLimit |