Class: Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data
- Defined in:
- lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb
Defined Under Namespace
Modules: Cadence
Instance Attribute Summary collapse
-
#cadence ⇒ Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence
Usage-reset cadence.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#currency_id ⇒ String?
Currency refId this assignment grants (present for credit capabilities).
-
#entity_id ⇒ String
The entity refId this assignment is attached to.
-
#feature_id ⇒ String?
Feature refId this assignment grants (present for feature capabilities).
-
#id ⇒ String
Synthetic UUID identifier — also the cursor anchor for paginated lists.
-
#parent_id ⇒ String?
Parent entity refId in the hierarchy, or ‘null` for a root.
-
#scope_entity_ids ⇒ Array<String>
Dimension-scoped sub-budget key: the set of entity refIds this budget applies to.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
-
#usage_limit ⇒ Float
Maximum usage allowed within one cadence window.
Instance Method Summary collapse
-
#initialize(id:, cadence:, created_at:, entity_id:, parent_id:, scope_entity_ids:, updated_at:, usage_limit:, currency_id: nil, feature_id: nil) ⇒ Object
constructor
Some parameter documentations has been truncated, see Data for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, cadence:, created_at:, entity_id:, parent_id:, scope_entity_ids:, updated_at:, usage_limit:, currency_id: nil, feature_id: nil) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data for more details.
A capability assignment for an entity belonging to a customer. Defines how much of the capability the entity may consume (‘usageLimit`) and how often the counter resets (`cadence`).
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 20 class Data < Stigg::Internal::Type::BaseModel # @!attribute id # Synthetic UUID identifier — also the cursor anchor for paginated lists # # @return [String] required :id, String # @!attribute cadence # Usage-reset cadence. Currently only `MONTH` is supported # # @return [Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence] required :cadence, enum: -> { Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence } # @!attribute created_at # Timestamp of when the record was created # # @return [Time] required :created_at, Time, api_name: :createdAt # @!attribute entity_id # The entity refId this assignment is attached to # # @return [String] required :entity_id, String, api_name: :entityId # @!attribute parent_id # Parent entity refId in the hierarchy, or `null` for a root. # # @return [String, nil] required :parent_id, String, api_name: :parentId, nil?: true # @!attribute scope_entity_ids # Dimension-scoped sub-budget key: the set of entity refIds this budget applies # to. Empty is the node-wide budget that always matches; a non-empty set only # applies when every listed entity is present in the resolved set # (order-insensitive). # # @return [Array<String>] required :scope_entity_ids, Stigg::Internal::Type::ArrayOf[String], api_name: :scopeEntityIds # @!attribute updated_at # Timestamp of when the record was last updated # # @return [Time] required :updated_at, Time, api_name: :updatedAt # @!attribute usage_limit # Maximum usage allowed within one cadence window # # @return [Float] required :usage_limit, Float, api_name: :usageLimit # @!attribute currency_id # Currency refId this assignment grants (present for credit capabilities). # # @return [String, nil] optional :currency_id, String, api_name: :currencyId # @!attribute feature_id # Feature refId this assignment grants (present for feature capabilities). # # @return [String, nil] optional :feature_id, String, api_name: :featureId # @!method initialize(id:, cadence:, created_at:, entity_id:, parent_id:, scope_entity_ids:, updated_at:, usage_limit:, currency_id: nil, feature_id: nil) # Some parameter documentations has been truncated, see # {Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data} for more # details. # # A capability assignment for an entity belonging to a customer. Defines how much # of the capability the entity may consume (`usageLimit`) and how often the # counter resets (`cadence`). # # @param id [String] Synthetic UUID identifier — also the cursor anchor for paginated lists # # @param cadence [Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence] Usage-reset cadence. Currently only `MONTH` is supported # # @param created_at [Time] Timestamp of when the record was created # # @param entity_id [String] The entity refId this assignment is attached to # # @param parent_id [String, nil] Parent entity refId in the hierarchy, or `null` for a root. # # @param scope_entity_ids [Array<String>] Dimension-scoped sub-budget key: the set of entity refIds this budget applies to # # @param updated_at [Time] Timestamp of when the record was last updated # # @param usage_limit [Float] Maximum usage allowed within one cadence window # # @param currency_id [String] Currency refId this assignment grants (present for credit capabilities). # # @param feature_id [String] Feature refId this assignment grants (present for feature capabilities). # Usage-reset cadence. Currently only `MONTH` is supported # # @see Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data#cadence module Cadence extend Stigg::Internal::Type::Enum MONTH = :MONTH # @!method self.values # @return [Array<Symbol>] end end |
Instance Attribute Details
#cadence ⇒ Symbol, Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence
Usage-reset cadence. Currently only ‘MONTH` is supported
31 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 31 required :cadence, enum: -> { Stigg::Models::V1Beta::Customers::AssignmentUpsertResponse::Data::Cadence } |
#created_at ⇒ Time
Timestamp of when the record was created
37 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 37 required :created_at, Time, api_name: :createdAt |
#currency_id ⇒ String?
Currency refId this assignment grants (present for credit capabilities).
76 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 76 optional :currency_id, String, api_name: :currencyId |
#entity_id ⇒ String
The entity refId this assignment is attached to
43 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 43 required :entity_id, String, api_name: :entityId |
#feature_id ⇒ String?
Feature refId this assignment grants (present for feature capabilities).
82 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 82 optional :feature_id, String, api_name: :featureId |
#id ⇒ String
Synthetic UUID identifier — also the cursor anchor for paginated lists
25 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 25 required :id, String |
#parent_id ⇒ String?
Parent entity refId in the hierarchy, or ‘null` for a root.
49 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 49 required :parent_id, String, api_name: :parentId, nil?: true |
#scope_entity_ids ⇒ Array<String>
Dimension-scoped sub-budget key: the set of entity refIds this budget applies to. Empty is the node-wide budget that always matches; a non-empty set only applies when every listed entity is present in the resolved set (order-insensitive).
58 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 58 required :scope_entity_ids, Stigg::Internal::Type::ArrayOf[String], api_name: :scopeEntityIds |
#updated_at ⇒ Time
Timestamp of when the record was last updated
64 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 64 required :updated_at, Time, api_name: :updatedAt |
#usage_limit ⇒ Float
Maximum usage allowed within one cadence window
70 |
# File 'lib/stigg/models/v1_beta/customers/assignment_upsert_response.rb', line 70 required :usage_limit, Float, api_name: :usageLimit |