Class: Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature
- Defined in:
- lib/stigg/models/v1_beta/customers/entitlement_check_response.rb
Defined Under Namespace
Modules: AccessDeniedReason, ResetPeriod Classes: Chain, Feature
Instance Attribute Summary collapse
- #access_denied_reason ⇒ Symbol, ...
-
#chains ⇒ Array<Array<Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Chain>>?
Per-entity rollups, one chain per resolved dimension.
- #current_usage ⇒ Float?
-
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
- #feature ⇒ Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Feature?
- #has_unlimited_usage ⇒ Boolean?
- #is_granted ⇒ Boolean
- #reset_period ⇒ Symbol, ...
- #type ⇒ Symbol, :FEATURE
- #usage_limit ⇒ Float?
-
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured.
-
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured.
-
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured.
-
#valid_until ⇒ Time?
The next time the entitlement should be recalculated.
Class Method Summary collapse
Instance Method Summary collapse
-
#initialize(current_usage:, entity_id:, is_granted:, usage_limit:) ⇒ Object
constructor
Per-entity governance node — limit and current usage for a single resolved entity.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(current_usage:, entity_id:, is_granted:, usage_limit:) ⇒ Object
Per-entity governance node — limit and current usage for a single resolved entity.
|
|
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 127
|
Instance Attribute Details
#access_denied_reason ⇒ Symbol, ...
38 39 40 41 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 38 required :access_denied_reason, enum: -> { Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::AccessDeniedReason }, api_name: :accessDeniedReason, nil?: true |
#chains ⇒ Array<Array<Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Chain>>?
Per-entity rollups, one chain per resolved dimension. Omitted when dimensions was not provided.
58 59 60 61 62 63 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 58 optional :chains, -> do Stigg::Internal::Type::ArrayOf[ Stigg::Internal::Type::ArrayOf[Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Chain] ] end |
#current_usage ⇒ Float?
68 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 68 optional :current_usage, Float, api_name: :currentUsage |
#entitlement_updated_at ⇒ Time?
Timestamp of the last update to the entitlement grant or configuration.
74 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 74 optional :entitlement_updated_at, Time, api_name: :entitlementUpdatedAt |
#feature ⇒ Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Feature?
79 80 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 79 optional :feature, -> { Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::Feature } |
#has_unlimited_usage ⇒ Boolean?
85 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 85 optional :has_unlimited_usage, Stigg::Internal::Type::Boolean, api_name: :hasUnlimitedUsage |
#is_granted ⇒ Boolean
46 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 46 required :is_granted, Stigg::Internal::Type::Boolean, api_name: :isGranted |
#reset_period ⇒ Symbol, ...
90 91 92 93 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 90 optional :reset_period, enum: -> { Stigg::Models::V1Beta::Customers::EntitlementCheckResponse::Data::Feature::ResetPeriod }, api_name: :resetPeriod, nil?: true |
#type ⇒ Symbol, :FEATURE
51 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 51 required :type, const: :FEATURE |
#usage_limit ⇒ Float?
98 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 98 optional :usage_limit, Float, api_name: :usageLimit, nil?: true |
#usage_period_anchor ⇒ Time?
The anchor for calculating the usage period for metered entitlements with a reset period configured
105 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 105 optional :usage_period_anchor, Time, api_name: :usagePeriodAnchor |
#usage_period_end ⇒ Time?
The end date of the usage period for metered entitlements with a reset period configured
112 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 112 optional :usage_period_end, Time, api_name: :usagePeriodEnd |
#usage_period_start ⇒ Time?
The start date of the usage period for metered entitlements with a reset period configured
119 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 119 optional :usage_period_start, Time, api_name: :usagePeriodStart |
#valid_until ⇒ Time?
The next time the entitlement should be recalculated
125 |
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 125 optional :valid_until, Time, api_name: :validUntil |
Class Method Details
.values ⇒ Array<Symbol>
|
|
# File 'lib/stigg/models/v1_beta/customers/entitlement_check_response.rb', line 181
|