Class: Stigg::Models::V1Beta::Customers::EntityUpsertParams::Entity

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1_beta/customers/entity_upsert_params.rb,
sig/stigg/models/v1_beta/customers/entity_upsert_params.rbs

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, entity_type_id: nil, metadata: nil) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1Beta::Customers::EntityUpsertParams::Entity for more details.

A single entity to create or update.

Parameters:

  • id (String)

    The unique identifier for the entity

  • entity_type_id (String) (defaults to: nil)

    The entity type ID this entity instantiates. Required when creating a new entity

  • metadata (Hash{Symbol=>String}) (defaults to: nil)

    Free-form key/value metadata. Patch semantics: empty-string value removes a key,



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_params.rb', line 45

class Entity < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   The unique identifier for the entity
  #
  #   @return [String]
  required :id, String

  # @!attribute entity_type_id
  #   The entity type ID this entity instantiates. Required when creating a new
  #   entity; on a re-upsert may be omitted to preserve the existing type. Governance
  #   returns 400 if missing on create.
  #
  #   @return [String, nil]
  optional :entity_type_id, String, api_name: :entityTypeId

  # @!attribute metadata
  #   Free-form key/value metadata. Patch semantics: empty-string value removes a key,
  #   omitted keys are preserved.
  #
  #   @return [Hash{Symbol=>String}, nil]
  optional :metadata, Stigg::Internal::Type::HashOf[String]

  # @!method initialize(id:, entity_type_id: nil, metadata: nil)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1Beta::Customers::EntityUpsertParams::Entity} for more details.
  #
  #   A single entity to create or update.
  #
  #   @param id [String] The unique identifier for the entity
  #
  #   @param entity_type_id [String] The entity type ID this entity instantiates. Required when creating a new entity
  #
  #   @param metadata [Hash{Symbol=>String}] Free-form key/value metadata. Patch semantics: empty-string value removes a key,
end

Instance Attribute Details

#entity_type_idString?

The entity type ID this entity instantiates. Required when creating a new entity; on a re-upsert may be omitted to preserve the existing type. Governance returns 400 if missing on create.

Parameters:

  • (String)

Returns:

  • (String, nil)


58
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_params.rb', line 58

optional :entity_type_id, String, api_name: :entityTypeId

#idString

The unique identifier for the entity

Parameters:

  • value (String)

Returns:

  • (String)


50
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_params.rb', line 50

required :id, String

#metadataHash{Symbol=>String}?

Free-form key/value metadata. Patch semantics: empty-string value removes a key, omitted keys are preserved.

Parameters:

  • (::Hash[Symbol, String])

Returns:

  • (Hash{Symbol=>String}, nil)


65
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_params.rb', line 65

optional :metadata, Stigg::Internal::Type::HashOf[String]

Instance Method Details

#to_hash{

Returns:

  • ({)


70
# File 'sig/stigg/models/v1_beta/customers/entity_upsert_params.rbs', line 70

def to_hash: -> {