Class: Stigg::Models::V1Beta::Customers::EntityUpsertResponse::Data
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::Customers::EntityUpsertResponse::Data
- Defined in:
- lib/stigg/models/v1_beta/customers/entity_upsert_response.rb
Instance Attribute Summary collapse
-
#archived_at ⇒ Time?
Timestamp of when the record was deleted.
-
#created_at ⇒ Time
Timestamp of when the record was created.
-
#id ⇒ String
The unique identifier for the entity.
-
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity.
-
#type_id ⇒ String
The entity type identifier this entity instantiates.
-
#updated_at ⇒ Time
Timestamp of when the record was last updated.
Instance Method Summary collapse
-
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
constructor
A stored entity instance tracked by the governance service for a given customer.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) ⇒ Object
A stored entity instance tracked by the governance service for a given customer
20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 20 class Data < Stigg::Internal::Type::BaseModel # @!attribute id # The unique identifier for the entity # # @return [String] required :id, String # @!attribute archived_at # Timestamp of when the record was deleted # # @return [Time, nil] required :archived_at, Time, api_name: :archivedAt, nil?: true # @!attribute created_at # Timestamp of when the record was created # # @return [Time] required :created_at, Time, api_name: :createdAt # @!attribute metadata # Free-form key/value metadata attached to the entity # # @return [Hash{Symbol=>String}] required :metadata, Stigg::Internal::Type::HashOf[String] # @!attribute type_id # The entity type identifier this entity instantiates # # @return [String] required :type_id, String, api_name: :typeId # @!attribute updated_at # Timestamp of when the record was last updated # # @return [Time] required :updated_at, Time, api_name: :updatedAt # @!method initialize(id:, archived_at:, created_at:, metadata:, type_id:, updated_at:) # A stored entity instance tracked by the governance service for a given customer # # @param id [String] The unique identifier for the entity # # @param archived_at [Time, nil] Timestamp of when the record was deleted # # @param created_at [Time] Timestamp of when the record was created # # @param metadata [Hash{Symbol=>String}] Free-form key/value metadata attached to the entity # # @param type_id [String] The entity type identifier this entity instantiates # # @param updated_at [Time] Timestamp of when the record was last updated end |
Instance Attribute Details
#archived_at ⇒ Time?
Timestamp of when the record was deleted
31 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 31 required :archived_at, Time, api_name: :archivedAt, nil?: true |
#created_at ⇒ Time
Timestamp of when the record was created
37 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 37 required :created_at, Time, api_name: :createdAt |
#id ⇒ String
The unique identifier for the entity
25 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 25 required :id, String |
#metadata ⇒ Hash{Symbol=>String}
Free-form key/value metadata attached to the entity
43 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 43 required :metadata, Stigg::Internal::Type::HashOf[String] |
#type_id ⇒ String
The entity type identifier this entity instantiates
49 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 49 required :type_id, String, api_name: :typeId |
#updated_at ⇒ Time
Timestamp of when the record was last updated
55 |
# File 'lib/stigg/models/v1_beta/customers/entity_upsert_response.rb', line 55 required :updated_at, Time, api_name: :updatedAt |