Class: Stigg::Models::V1Beta::EntityTypeUpsertParams::Type
- Inherits:
-
Internal::Type::BaseModel
- Object
- Internal::Type::BaseModel
- Stigg::Models::V1Beta::EntityTypeUpsertParams::Type
- Defined in:
- lib/stigg/models/v1_beta/entity_type_upsert_params.rb
Instance Attribute Summary collapse
-
#attribution_keys ⇒ Array<String>
Dimension keys used to attribute usage events to instances of this type (e.g. [“orgId”]).
-
#display_name ⇒ String
The display name for the entity type.
-
#id ⇒ String
The unique identifier for the entity.
Instance Method Summary collapse
-
#initialize(id:, attribution_keys:, display_name:) ⇒ Object
constructor
Some parameter documentations has been truncated, see Type for more details.
Methods inherited from Internal::Type::BaseModel
==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml
Methods included from Internal::Type::Converter
#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info
Methods included from Internal::Util::SorbetRuntimeSupport
#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type
Constructor Details
#initialize(id:, attribution_keys:, display_name:) ⇒ Object
Some parameter documentations has been truncated, see Stigg::Models::V1Beta::EntityTypeUpsertParams::Type for more details.
A single entity type definition.
22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 22 class Type < Stigg::Internal::Type::BaseModel # @!attribute id # The unique identifier for the entity # # @return [String] required :id, String # @!attribute attribution_keys # Dimension keys used to attribute usage events to instances of this type (e.g. # ["orgId"]). Empty array means no attribution. # # @return [Array<String>] required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys # @!attribute display_name # The display name for the entity type # # @return [String] required :display_name, String, api_name: :displayName # @!method initialize(id:, attribution_keys:, display_name:) # Some parameter documentations has been truncated, see # {Stigg::Models::V1Beta::EntityTypeUpsertParams::Type} for more details. # # A single entity type definition. # # @param id [String] The unique identifier for the entity # # @param attribution_keys [Array<String>] Dimension keys used to attribute usage events to instances of this type (e.g. [" # # @param display_name [String] The display name for the entity type end |
Instance Attribute Details
#attribution_keys ⇒ Array<String>
Dimension keys used to attribute usage events to instances of this type (e.g. [“orgId”]). Empty array means no attribution.
34 |
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 34 required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys |
#display_name ⇒ String
The display name for the entity type
40 |
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 40 required :display_name, String, api_name: :displayName |
#id ⇒ String
The unique identifier for the entity
27 |
# File 'lib/stigg/models/v1_beta/entity_type_upsert_params.rb', line 27 required :id, String |