Class: Stigg::Models::V1Beta::EntityTypeUpsertResponse::Data

Inherits:
Internal::Type::BaseModel show all
Defined in:
lib/stigg/models/v1_beta/entity_type_upsert_response.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods inherited from Internal::Type::BaseModel

==, #==, #[], coerce, #deconstruct_keys, #deep_to_h, dump, fields, hash, #hash, inherited, inspect, #inspect, known_fields, optional, recursively_to_h, required, #to_h, #to_json, #to_s, to_sorbet_type, #to_yaml

Methods included from Internal::Type::Converter

#coerce, coerce, #dump, dump, #inspect, inspect, meta_info, new_coerce_state, type_info

Methods included from Internal::Util::SorbetRuntimeSupport

#const_missing, #define_sorbet_constant!, #sorbet_constant_defined?, #to_sorbet_type, to_sorbet_type

Constructor Details

#initialize(id:, attribution_keys:, created_at:, display_name:, updated_at:) ⇒ Object

Some parameter documentations has been truncated, see Stigg::Models::V1Beta::EntityTypeUpsertResponse::Data for more details.

A vendor-defined category of resource that can be governed (e.g. Org, Team, User). Vendors define entity types once per environment; their customers create instances (entities) of these types and the governance engine tracks usage and enforces limits per instance.

Parameters:

  • id (String)

    The unique identifier for the entity

  • attribution_keys (Array<String>)

    Dimension keys used to attribute usage events to instances of this type (e.g. [“

  • created_at (Time)

    Timestamp of when the record was created

  • display_name (String)

    The display name for the entity type

  • updated_at (Time)

    Timestamp of when the record was last updated



19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 19

class Data < Stigg::Internal::Type::BaseModel
  # @!attribute id
  #   The unique identifier for the entity
  #
  #   @return [String]
  required :id, String

  # @!attribute attribution_keys
  #   Dimension keys used to attribute usage events to instances of this type (e.g.
  #   ["orgId"]). Empty array means no attribution.
  #
  #   @return [Array<String>]
  required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys

  # @!attribute created_at
  #   Timestamp of when the record was created
  #
  #   @return [Time]
  required :created_at, Time, api_name: :createdAt

  # @!attribute display_name
  #   The display name for the entity type
  #
  #   @return [String]
  required :display_name, String, api_name: :displayName

  # @!attribute updated_at
  #   Timestamp of when the record was last updated
  #
  #   @return [Time]
  required :updated_at, Time, api_name: :updatedAt

  # @!method initialize(id:, attribution_keys:, created_at:, display_name:, updated_at:)
  #   Some parameter documentations has been truncated, see
  #   {Stigg::Models::V1Beta::EntityTypeUpsertResponse::Data} for more details.
  #
  #   A vendor-defined category of resource that can be governed (e.g. Org, Team,
  #   User). Vendors define entity types once per environment; their customers create
  #   instances (entities) of these types and the governance engine tracks usage and
  #   enforces limits per instance.
  #
  #   @param id [String] The unique identifier for the entity
  #
  #   @param attribution_keys [Array<String>] Dimension keys used to attribute usage events to instances of this type (e.g. ["
  #
  #   @param created_at [Time] Timestamp of when the record was created
  #
  #   @param display_name [String] The display name for the entity type
  #
  #   @param updated_at [Time] Timestamp of when the record was last updated
end

Instance Attribute Details

#attribution_keysArray<String>

Dimension keys used to attribute usage events to instances of this type (e.g. [“orgId”]). Empty array means no attribution.

Returns:

  • (Array<String>)


31
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 31

required :attribution_keys, Stigg::Internal::Type::ArrayOf[String], api_name: :attributionKeys

#created_atTime

Timestamp of when the record was created

Returns:

  • (Time)


37
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 37

required :created_at, Time, api_name: :createdAt

#display_nameString

The display name for the entity type

Returns:

  • (String)


43
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 43

required :display_name, String, api_name: :displayName

#idString

The unique identifier for the entity

Returns:

  • (String)


24
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 24

required :id, String

#updated_atTime

Timestamp of when the record was last updated

Returns:

  • (Time)


49
# File 'lib/stigg/models/v1_beta/entity_type_upsert_response.rb', line 49

required :updated_at, Time, api_name: :updatedAt