Class: Stigg::Resources::V1::Credits

Inherits:
Object
  • Object
show all
Defined in:
lib/stigg/resources/v1/credits.rb,
lib/stigg/resources/v1/credits/grants.rb,
lib/stigg/resources/v1/credits/custom_currencies.rb

Defined Under Namespace

Classes: CustomCurrencies, Grants

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(client:) ⇒ Credits

This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.

Returns a new instance of Credits.

Parameters:



126
127
128
129
130
# File 'lib/stigg/resources/v1/credits.rb', line 126

def initialize(client:)
  @client = client
  @grants = Stigg::Resources::V1::Credits::Grants.new(client: client)
  @custom_currencies = Stigg::Resources::V1::Credits::CustomCurrencies.new(client: client)
end

Instance Attribute Details

#custom_currenciesStigg::Resources::V1::Credits::CustomCurrencies (readonly)

Operations related to custom currencies



13
14
15
# File 'lib/stigg/resources/v1/credits.rb', line 13

def custom_currencies
  @custom_currencies
end

#grantsStigg::Resources::V1::Credits::Grants (readonly)

Operations related to credit grants



9
10
11
# File 'lib/stigg/resources/v1/credits.rb', line 9

def grants
  @grants
end

Instance Method Details

#get_auto_recharge(currency_id:, customer_id:, request_options: {}) ⇒ Stigg::Models::V1::CreditGetAutoRechargeResponse

Retrieves the automatic recharge configuration for a customer and currency. Returns default settings if no configuration exists.

Parameters:

  • currency_id (String)

    Filter by currency ID (required)

  • customer_id (String)

    Filter by customer ID (required)

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



29
30
31
32
33
34
35
36
37
38
39
# File 'lib/stigg/resources/v1/credits.rb', line 29

def get_auto_recharge(params)
  parsed, options = Stigg::V1::CreditGetAutoRechargeParams.dump_request(params)
  query = Stigg::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "api/v1/credits/auto-recharge",
    query: query.transform_keys(currency_id: "currencyId", customer_id: "customerId"),
    model: Stigg::Models::V1::CreditGetAutoRechargeResponse,
    options: options
  )
end

#get_usage(customer_id:, currency_id: nil, end_date: nil, resource_id: nil, start_date: nil, time_range: nil, request_options: {}) ⇒ Stigg::Models::V1::CreditGetUsageResponse

Some parameter documentations has been truncated, see Models::V1::CreditGetUsageParams for more details.

Retrieves credit usage time-series data for a customer, grouped by feature, over a specified time range.

Parameters:

  • customer_id (String)

    Filter by customer ID (required)

  • currency_id (String)

    Filter by currency ID

  • end_date (Time)

    End date for the credit usage time range (ISO 8601). Defaults to now when startD

  • resource_id (String)

    Filter by resource ID

  • start_date (Time)

    Start date for the credit usage time range (ISO 8601). Takes precedence over tim

  • time_range (Symbol, Stigg::Models::V1::CreditGetUsageParams::TimeRange)

    Time range for usage data (LAST_DAY, LAST_WEEK, LAST_MONTH, LAST_YEAR). Defaults

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/stigg/resources/v1/credits.rb', line 66

def get_usage(params)
  parsed, options = Stigg::V1::CreditGetUsageParams.dump_request(params)
  query = Stigg::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "api/v1/credits/usage",
    query: query.transform_keys(
      customer_id: "customerId",
      currency_id: "currencyId",
      end_date: "endDate",
      resource_id: "resourceId",
      start_date: "startDate",
      time_range: "timeRange"
    ),
    model: Stigg::Models::V1::CreditGetUsageResponse,
    options: options
  )
end

#list_ledger(customer_id:, after: nil, before: nil, currency_id: nil, limit: nil, resource_id: nil, request_options: {}) ⇒ Stigg::Internal::MyCursorIDPage<Stigg::Models::V1::CreditListLedgerResponse>

Retrieves a paginated list of credit ledger events for a customer.

Parameters:

  • customer_id (String)

    Filter by customer ID (required)

  • after (String)

    Return items that come after this cursor

  • before (String)

    Return items that come before this cursor

  • currency_id (String)

    Filter by currency ID

  • limit (Integer)

    Maximum number of items to return

  • resource_id (String)

    Filter by resource ID

  • request_options (Stigg::RequestOptions, Hash{Symbol=>Object}, nil)

Returns:

See Also:



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/stigg/resources/v1/credits.rb', line 106

def list_ledger(params)
  parsed, options = Stigg::V1::CreditListLedgerParams.dump_request(params)
  query = Stigg::Internal::Util.encode_query_params(parsed)
  @client.request(
    method: :get,
    path: "api/v1/credits/ledger",
    query: query.transform_keys(
      customer_id: "customerId",
      currency_id: "currencyId",
      resource_id: "resourceId"
    ),
    page: Stigg::Internal::MyCursorIDPage,
    model: Stigg::Models::V1::CreditListLedgerResponse,
    options: options
  )
end